@@ -5,18 +5,20 @@
 mlpack uses CMake as a build system and allows several flexible build
 configuration options.  One can consult any of numerous CMake tutorials for
 further documentation, but this tutorial should be enough to get mlpack built
-and installed.
+and installed on most Linux and UNIX-like systems (including OS X).  If you want
+to build mlpack on Windows, see <a
+href="http://keon.io/mlpack-on-windows.html">Keon's excellent tutorial</a>.
 
 @section Download latest mlpack build
-Download latest mlpack build from here: <a
-href="http://www.mlpack.org/files/mlpack-2.0.1.tar.gz">mlpack-2.0.1</a>
+
+Download latest mlpack build from here:
 
 @section builddir Creating Build Directory
 
 Once the mlpack source is unpacked, you should create a build directory.
 
 @code
-$ cd mlpack-2.0.1
+$ cd mlpack-2.0.2
 $ mkdir build
 @endcode
 
@@ -36,24 +38,16 @@ In Ubuntu and Debian, you can get all of these dependencies through apt:
 
 @code
 # apt-get install libboost-math-dev libboost-program-options-dev
-  libboost-test-dev libboost-serialization-dev libarmadillo-dev
+  libboost-test-dev libboost-serialization-dev libarmadillo-dev binutils-dev
 @endcode
 
-If you are using an Ubuntu version older than 13.10 ("Saucy Salamander") or
-Debian older than Jessie, you will have to compile Armadillo from source.  See
-the README.txt distributed with Armadillo for more information.
-
-On Fedora, Red Hat, or CentOS, these same dependencies can be obtained via yum:
+On Fedora, Red Hat, or CentOS, these same dependencies can be obtained via dnf:
 
 @code
-# yum install boost-devel boost-test boost-program-options boost-math
-  libxml2-devel armadillo-devel
+# dnf install boost-devel boost-test boost-program-options boost-math
+  armadillo-devel binutils-devel
 @endcode
 
-On Red Hat Enterprise Linux 5 and older (as well as CentOS 5), the Armadillo
-version available is too old and must be compiled by hand.  The same applies for
-Fedora 16 and older.
-
 @section config Configuring CMake
 
 Running CMake is the equivalent to running `./configure` with autotools.  If you
@@ -84,6 +78,12 @@ The full list of options mlpack allows:
    OFF in releases)
  - ARMA_EXTRA_DEBUG=(ON/OFF): compile with extra Armadillo debugging symbols
        (default OFF)
+ - BUILD_TESTS=(ON/OFF): compile the \c mlpack_test program (default ON)
+ - BUILD_CLI_EXECUTABLES=(ON/OFF): compile the mlpack command-line executables
+       (i.e. \c mlpack_knn, \c mlpack_kfn, \c mlpack_logistic_regression, etc.)
+       (default ON)
+ - TEST_VERBOSE=(ON/OFF): run test cases in \c mlpack_test with verbose output
+       (default OFF)
 
 Each option can be specified to CMake with the '-D' flag.  Other tools can also
 be used to configure CMake, but those are not documented here.
@@ -105,7 +105,7 @@ You can specify individual components which you want to build, if you do not
 want to build everything in the library:
 
 @code
-$ make pca allknn allkfn
+$ make mlpack_pca mlpack_knn mlpack_kfn
 @endcode
 
 If the build fails and you cannot figure out why, register an account on Trac
@@ -116,7 +116,7 @@ http://mlpack.org/
 
 Alternately, mlpack help can be found in IRC at \#mlpack on irc.freenode.net.
 
-@section install Installing mlpack 
+@section install Installing mlpack
 
 If you wish to install mlpack to /usr/include/mlpack/ and /usr/lib/ and
 /usr/bin/, once it has built, make sure you have root privileges (or write
