@@ -6,15 +6,15 @@
  * is useful when the dataset contains categorical non-numeric features that
  * needs to be mapped to categorical numeric features.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_DATA_DATASET_INFO_HPP
-#define __MLPACK_CORE_DATA_DATASET_INFO_HPP
+#ifndef MLPACK_CORE_DATA_DATASET_INFO_HPP
+#define MLPACK_CORE_DATA_DATASET_INFO_HPP
 
 #include <mlpack/core.hpp>
 #include <unordered_map>
@@ -38,8 +38,8 @@ enum Datatype : bool /* bool is all the precision we need for two types */
 /**
  * Auxiliary information for a dataset, including mappings to/from strings and
  * the datatype of each dimension.  DatasetInfo objects are optionally produced
- * by data::Load(), and store the type of each dimension (Datatype::NUMERIC or
- * Datatype::CATEGORICAL) as well as mappings from strings to unsigned integers
+ * by data::Load(), and store the type of each dimension (Datatype::numeric or
+ * Datatype::categorical) as well as mappings from strings to unsigned integers
  * and vice versa.
  */
 class DatasetInfo
@@ -63,15 +63,38 @@ class DatasetInfo
    */
   size_t MapString(const std::string& string, const size_t dimension);
 
+  /**
+   * Return the string that corresponds to a given value in a given dimension.
+   * If the string is not a valid mapping in the given dimension, a
+   * std::invalid_argument is thrown.
+   *
+   * @param value Mapped value for string.
+   * @param dimension Dimension to unmap string from.
+   */
   const std::string& UnmapString(const size_t value, const size_t dimension);
 
+  //! Return the type of a given dimension (numeric or categorical).
   Datatype Type(const size_t dimension) const;
+  //! Modify the type of a given dimension (be careful!).
   Datatype& Type(const size_t dimension);
 
+  /**
+   * Get the number of mappings for a particular dimension.  If the dimension
+   * is numeric, then this will return 0.
+   */
   size_t NumMappings(const size_t dimension) const;
 
+  /**
+   * Get the dimensionality of the DatasetInfo object (that is, how many
+   * dimensions it has information for).  If this object was created by a call
+   * to mlpack::data::Load(), then the dimensionality will be the same as the
+   * number of rows (dimensions) in the dataset.
+   */
   size_t Dimensionality() const;
 
+  /**
+   * Serialize the dataset information.
+   */
   template<typename Archive>
   void Serialize(Archive& ar, const unsigned int /* version */)
   {
@@ -80,9 +103,11 @@ class DatasetInfo
   }
 
  private:
+  //! Types of each dimension.
   std::vector<Datatype> types;
 
-  // Map entries will only exist for dimensions that are categorical.
+  //! Mappings from strings to integers.  Map entries will only exist for
+  //! dimensions that are categorical.
   std::unordered_map<size_t, std::pair<boost::bimap<std::string, size_t>,
       size_t>> maps;
 
