@@ -5,15 +5,15 @@
  * Given a filename, extract its extension.  This is used by data::Load() and
  * data::Save().
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_DATA_EXTENSION_HPP
-#define __MLPACK_CORE_DATA_EXTENSION_HPP
+#ifndef MLPACK_CORE_DATA_EXTENSION_HPP
+#define MLPACK_CORE_DATA_EXTENSION_HPP
 
 #include <mlpack/prereqs.hpp>
 
