@@ -8,23 +8,15 @@
  * This allows our mlpack naming conventions to remain intact, and only costs a
  * small amount of ridiculous template metaprogramming.
  *
- * This file is part of mlpack 2.0.0.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * mlpack is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * mlpack.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redistribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_UTIL_SERIALIZATION_SHIM_HPP
-#define __MLPACK_CORE_UTIL_SERIALIZATION_SHIM_HPP
+#ifndef MLPACK_CORE_UTIL_SERIALIZATION_SHIM_HPP
+#define MLPACK_CORE_UTIL_SERIALIZATION_SHIM_HPP
 
 #include <mlpack/core/util/sfinae_utility.hpp>
 #include <boost/serialization/serialization.hpp>
