@@ -4,15 +4,15 @@
  *
  * Definition of the Epanechnikov kernel.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_KERNELS_EPANECHNIKOV_KERNEL_HPP
-#define __MLPACK_CORE_KERNELS_EPANECHNIKOV_KERNEL_HPP
+#ifndef MLPACK_CORE_KERNELS_EPANECHNIKOV_KERNEL_HPP
+#define MLPACK_CORE_KERNELS_EPANECHNIKOV_KERNEL_HPP
 
 #include <mlpack/core.hpp>
 
@@ -59,12 +59,12 @@ class EpanechnikovKernel
   double Evaluate(const double distance) const;
 
   /**
-   * Evaluate the Gradient of Epanechnikov kernel 
+   * Evaluate the Gradient of Epanechnikov kernel
    * given that the distance between the two
    * input points is known.
    */
   double Gradient(const double distance) const;
-  
+
   /**
    * Evaluate the Gradient of Epanechnikov kernel
    * given that the squared distance between the two
