@@ -6,15 +6,15 @@
  *
  * Implementation of the Gaussian kernel (GaussianKernel).
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_KERNELS_GAUSSIAN_KERNEL_HPP
-#define __MLPACK_CORE_KERNELS_GAUSSIAN_KERNEL_HPP
+#ifndef MLPACK_CORE_KERNELS_GAUSSIAN_KERNEL_HPP
+#define MLPACK_CORE_KERNELS_GAUSSIAN_KERNEL_HPP
 
 #include <mlpack/core.hpp>
 #include <mlpack/core/metrics/lmetric.hpp>
@@ -81,9 +81,9 @@ class GaussianKernel
     // The precalculation of gamma saves us a little computation time.
     return exp(gamma * std::pow(t, 2.0));
   }
-  
+
   /**
-   * Evaluation of the gradient of Gaussian kernel 
+   * Evaluation of the gradient of Gaussian kernel
    * given the distance between two points.
    *
    * @param t The distance between the two points the kernel is evaluated on.
@@ -93,7 +93,7 @@ class GaussianKernel
   double Gradient(const double t) const {
     return 2 * t * gamma * exp(gamma * std::pow(t, 2.0));
   }
-  
+
   /**
    * Evaluation of the gradient of Gaussian kernel
    * given the squared distance between two points.
