@@ -5,15 +5,15 @@
  * This provides the KernelTraits class, a template class to get information
  * about various kernels.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_KERNELS_KERNEL_TRAITS_HPP
-#define __MLPACK_CORE_KERNELS_KERNEL_TRAITS_HPP
+#ifndef MLPACK_CORE_KERNELS_KERNEL_TRAITS_HPP
+#define MLPACK_CORE_KERNELS_KERNEL_TRAITS_HPP
 
 namespace mlpack {
 namespace kernel {
@@ -33,7 +33,7 @@ class KernelTraits
    * If true, then the kernel is normalized: K(x, x) = K(y, y) = 1 for all x.
    */
   static const bool IsNormalized = false;
-  
+
   /**
    * If true, then the kernel include a squared distance, ||x - y||^2 .
    */
