@@ -4,15 +4,15 @@
  *
  * Implementation of the Laplacian kernel (LaplacianKernel).
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_KERNELS_LAPLACIAN_KERNEL_HPP
-#define __MLPACK_CORE_KERNELS_LAPLACIAN_KERNEL_HPP
+#ifndef MLPACK_CORE_KERNELS_LAPLACIAN_KERNEL_HPP
+#define MLPACK_CORE_KERNELS_LAPLACIAN_KERNEL_HPP
 
 #include <mlpack/core.hpp>
 
@@ -79,7 +79,7 @@ class LaplacianKernel
     // The precalculation of gamma saves us a little computation time.
     return exp(-t / bandwidth);
   }
-  
+
   /**
    * Evaluation of the gradient of the Laplacian kernel
    * given the distance between two points.
