@@ -4,15 +4,15 @@
  *
  * Definition and implementation of the trivially simple triangular kernel.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_KERNELS_TRIANGULAR_KERNEL_HPP
-#define __MLPACK_CORE_KERNELS_TRIANGULAR_KERNEL_HPP
+#ifndef MLPACK_CORE_KERNELS_TRIANGULAR_KERNEL_HPP
+#define MLPACK_CORE_KERNELS_TRIANGULAR_KERNEL_HPP
 
 #include <mlpack/core.hpp>
 #include <mlpack/core/metrics/lmetric.hpp>
@@ -64,9 +64,9 @@ class TriangularKernel
   {
     return std::max(0.0, (1 - distance) / bandwidth);
   }
-  
+
   /**
-   * Evaluate the gradient of triangular kernel 
+   * Evaluate the gradient of triangular kernel
    * given that the distance between the two
    * points is known.
    *
