@@ -3,15 +3,15 @@
  *
  * Miscellaneous math clamping routines.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_MATH_CLAMP_HPP
-#define __MLPACK_CORE_MATH_CLAMP_HPP
+#ifndef MLPACK_CORE_MATH_CLAMP_HPP
+#define MLPACK_CORE_MATH_CLAMP_HPP
 
 #include <stdlib.h>
 #include <math.h>
@@ -66,4 +66,4 @@ inline double ClampRange(double value,
 } // namespace math
 } // namespace mlpack
 
-#endif // __MLPACK_CORE_MATH_CLAMP_HPP
+#endif // MLPACK_CORE_MATH_CLAMP_HPP
