@@ -4,15 +4,15 @@
  *
  * Linear algebra utilities.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_MATH_LIN_ALG_HPP
-#define __MLPACK_CORE_MATH_LIN_ALG_HPP
+#ifndef MLPACK_CORE_MATH_LIN_ALG_HPP
+#define MLPACK_CORE_MATH_LIN_ALG_HPP
 
 #include <mlpack/prereqs.hpp>
 
@@ -132,4 +132,4 @@ void SymKronId(const arma::mat& A, arma::mat& op);
 // Partially include implementation
 #include "lin_alg_impl.hpp"
 
-#endif // __MLPACK_CORE_MATH_LIN_ALG_HPP
+#endif // MLPACK_CORE_MATH_LIN_ALG_HPP
