@@ -3,28 +3,34 @@
  *
  * Miscellaneous math random-related routines.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_MATH_RANDOM_HPP
-#define __MLPACK_CORE_MATH_RANDOM_HPP
+#ifndef MLPACK_CORE_MATH_RANDOM_HPP
+#define MLPACK_CORE_MATH_RANDOM_HPP
 
 #include <mlpack/prereqs.hpp>
+#include <mlpack/mlpack_export.hpp>
 #include <random>
 
 namespace mlpack {
 namespace math /** Miscellaneous math routines. */ {
 
+/**
+ * MLPACK_EXPORT is required for global variables; it exports the symbols
+ * correctly on Windows.
+ */
+
 // Global random object.
-extern std::mt19937 randGen;
+extern MLPACK_EXPORT std::mt19937 randGen;
 // Global uniform distribution.
-extern std::uniform_real_distribution<> randUniformDist;
+extern MLPACK_EXPORT std::uniform_real_distribution<> randUniformDist;
 // Global normal distribution.
-extern std::normal_distribution<> randNormalDist;
+extern MLPACK_EXPORT std::normal_distribution<> randNormalDist;
 
 /**
  * Set the random seed used by the random functions (Random() and RandInt()).
@@ -101,4 +107,4 @@ inline double RandNormal(const double mean, const double variance)
 } // namespace math
 } // namespace mlpack
 
-#endif // __MLPACK_CORE_MATH_MATH_LIB_HPP
+#endif // MLPACK_CORE_MATH_MATH_LIB_HPP
