@@ -5,15 +5,15 @@
  * Implementation of round() for use on Visual Studio, where C99 isn't
  * implemented.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_MATH_ROUND_HPP
-#define __MLPACK_CORE_MATH_ROUND_HPP
+#ifndef MLPACK_CORE_MATH_ROUND_HPP
+#define MLPACK_CORE_MATH_ROUND_HPP
 
 // _MSC_VER should only be defined for Visual Studio, which doesn't implement
 // C99.
