@@ -5,15 +5,15 @@
  * Inner product induced metric.  If given a kernel function, this gives the
  * complementary metric.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_FASTMKS_IP_METRIC_HPP
-#define __MLPACK_METHODS_FASTMKS_IP_METRIC_HPP
+#ifndef MLPACK_METHODS_FASTMKS_IP_METRIC_HPP
+#define MLPACK_METHODS_FASTMKS_IP_METRIC_HPP
 
 namespace mlpack {
 namespace metric {
@@ -53,7 +53,7 @@ class IPMetric
    * @return Distance between the two points in kernel space.
    */
   template<typename VecTypeA, typename VecTypeB>
-  double Evaluate(const VecTypeA& a, const VecTypeB& b);
+  typename VecTypeA::elem_type Evaluate(const VecTypeA& a, const VecTypeB& b);
 
   //! Get the kernel.
   const KernelType& Kernel() const { return *kernel; }
