@@ -4,15 +4,15 @@
  *
  * Implementation of the IPMetric.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_FASTMKS_IP_METRIC_IMPL_HPP
-#define __MLPACK_METHODS_FASTMKS_IP_METRIC_IMPL_HPP
+#ifndef MLPACK_METHODS_FASTMKS_IP_METRIC_IMPL_HPP
+#define MLPACK_METHODS_FASTMKS_IP_METRIC_IMPL_HPP
 
 // In case it hasn't been included yet.
 #include "ip_metric_impl.hpp"
@@ -51,8 +51,9 @@ IPMetric<KernelType>::~IPMetric()
 
 template<typename KernelType>
 template<typename Vec1Type, typename Vec2Type>
-inline double IPMetric<KernelType>::Evaluate(const Vec1Type& a,
-                                             const Vec2Type& b)
+inline typename Vec1Type::elem_type IPMetric<KernelType>::Evaluate(
+    const Vec1Type& a,
+    const Vec2Type& b)
 {
   // This is the metric induced by the kernel function.
   // Maybe we can do better by caching some of this?
@@ -78,8 +79,9 @@ void IPMetric<KernelType>::Serialize(Archive& ar,
 // the Euclidean distance.
 template<>
 template<typename Vec1Type, typename Vec2Type>
-inline double IPMetric<kernel::LinearKernel>::Evaluate(const Vec1Type& a,
-                                                       const Vec2Type& b)
+inline typename Vec1Type::elem_type IPMetric<kernel::LinearKernel>::Evaluate(
+    const Vec1Type& a,
+    const Vec2Type& b)
 {
   return metric::LMetric<2, true>::Evaluate(a, b);
 }
