@@ -7,15 +7,15 @@
  *
  * This also gives several convenience typedefs for commonly used L-metrics.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_METRICS_LMETRIC_HPP
-#define __MLPACK_CORE_METRICS_LMETRIC_HPP
+#ifndef MLPACK_CORE_METRICS_LMETRIC_HPP
+#define MLPACK_CORE_METRICS_LMETRIC_HPP
 
 #include <mlpack/core.hpp>
 
@@ -82,7 +82,8 @@ class LMetric
    * @return Distance between vectors a and b.
    */
   template<typename VecTypeA, typename VecTypeB>
-  static double Evaluate(const VecTypeA& a, const VecTypeB& b);
+  static typename VecTypeA::elem_type Evaluate(const VecTypeA& a,
+                                               const VecTypeB& b);
 
   //! Serialize the metric (nothing to do).
   template<typename Archive>
