@@ -5,15 +5,15 @@
  *
  * The generic L-BFGS optimizer.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_OPTIMIZERS_LBFGS_LBFGS_HPP
-#define __MLPACK_CORE_OPTIMIZERS_LBFGS_LBFGS_HPP
+#ifndef MLPACK_CORE_OPTIMIZERS_LBFGS_LBFGS_HPP
+#define MLPACK_CORE_OPTIMIZERS_LBFGS_LBFGS_HPP
 
 #include <mlpack/core.hpp>
 
@@ -45,7 +45,7 @@ class L_BFGS
    * @param function Instance of function to be optimized.
    * @param numBasis Number of memory points to be stored (default 5).
    * @param maxIterations Maximum number of iterations for the optimization
-   *     (default 0 -- may run indefinitely).
+   *     (0 means no limit and may run indefinitely).
    * @param armijoConstant Controls the accuracy of the line search routine for
    *     determining the Armijo condition.
    * @param wolfe Parameter for detecting the Wolfe condition.
@@ -58,7 +58,7 @@ class L_BFGS
    */
   L_BFGS(FunctionType& function,
          const size_t numBasis = 10, /* same default as scipy */
-         const size_t maxIterations = 0, /* run forever */
+         const size_t maxIterations = 10000, /* many but not infinite */
          const double armijoConstant = 1e-4,
          const double wolfe = 0.9,
          const double minGradientNorm = 1e-6,
@@ -265,5 +265,5 @@ class L_BFGS
 
 #include "lbfgs_impl.hpp"
 
-#endif // __MLPACK_CORE_OPTIMIZERS_LBFGS_LBFGS_HPP
+#endif // MLPACK_CORE_OPTIMIZERS_LBFGS_LBFGS_HPP
 
