@@ -4,15 +4,15 @@
  *
  * Stochastic Gradient Descent (SGD).
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_OPTIMIZERS_SGD_SGD_HPP
-#define __MLPACK_CORE_OPTIMIZERS_SGD_SGD_HPP
+#ifndef MLPACK_CORE_OPTIMIZERS_SGD_SGD_HPP
+#define MLPACK_CORE_OPTIMIZERS_SGD_SGD_HPP
 
 #include <mlpack/core.hpp>
 
@@ -38,7 +38,7 @@ namespace optimization {
  * is chosen according to \f$ j \f$ (the iteration number).  The SGD class
  * supports either scanning through each of the \f$ n \f$ functions \f$ f_i(A)
  * \f$ linearly, or in a random sequence.  The algorithm continues until \f$ j
- * \f$ reaches the maximum number of iterations -- or when a full sequence of
+ * \f$ reaches the maximum number of iterations---or when a full sequence of
  * updates through each of the \f$ n \f$ functions \f$ f_i(A) \f$ produces an
  * improvement within a certain tolerance \f$ \epsilon \f$.  That is,
  *
@@ -79,7 +79,12 @@ class SGD
 {
  public:
   /**
-   * Construct the SGD optimizer with the given function and parameters.
+   * Construct the SGD optimizer with the given function and parameters.  The
+   * defaults here are not necessarily good for the given problem, so it is
+   * suggested that the values used be tailored to the task at hand.  The
+   * maximum number of iterations refers to the maximum number of points that
+   * are processed (i.e., one iteration equals one point; one iteration does not
+   * equal one pass over the dataset).
    *
    * @param function Function to be optimized (minimized).
    * @param stepSize Step size for each iteration.
