@@ -4,15 +4,15 @@
  * Bounds that are useful for binary space partitioning trees.
  * Interface to a ball bound that works in arbitrary metric spaces.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_BALLBOUND_HPP
-#define __MLPACK_CORE_TREE_BALLBOUND_HPP
+#ifndef MLPACK_CORE_TREE_BALLBOUND_HPP
+#define MLPACK_CORE_TREE_BALLBOUND_HPP
 
 #include <mlpack/core.hpp>
 #include <mlpack/core/metrics/lmetric.hpp>
@@ -23,28 +23,29 @@ namespace bound {
 
 /**
  * Ball bound encloses a set of points at a specific distance (radius) from a
- * specific point (center). TMetricType is the custom metric type that defaults
+ * specific point (center). MetricType is the custom metric type that defaults
  * to the Euclidean (L2) distance.
  *
- * @tparam VecType Type of vector (arma::vec or arma::sp_vec).
- * @tparam TMetricType metric type used in the distance measure.
+ * @tparam MetricType metric type used in the distance measure.
+ * @tparam VecType Type of vector (arma::vec or arma::sp_vec or similar).
  */
-template<typename VecType = arma::vec,
-         typename TMetricType = metric::LMetric<2, true> >
+template<typename MetricType = metric::LMetric<2, true>,
+         typename VecType = arma::vec>
 class BallBound
 {
  public:
+  //! The underlying data type.
+  typedef typename VecType::elem_type ElemType;
+  //! A public version of the vector type.
   typedef VecType Vec;
-  //! Needed for BinarySpaceTree.
-  typedef TMetricType MetricType;
 
  private:
   //! The radius of the ball bound.
-  double radius;
+  ElemType radius;
   //! The center of the ball bound.
   VecType center;
   //! The metric used in this bound.
-  TMetricType* metric;
+  MetricType* metric;
 
   /**
    * To know whether this object allocated memory to the metric member
@@ -72,7 +73,7 @@ class BallBound
    * @param radius Radius of ball bound.
    * @param center Center of ball bound.
    */
-  BallBound(const double radius, const VecType& center);
+  BallBound(const ElemType radius, const VecType& center);
 
   //! Copy constructor. To prevent memory leaks.
   BallBound(const BallBound& other);
@@ -87,9 +88,9 @@ class BallBound
   ~BallBound();
 
   //! Get the radius of the ball.
-  double Radius() const { return radius; }
+  ElemType Radius() const { return radius; }
   //! Modify the radius of the ball.
-  double& Radius() { return radius; }
+  ElemType& Radius() { return radius; }
 
   //! Get the center point of the ball.
   const VecType& Center() const { return center; }
@@ -97,16 +98,16 @@ class BallBound
   VecType& Center() { return center; }
 
   //! Get the dimensionality of the ball.
-  double Dim() const { return center.n_elem; }
+  size_t Dim() const { return center.n_elem; }
 
   /**
    * Get the minimum width of the bound (this is same as the diameter).
    * For ball bounds, width along all dimensions remain same.
    */
-  double MinWidth() const { return radius * 2.0; }
+  ElemType MinWidth() const { return radius * 2.0; }
 
   //! Get the range in a certain dimension.
-  math::Range operator[](const size_t i) const;
+  math::RangeType<ElemType> operator[](const size_t i) const;
 
   /**
    * Determines if a point is within this bound.
@@ -124,42 +125,42 @@ class BallBound
    * Calculates minimum bound-to-point squared distance.
    */
   template<typename OtherVecType>
-  double MinDistance(const OtherVecType& point,
-                     typename boost::enable_if<IsVector<OtherVecType> >* = 0)
+  ElemType MinDistance(const OtherVecType& point,
+                       typename boost::enable_if<IsVector<OtherVecType>>* = 0)
       const;
 
   /**
    * Calculates minimum bound-to-bound squared distance.
    */
-  double MinDistance(const BallBound& other) const;
+  ElemType MinDistance(const BallBound& other) const;
 
   /**
    * Computes maximum distance.
    */
   template<typename OtherVecType>
-  double MaxDistance(const OtherVecType& point,
-                     typename boost::enable_if<IsVector<OtherVecType> >* = 0)
+  ElemType MaxDistance(const OtherVecType& point,
+                       typename boost::enable_if<IsVector<OtherVecType>>* = 0)
       const;
 
   /**
    * Computes maximum distance.
    */
-  double MaxDistance(const BallBound& other) const;
+  ElemType MaxDistance(const BallBound& other) const;
 
   /**
    * Calculates minimum and maximum bound-to-point distance.
    */
   template<typename OtherVecType>
-  math::Range RangeDistance(
+  math::RangeType<ElemType> RangeDistance(
       const OtherVecType& other,
-      typename boost::enable_if<IsVector<OtherVecType> >* = 0) const;
+      typename boost::enable_if<IsVector<OtherVecType>>* = 0) const;
 
   /**
    * Calculates minimum and maximum bound-to-bound distance.
    *
    * Example: bound1.MinDistanceSq(other) for minimum distance.
    */
-  math::Range RangeDistance(const BallBound& other) const;
+  math::RangeType<ElemType> RangeDistance(const BallBound& other) const;
 
   /**
    * Expand the bound to include the given node.
@@ -180,12 +181,12 @@ class BallBound
   /**
    * Returns the diameter of the ballbound.
    */
-  double Diameter() const { return 2 * radius; }
+  ElemType Diameter() const { return 2 * radius; }
 
   //! Returns the distance metric used in this bound.
-  const TMetricType& Metric() const { return *metric; }
+  const MetricType& Metric() const { return *metric; }
   //! Modify the distance metric used in this bound.
-  TMetricType& Metric() { return *metric; }
+  MetricType& Metric() { return *metric; }
 
   //! Serialize the bound.
   template<typename Archive>
@@ -193,8 +194,8 @@ class BallBound
 };
 
 //! A specialization of BoundTraits for this bound type.
-template<typename VecType, typename TMetricType>
-struct BoundTraits<BallBound<VecType, TMetricType>>
+template<typename MetricType, typename VecType>
+struct BoundTraits<BallBound<MetricType, VecType>>
 {
   //! These bounds are potentially loose in some dimensions.
   const static bool HasTightBounds = false;
@@ -205,4 +206,4 @@ struct BoundTraits<BallBound<VecType, TMetricType>>
 
 #include "ballbound_impl.hpp"
 
-#endif // __MLPACK_CORE_TREE_DBALLBOUND_HPP
+#endif // MLPACK_CORE_TREE_DBALLBOUND_HPP
