@@ -5,15 +5,15 @@
  * Template typedefs for the BinarySpaceTree class that satisfy the requirements
  * of the TreeType policy class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_BINARY_SPACE_TREE_TYPEDEF_HPP
-#define __MLPACK_CORE_TREE_BINARY_SPACE_TREE_TYPEDEF_HPP
+#ifndef MLPACK_CORE_TREE_BINARY_SPACE_TREE_TYPEDEF_HPP
+#define MLPACK_CORE_TREE_BINARY_SPACE_TREE_TYPEDEF_HPP
 
 // In case it hasn't been included yet.
 #include "../binary_space_tree.hpp"
@@ -110,7 +110,7 @@ template<typename MetricType, typename StatisticType, typename MatType>
 using BallTree = BinarySpaceTree<MetricType,
                                  StatisticType,
                                  MatType,
-                                 bound::HRectBound,
+                                 bound::BallBound,
                                  MidpointSplit>;
 
 /**
@@ -139,7 +139,7 @@ template<typename MetricType, typename StatisticType, typename MatType>
 using MeanSplitBallTree = BinarySpaceTree<MetricType,
                                           StatisticType,
                                           MatType,
-                                          bound::HRectBound,
+                                          bound::BallBound,
                                           MeanSplit>;
 
 } // namespace tree
