@@ -3,16 +3,16 @@
  *
  * Bounds that are useful for binary space partitioning trees.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 
-#ifndef __MLPACK_CORE_TREE_BOUNDS_HPP
-#define __MLPACK_CORE_TREE_BOUNDS_HPP
+#ifndef MLPACK_CORE_TREE_BOUNDS_HPP
+#define MLPACK_CORE_TREE_BOUNDS_HPP
 
 #include <mlpack/core/math/range.hpp>
 #include <mlpack/core/metrics/lmetric.hpp>
@@ -21,4 +21,4 @@
 #include "hrectbound.hpp"
 #include "ballbound.hpp"
 
-#endif // __MLPACK_CORE_TREE_BOUNDS_HPP
+#endif // MLPACK_CORE_TREE_BOUNDS_HPP
