@@ -5,15 +5,15 @@
  * A very simple policy for the cover tree; the first point in the dataset is
  * chosen as the root of the cover tree.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_FIRST_POINT_IS_ROOT_HPP
-#define __MLPACK_CORE_TREE_FIRST_POINT_IS_ROOT_HPP
+#ifndef MLPACK_CORE_TREE_FIRST_POINT_IS_ROOT_HPP
+#define MLPACK_CORE_TREE_FIRST_POINT_IS_ROOT_HPP
 
 #include <mlpack/core.hpp>
 
@@ -42,4 +42,4 @@ class FirstPointIsRoot
 } // namespace tree
 } // namespace mlpack
 
-#endif // __MLPACK_CORE_TREE_FIRST_POINT_IS_ROOT_HPP
+#endif // MLPACK_CORE_TREE_FIRST_POINT_IS_ROOT_HPP
