@@ -5,15 +5,15 @@
  * This file contains the specialization of the TreeTraits class for the
  * CoverTree type of tree.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_COVER_TREE_TRAITS_HPP
-#define __MLPACK_CORE_TREE_COVER_TREE_TRAITS_HPP
+#ifndef MLPACK_CORE_TREE_COVER_TREE_TRAITS_HPP
+#define MLPACK_CORE_TREE_COVER_TREE_TRAITS_HPP
 
 #include <mlpack/core/tree/tree_traits.hpp>
 
