@@ -6,15 +6,15 @@
  * This file describes the interface for the HRectBound class, which implements
  * a hyperrectangle bound.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_HRECTBOUND_HPP
-#define __MLPACK_CORE_TREE_HRECTBOUND_HPP
+#ifndef MLPACK_CORE_TREE_HRECTBOUND_HPP
+#define MLPACK_CORE_TREE_HRECTBOUND_HPP
 
 #include <mlpack/core.hpp>
 #include <mlpack/core/math/range.hpp>
@@ -48,11 +48,11 @@ struct IsLMetric<metric::LMetric<Power, TakeRoot>>
  * with the LMetric class.  Be sure to use the same template parameters for
  * LMetric as you do for HRectBound -- otherwise odd results may occur.
  *
- * @tparam Power The metric to use; use 2 for Euclidean (L2).
- * @tparam TakeRoot Whether or not the root should be taken (see LMetric
- *     documentation).
+ * @tparam MetricType Type of metric to use; must be of type LMetric.
+ * @tparam ElemType Element type (double/float/int/etc.).
  */
-template<typename MetricType = metric::LMetric<2, true>>
+template<typename MetricType = metric::LMetric<2, true>,
+         typename ElemType = double>
 class HRectBound
 {
   // It is required that HRectBound have an LMetric as the given MetricType.
@@ -93,28 +93,29 @@ class HRectBound
 
   //! Get the range for a particular dimension.  No bounds checking.  Be
   //! careful: this may make MinWidth() invalid.
-  math::Range& operator[](const size_t i) { return bounds[i]; }
+  math::RangeType<ElemType>& operator[](const size_t i) { return bounds[i]; }
   //! Modify the range for a particular dimension.  No bounds checking.
-  const math::Range& operator[](const size_t i) const { return bounds[i]; }
+  const math::RangeType<ElemType>& operator[](const size_t i) const
+  { return bounds[i]; }
 
   //! Get the minimum width of the bound.
-  double MinWidth() const { return minWidth; }
+  ElemType MinWidth() const { return minWidth; }
   //! Modify the minimum width of the bound.
-  double& MinWidth() { return minWidth; }
+  ElemType& MinWidth() { return minWidth; }
 
   /**
    * Calculates the center of the range, placing it into the given vector.
    *
    * @param center Vector which the center will be written to.
    */
-  void Center(arma::vec& center) const;
+  void Center(arma::Col<ElemType>& center) const;
 
   /**
    * Calculate the volume of the hyperrectangle.
    *
    * @return Volume of the hyperrectangle.
    */
-  double Volume() const;
+  ElemType Volume() const;
 
   /**
    * Calculates minimum bound-to-point distance.
@@ -122,15 +123,15 @@ class HRectBound
    * @param point Point to which the minimum distance is requested.
    */
   template<typename VecType>
-  double MinDistance(const VecType& point,
-                     typename boost::enable_if<IsVector<VecType> >* = 0) const;
+  ElemType MinDistance(const VecType& point,
+                       typename boost::enable_if<IsVector<VecType>>* = 0) const;
 
   /**
    * Calculates minimum bound-to-bound distance.
    *
    * @param other Bound to which the minimum distance is requested.
    */
-  double MinDistance(const HRectBound& other) const;
+  ElemType MinDistance(const HRectBound& other) const;
 
   /**
    * Calculates maximum bound-to-point squared distance.
@@ -138,15 +139,15 @@ class HRectBound
    * @param point Point to which the maximum distance is requested.
    */
   template<typename VecType>
-  double MaxDistance(const VecType& point,
-                     typename boost::enable_if<IsVector<VecType> >* = 0) const;
+  ElemType MaxDistance(const VecType& point,
+                       typename boost::enable_if<IsVector<VecType>>* = 0) const;
 
   /**
    * Computes maximum distance.
    *
    * @param other Bound to which the maximum distance is requested.
    */
-  double MaxDistance(const HRectBound& other) const;
+  ElemType MaxDistance(const HRectBound& other) const;
 
   /**
    * Calculates minimum and maximum bound-to-bound distance.
@@ -154,7 +155,7 @@ class HRectBound
    * @param other Bound to which the minimum and maximum distances are
    *     requested.
    */
-  math::Range RangeDistance(const HRectBound& other) const;
+  math::RangeType<ElemType> RangeDistance(const HRectBound& other) const;
 
   /**
    * Calculates minimum and maximum bound-to-point distance.
@@ -163,9 +164,9 @@ class HRectBound
    *     requested.
    */
   template<typename VecType>
-  math::Range RangeDistance(const VecType& point,
-                            typename boost::enable_if<IsVector<VecType> >* = 0)
-      const;
+  math::RangeType<ElemType> RangeDistance(
+      const VecType& point,
+      typename boost::enable_if<IsVector<VecType>>* = 0) const;
 
   /**
    * Expands this region to include new points.
@@ -191,7 +192,7 @@ class HRectBound
   /**
    * Returns the diameter of the hyperrectangle (that is, the longest diagonal).
    */
-  double Diameter() const;
+  ElemType Diameter() const;
 
   /**
    * Serialize the bound object.
@@ -203,14 +204,14 @@ class HRectBound
   //! The dimensionality of the bound.
   size_t dim;
   //! The bounds for each dimension.
-  math::Range* bounds;
+  math::RangeType<ElemType>* bounds;
   //! Cached minimum width of bound.
-  double minWidth;
+  ElemType minWidth;
 };
 
 // A specialization of BoundTraits for this class.
-template<typename MetricType>
-struct BoundTraits<HRectBound<MetricType>>
+template<typename MetricType, typename ElemType>
+struct BoundTraits<HRectBound<MetricType, ElemType>>
 {
   //! These bounds are always tight for each dimension.
   const static bool HasTightBounds = true;
@@ -221,4 +222,4 @@ struct BoundTraits<HRectBound<MetricType>>
 
 #include "hrectbound_impl.hpp"
 
-#endif // __MLPACK_CORE_TREE_HRECTBOUND_HPP
+#endif // MLPACK_CORE_TREE_HRECTBOUND_HPP
