@@ -5,15 +5,15 @@
  * Include all the necessary files to use the Rectangle Type Trees (RTree,
  * RStarTree, XTree, and HilbertRTree).
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_RECTANGLE_TREE_HPP
-#define __MLPACK_CORE_TREE_RECTANGLE_TREE_HPP
+#ifndef MLPACK_CORE_TREE_RECTANGLE_TREE_HPP
+#define MLPACK_CORE_TREE_RECTANGLE_TREE_HPP
 
 /* We include bounds.hpp since it gives us the necessary files.
  * However, we will not use the "ballbounds" option.
