@@ -5,15 +5,15 @@
  * Implementation of RTreeDescentHeuristic, a class that chooses the best child
  * of a node in an R tree when inserting a new point.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_DESCENT_HEURISTIC_IMPL_HPP
-#define __MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_DESCENT_HEURISTIC_IMPL_HPP
+#ifndef MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_DESCENT_HEURISTIC_IMPL_HPP
+#define MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_DESCENT_HEURISTIC_IMPL_HPP
 
 #include "r_tree_descent_heuristic.hpp"
 
@@ -24,14 +24,17 @@ template<typename TreeType>
 inline size_t RTreeDescentHeuristic::ChooseDescentNode(const TreeType* node,
                                                        const arma::vec& point)
 {
-  double minScore = DBL_MAX;
+  // Convenience typedef.
+  typedef typename TreeType::ElemType ElemType;
+
+  ElemType minScore = std::numeric_limits<ElemType>::max();
   int bestIndex = 0;
-  double bestVol = 0.0;
+  ElemType bestVol = 0.0;
 
   for (size_t i = 0; i < node->NumChildren(); i++)
   {
-    double v1 = 1.0;
-    double v2 = 1.0;
+    ElemType v1 = 1.0;
+    ElemType v2 = 1.0;
     for (size_t j = 0; j < node->Children()[i]->Bound().Dim(); j++)
     {
       v1 *= node->Children()[i]->Bound()[j].Width();
@@ -65,14 +68,17 @@ inline size_t RTreeDescentHeuristic::ChooseDescentNode(
     const TreeType* node,
     const TreeType* insertedNode)
 {
-  double minScore = DBL_MAX;
+  // Convenience typedef.
+  typedef typename TreeType::ElemType ElemType;
+
+  ElemType minScore = std::numeric_limits<ElemType>::max();
   int bestIndex = 0;
-  double bestVol = 0.0;
+  ElemType bestVol = 0.0;
 
   for (size_t i = 0; i < node->NumChildren(); i++)
   {
-    double v1 = 1.0;
-    double v2 = 1.0;
+    ElemType v1 = 1.0;
+    ElemType v2 = 1.0;
     for (size_t j = 0; j < node->Children()[i]->Bound().Dim(); j++)
     {
       v1 *= node->Children()[i]->Bound()[j].Width();
