@@ -5,15 +5,15 @@
  * Defintion of the RTreeSplit class, a class that splits the nodes of an R
  * tree, starting at a leaf node and moving upwards if necessary.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_SPLIT_HPP
-#define __MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_SPLIT_HPP
+#ifndef MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_SPLIT_HPP
+#define MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_SPLIT_HPP
 
 #include <mlpack/core.hpp>
 
@@ -25,42 +25,45 @@ namespace tree /** Trees and tree-building procedures. */ {
  * nodes overflow, we split them, moving up the tree and splitting nodes
  * as necessary.
  */
+template<typename TreeType>
 class RTreeSplit
 {
  public:
+  //! Default constructor.
+  RTreeSplit() { }
+
+  //! Construct this with the specified node.
+  RTreeSplit(const TreeType* /* node */) { }
+
+  //! Create a copy of the other split.
+  RTreeSplit(const TreeType& /* other */) { }
+
   /**
    * Split a leaf node using the "default" algorithm.  If necessary, this split
    * will propagate upwards through the tree.
    */
-  template<typename TreeType>
-  static void SplitLeafNode(TreeType* tree,
-                            std::vector<bool>& relevels);
+  void SplitLeafNode(TreeType* tree, std::vector<bool>& relevels);
 
   /**
    * Split a non-leaf node using the "default" algorithm.  If this is a root
    * node, the tree increases in depth.
    */
-  template<typename TreeType>
-  static bool SplitNonLeafNode(TreeType* tree,
-                               std::vector<bool>& relevels);
+  bool SplitNonLeafNode(TreeType* tree, std::vector<bool>& relevels);
 
  private:
   /**
    * Get the seeds for splitting a leaf node.
    */
-  template<typename TreeType>
-  static void GetPointSeeds(const TreeType& tree, int& i, int& j);
+  static void GetPointSeeds(const TreeType* tree, int& i, int& j);
 
   /**
    * Get the seeds for splitting a non-leaf node.
    */
-  template<typename TreeType>
-  static void GetBoundSeeds(const TreeType& tree, int& i, int& j);
+  static void GetBoundSeeds(const TreeType* tree, int& i, int& j);
 
   /**
    * Assign points to the two new nodes.
    */
-  template<typename TreeType>
   static void AssignPointDestNode(TreeType* oldTree,
                                   TreeType* treeOne,
                                   TreeType* treeTwo,
@@ -70,7 +73,6 @@ class RTreeSplit
   /**
    * Assign nodes to the two new nodes.
    */
-  template<typename TreeType>
   static void AssignNodeDestNode(TreeType* oldTree,
                                  TreeType* treeOne,
                                  TreeType* treeTwo,
@@ -80,8 +82,15 @@ class RTreeSplit
   /**
    * Insert a node into another node.
    */
-  template<typename TreeType>
   static void InsertNodeIntoTree(TreeType* destTree, TreeType* srcNode);
+
+ public:
+  /**
+   * Serialize the split.
+   */
+  template<typename Archive>
+  void Serialize(Archive &, const unsigned int /* version */) { };
+
 };
 
 } // namespace tree
