@@ -4,15 +4,15 @@
  *
  * Implementation of class (RTreeSplit) to split a RectangleTree.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_SPLIT_IMPL_HPP
-#define __MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_SPLIT_IMPL_HPP
+#ifndef MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_SPLIT_IMPL_HPP
+#define MLPACK_CORE_TREE_RECTANGLE_TREE_R_TREE_SPLIT_IMPL_HPP
 
 #include "r_tree_split.hpp"
 #include "rectangle_tree.hpp"
@@ -28,7 +28,8 @@ namespace tree {
  * new nodes into the tree, spliting the parent if necessary.
  */
 template<typename TreeType>
-void RTreeSplit::SplitLeafNode(TreeType* tree, std::vector<bool>& relevels)
+void RTreeSplit<TreeType>::SplitLeafNode(TreeType* tree,
+                                         std::vector<bool>& relevels)
 {
   // If we are splitting the root node, we need will do things differently so
   // that the constructor and other methods don't confuse the end user by giving
@@ -42,7 +43,7 @@ void RTreeSplit::SplitLeafNode(TreeType* tree, std::vector<bool>& relevels)
     tree->NullifyData();
     // Because this was a leaf node, numChildren must be 0.
     tree->Children()[(tree->NumChildren())++] = copy;
-    SplitLeafNode(copy, relevels);
+    copy->Split().SplitLeafNode(copy, relevels);
     return;
   }
 
@@ -53,7 +54,7 @@ void RTreeSplit::SplitLeafNode(TreeType* tree, std::vector<bool>& relevels)
   // rectangles, only points.  We assume that the tree uses Euclidean Distance.
   int i = 0;
   int j = 0;
-  GetPointSeeds(*tree, i, j);
+  RTreeSplit<TreeType>::GetPointSeeds(tree,i, j);
 
   TreeType* treeOne = new TreeType(tree->Parent());
   TreeType* treeTwo = new TreeType(tree->Parent());
@@ -73,7 +74,7 @@ void RTreeSplit::SplitLeafNode(TreeType* tree, std::vector<bool>& relevels)
   // just in case, we use an assert.
   assert(par->NumChildren() <= par->MaxNumChildren() + 1);
   if (par->NumChildren() == par->MaxNumChildren() + 1)
-    SplitNonLeafNode(par, relevels);
+    par->Split().SplitNonLeafNode(par, relevels);
 
   assert(treeOne->Parent()->NumChildren() <= treeOne->MaxNumChildren());
   assert(treeOne->Parent()->NumChildren() >= treeOne->MinNumChildren());
@@ -92,7 +93,8 @@ void RTreeSplit::SplitLeafNode(TreeType* tree, std::vector<bool>& relevels)
  * higher up the tree because they were already updated if necessary.
  */
 template<typename TreeType>
-bool RTreeSplit::SplitNonLeafNode(TreeType* tree, std::vector<bool>& relevels)
+bool RTreeSplit<TreeType>::SplitNonLeafNode(TreeType* tree,
+                                            std::vector<bool>& relevels)
 {
   // If we are splitting the root node, we need will do things differently so
   // that the constructor and other methods don't confuse the end user by giving
@@ -105,13 +107,13 @@ bool RTreeSplit::SplitNonLeafNode(TreeType* tree, std::vector<bool>& relevels)
     tree->NumChildren() = 0;
     tree->NullifyData();
     tree->Children()[(tree->NumChildren())++] = copy;
-    SplitNonLeafNode(copy, relevels);
+    copy->Split().SplitNonLeafNode(copy, relevels);
     return true;
   }
 
   int i = 0;
   int j = 0;
-  GetBoundSeeds(*tree, i, j);
+  RTreeSplit<TreeType>::GetBoundSeeds(tree,i, j);
 
   assert(i != j);
 
@@ -138,7 +140,7 @@ bool RTreeSplit::SplitNonLeafNode(TreeType* tree, std::vector<bool>& relevels)
   assert(par->NumChildren() <= par->MaxNumChildren() + 1);
 
   if (par->NumChildren() == par->MaxNumChildren() + 1)
-    SplitNonLeafNode(par, relevels);
+    par->Split().SplitNonLeafNode(par, relevels);
 
   // We have to update the children of each of these new nodes so that they
   // record the correct parent.
@@ -164,18 +166,20 @@ bool RTreeSplit::SplitNonLeafNode(TreeType* tree, std::vector<bool>& relevels)
  * The indices of these points will be stored in iRet and jRet.
  */
 template<typename TreeType>
-void RTreeSplit::GetPointSeeds(const TreeType& tree, int& iRet, int& jRet)
+void RTreeSplit<TreeType>::GetPointSeeds(const TreeType* tree,
+                                         int& iRet,
+                                         int& jRet)
 {
   // Here we want to find the pair of points that it is worst to place in the
   // same node.  Because we are just using points, we will simply choose the two
   // that would create the most voluminous hyperrectangle.
-  double worstPairScore = -1.0;
-  for (size_t i = 0; i < tree.Count(); i++)
+  typename TreeType::ElemType worstPairScore = -1.0;
+  for (size_t i = 0; i < tree->Count(); i++)
   {
-    for (size_t j = i + 1; j < tree.Count(); j++)
+    for (size_t j = i + 1; j < tree->Count(); j++)
     {
-      const double score = arma::prod(arma::abs(tree.LocalDataset().col(i) -
-          tree.LocalDataset().col(j)));
+      const typename TreeType::ElemType score = arma::prod(arma::abs(
+          tree->LocalDataset().col(i) - tree->LocalDataset().col(j)));
 
       if (score > worstPairScore)
       {
@@ -192,20 +196,25 @@ void RTreeSplit::GetPointSeeds(const TreeType& tree, int& iRet, int& jRet)
  * indices of the bounds will be stored in iRet and jRet.
  */
 template<typename TreeType>
-void RTreeSplit::GetBoundSeeds(const TreeType& tree, int& iRet, int& jRet)
+void RTreeSplit<TreeType>::GetBoundSeeds(const TreeType* tree,
+                                         int& iRet,
+                                         int& jRet)
 {
-  double worstPairScore = -1.0;
-  for (size_t i = 0; i < tree.NumChildren(); i++)
+  // Convenience typedef.
+  typedef typename TreeType::ElemType ElemType;
+
+  ElemType worstPairScore = -1.0;
+  for (size_t i = 0; i < tree->NumChildren(); i++)
   {
-    for (size_t j = i + 1; j < tree.NumChildren(); j++)
+    for (size_t j = i + 1; j < tree->NumChildren(); j++)
     {
-      double score = 1.0;
-      for (size_t k = 0; k < tree.Bound().Dim(); k++)
+      ElemType score = 1.0;
+      for (size_t k = 0; k < tree->Bound().Dim(); k++)
       {
-        const double hiMax = std::max(tree.Children()[i]->Bound()[k].Hi(),
-                                      tree.Children()[j]->Bound()[k].Hi());
-        const double loMin = std::min(tree.Children()[i]->Bound()[k].Lo(),
-                                      tree.Children()[j]->Bound()[k].Lo());
+        const ElemType hiMax = std::max(tree->Children()[i]->Bound()[k].Hi(),
+                                        tree->Children()[j]->Bound()[k].Hi());
+        const ElemType loMin = std::min(tree->Children()[i]->Bound()[k].Lo(),
+                                        tree->Children()[j]->Bound()[k].Lo());
         score *= (hiMax - loMin);
       }
 
@@ -220,12 +229,15 @@ void RTreeSplit::GetBoundSeeds(const TreeType& tree, int& iRet, int& jRet)
 }
 
 template<typename TreeType>
-void RTreeSplit::AssignPointDestNode(TreeType* oldTree,
-                                     TreeType* treeOne,
-                                     TreeType* treeTwo,
-                                     const int intI,
-                                     const int intJ)
+void RTreeSplit<TreeType>::AssignPointDestNode(TreeType* oldTree,
+                                               TreeType* treeOne,
+                                               TreeType* treeTwo,
+                                               const int intI,
+                                               const int intJ)
 {
+  // Convenience typedef.
+  typedef typename TreeType::ElemType ElemType;
+
   size_t end = oldTree->Count();
 
   assert(end > 1); // If this isn't true, the tree is really weird.
@@ -271,15 +283,15 @@ void RTreeSplit::AssignPointDestNode(TreeType* oldTree,
       std::min(numAssignedOne, numAssignedTwo)))
   {
     int bestIndex = 0;
-    double bestScore = DBL_MAX;
+    ElemType bestScore = std::numeric_limits<ElemType>::max();
     int bestRect = 1;
 
     // Calculate the increase in volume for assigning this point to each
     // rectangle.
 
     // First, calculate the starting volume.
-    double volOne = 1.0;
-    double volTwo = 1.0;
+    ElemType volOne = 1.0;
+    ElemType volTwo = 1.0;
     for (size_t i = 0; i < oldTree->Bound().Dim(); i++)
     {
       volOne *= treeOne->Bound()[i].Width();
@@ -290,11 +302,11 @@ void RTreeSplit::AssignPointDestNode(TreeType* oldTree,
     // minimizes the increase in volume.
     for (size_t index = 0; index < end; index++)
     {
-      double newVolOne = 1.0;
-      double newVolTwo = 1.0;
+      ElemType newVolOne = 1.0;
+      ElemType newVolTwo = 1.0;
       for (size_t i = 0; i < oldTree->Bound().Dim(); i++)
       {
-        double c = oldTree->LocalDataset().col(index)[i];
+        ElemType c = oldTree->LocalDataset().col(index)[i];
         newVolOne *= treeOne->Bound()[i].Contains(c) ?
             treeOne->Bound()[i].Width() : (c < treeOne->Bound()[i].Lo() ?
             (treeOne->Bound()[i].Hi() - c) : (c - treeOne->Bound()[i].Lo()));
@@ -358,12 +370,14 @@ void RTreeSplit::AssignPointDestNode(TreeType* oldTree,
 }
 
 template<typename TreeType>
-void RTreeSplit::AssignNodeDestNode(TreeType* oldTree,
-                                    TreeType* treeOne,
-                                    TreeType* treeTwo,
-                                    const int intI,
-                                    const int intJ)
+void RTreeSplit<TreeType>::AssignNodeDestNode(TreeType* oldTree,
+                                              TreeType* treeOne,
+                                              TreeType* treeTwo,
+                                              const int intI,
+                                              const int intJ)
 {
+  // Convenience typedef.
+  typedef typename TreeType::ElemType ElemType;
 
   size_t end = oldTree->NumChildren();
   assert(end > 1); // If this isn't true, the tree is really weird.
@@ -413,13 +427,13 @@ void RTreeSplit::AssignNodeDestNode(TreeType* oldTree,
       std::min(numAssignTreeOne, numAssignTreeTwo)))
   {
     int bestIndex = 0;
-    double bestScore = DBL_MAX;
+    ElemType bestScore = std::numeric_limits<ElemType>::max();
     int bestRect = 0;
 
     // Calculate the increase in volume for assigning this node to each of the
     // new rectangles.
-    double volOne = 1.0;
-    double volTwo = 1.0;
+    ElemType volOne = 1.0;
+    ElemType volTwo = 1.0;
     for (size_t i = 0; i < oldTree->Bound().Dim(); i++)
     {
       volOne *= treeOne->Bound()[i].Width();
@@ -428,13 +442,14 @@ void RTreeSplit::AssignNodeDestNode(TreeType* oldTree,
 
     for (size_t index = 0; index < end; index++)
     {
-      double newVolOne = 1.0;
-      double newVolTwo = 1.0;
+      ElemType newVolOne = 1.0;
+      ElemType newVolTwo = 1.0;
       for (size_t i = 0; i < oldTree->Bound().Dim(); i++)
       {
         // For each of the new rectangles, find the width in this dimension if
         // we add the rectangle at index to the new rectangle.
-        const math::Range& range = oldTree->Children()[index]->Bound()[i];
+        const math::RangeType<ElemType>& range =
+            oldTree->Children()[index]->Bound()[i];
         newVolOne *= treeOne->Bound()[i].Contains(range) ?
             treeOne->Bound()[i].Width() : (range.Contains(treeOne->Bound()[i]) ?
             range.Width() : (range.Lo() < treeOne->Bound()[i].Lo() ?
@@ -520,7 +535,8 @@ void RTreeSplit::AssignNodeDestNode(TreeType* oldTree,
  * numberOfChildren.
  */
 template<typename TreeType>
-void RTreeSplit::InsertNodeIntoTree(TreeType* destTree, TreeType* srcNode)
+void RTreeSplit<TreeType>::InsertNodeIntoTree(TreeType* destTree,
+                                              TreeType* srcNode)
 {
   destTree->Bound() |= srcNode->Bound();
   destTree->Children()[destTree->NumChildren()++] = srcNode;
