@@ -5,15 +5,15 @@
  * Definition of generalized rectangle type trees (r_tree, r_star_tree, x_tree,
  * and hilbert_r_tree).
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_RECTANGLE_TREE_RECTANGLE_TREE_HPP
-#define __MLPACK_CORE_TREE_RECTANGLE_TREE_RECTANGLE_TREE_HPP
+#ifndef MLPACK_CORE_TREE_RECTANGLE_TREE_RECTANGLE_TREE_HPP
+#define MLPACK_CORE_TREE_RECTANGLE_TREE_RECTANGLE_TREE_HPP
 
 #include <mlpack/core.hpp>
 
@@ -42,10 +42,11 @@ namespace tree /** Trees and tree-building procedures. */ {
  * @tparam DescentType The heuristic to use when descending the tree to insert
  *    points.
  */
+
 template<typename MetricType = metric::EuclideanDistance,
          typename StatisticType = EmptyStatistic,
          typename MatType = arma::mat,
-         typename SplitType = RTreeSplit,
+         template<typename> class SplitType = RTreeSplit,
          typename DescentType = RTreeDescentHeuristic>
 class RectangleTree
 {
@@ -54,28 +55,10 @@ class RectangleTree
       "RectangleTree: MetricType must be metric::EuclideanDistance.");
 
  public:
-  /**
-   * The X tree requires that the tree records it's "split history".  To make
-   * this easy, we use the following structure.
-   */
-  typedef struct SplitHistoryStruct
-  {
-    int lastDimension;
-    std::vector<bool> history;
-
-    SplitHistoryStruct(int dim) : lastDimension(0), history(dim)
-    {
-      for (int i = 0; i < dim; i++)
-        history[i] = false;
-    }
-
-    template<typename Archive>
-    void Serialize(Archive& ar, const unsigned int /* version */)
-    {
-      ar & data::CreateNVP(lastDimension, "lastDimension");
-      ar & data::CreateNVP(history, "history");
-    }
-  } SplitHistoryStruct;
+  //! So other classes can use TreeType::Mat.
+  typedef MatType Mat;
+  //! The element type held by the matrix type.
+  typedef typename MatType::elem_type ElemType;
 
  private:
   //! The max number of child nodes a non-leaf node can have.
@@ -101,13 +84,11 @@ class RectangleTree
   //! The minimum leaf size.
   size_t minLeafSize;
   //! The bound object for this node.
-  bound::HRectBound<metric::EuclideanDistance> bound;
+  bound::HRectBound<metric::EuclideanDistance, ElemType> bound;
   //! Any extra data contained in the node.
   StatisticType stat;
-  //! A struct to store the "split history" for X trees.
-  SplitHistoryStruct splitHistory;
   //! The distance from the centroid of this node to the centroid of the parent.
-  double parentDistance;
+  ElemType parentDistance;
   //! The dataset.
   const MatType* dataset;
   //! Whether or not we are responsible for deleting the dataset.  This is
@@ -117,11 +98,10 @@ class RectangleTree
   std::vector<size_t> points;
   //! The local dataset
   MatType* localDataset;
+  //! The class that performs the split of the node.
+  SplitType<RectangleTree> split;
 
  public:
-  //! So other classes can use TreeType::Mat.
-  typedef MatType Mat;
-
   //! A single traverser for rectangle type trees.  See
   //! single_tree_traverser.hpp for implementation.
   template<typename RuleType>
@@ -178,8 +158,10 @@ class RectangleTree
    * firstDataIndex) from the parent.
    *
    * @param parentNode The parent of the node that is being constructed.
+   * @param numMaxChildren The max number of child nodes (used in x-trees).
    */
-  explicit RectangleTree(RectangleTree* parentNode);
+  explicit RectangleTree(RectangleTree* parentNode,
+                         const size_t numMaxChildren = 0);
 
   /**
    * Create a rectangle tree by copying the other tree.  Be careful!  This can
@@ -316,10 +298,10 @@ class RectangleTree
   //! Modify the statistic object for this node.
   StatisticType& Stat() { return stat; }
 
-  //! Return the split history object of this node.
-  const SplitHistoryStruct& SplitHistory() const { return splitHistory; }
-  //! Modify the split history object of this node.
-  SplitHistoryStruct& SplitHistory() { return splitHistory; }
+  //! Return the split object of this node.
+  const SplitType<RectangleTree>& Split() const { return split; }
+  //! Modify the split object of this node.
+  SplitType<RectangleTree>& Split() { return split; }
 
   //! Return whether or not this node is a leaf (true if it has no children).
   bool IsLeaf() const;
@@ -384,7 +366,7 @@ class RectangleTree
    * Return the furthest distance to a point held in this node.  If this is not
    * a leaf node, then the distance is 0 because the node holds no points.
    */
-  double FurthestPointDistance() const;
+  ElemType FurthestPointDistance() const;
 
   /**
    * Return the furthest possible descendant distance.  This returns the maximum
@@ -393,19 +375,19 @@ class RectangleTree
    * furthest descendant distance may be less than what this method returns (but
    * it will never be greater than this).
    */
-  double FurthestDescendantDistance() const;
+  ElemType FurthestDescendantDistance() const;
 
   //! Return the minimum distance from the center to any edge of the bound.
   //! Currently, this returns 0, which doesn't break algorithms, but it isn't
   //! necessarily correct, either.
-  double MinimumBoundDistance() const { return bound.MinWidth() / 2.0; }
+  ElemType MinimumBoundDistance() const { return bound.MinWidth() / 2.0; }
 
   //! Return the distance from the center of this node to the center of the
   //! parent node.
-  double ParentDistance() const { return parentDistance; }
+  ElemType ParentDistance() const { return parentDistance; }
   //! Modify the distance from the center of this node to the center of the
   //! parent node.
-  double& ParentDistance() { return parentDistance; }
+  ElemType& ParentDistance() { return parentDistance; }
 
   /**
    * Get the specified child.
@@ -458,27 +440,27 @@ class RectangleTree
   size_t Point(const size_t index) const;
 
   //! Return the minimum distance to another node.
-  double MinDistance(const RectangleTree* other) const
+  ElemType MinDistance(const RectangleTree* other) const
   {
     return bound.MinDistance(other->Bound());
   }
 
   //! Return the maximum distance to another node.
-  double MaxDistance(const RectangleTree* other) const
+  ElemType MaxDistance(const RectangleTree* other) const
   {
     return bound.MaxDistance(other->Bound());
   }
 
   //! Return the minimum and maximum distance to another node.
-  math::Range RangeDistance(const RectangleTree* other) const
+  math::RangeType<ElemType> RangeDistance(const RectangleTree* other) const
   {
     return bound.RangeDistance(other->Bound());
   }
 
   //! Return the minimum distance to another point.
   template<typename VecType>
-  double MinDistance(const VecType& point,
-                     typename boost::enable_if<IsVector<VecType> >::type* = 0)
+  ElemType MinDistance(const VecType& point,
+                       typename boost::enable_if<IsVector<VecType> >::type* = 0)
       const
   {
     return bound.MinDistance(point);
@@ -486,8 +468,8 @@ class RectangleTree
 
   //! Return the maximum distance to another point.
   template<typename VecType>
-  double MaxDistance(const VecType& point,
-                     typename boost::enable_if<IsVector<VecType> >::type* = 0)
+  ElemType MaxDistance(const VecType& point,
+                       typename boost::enable_if<IsVector<VecType> >::type* = 0)
       const
   {
     return bound.MaxDistance(point);
@@ -495,7 +477,7 @@ class RectangleTree
 
   //! Return the minimum and maximum distance to another point.
   template<typename VecType>
-  math::Range RangeDistance(
+  math::RangeType<ElemType> RangeDistance(
       const VecType& point,
       typename boost::enable_if<IsVector<VecType> >::type* = 0) const
   {
