@@ -4,22 +4,21 @@
  *
  * Implementation of generalized rectangle tree.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_TREE_RECTANGLE_TREE_RECTANGLE_TREE_IMPL_HPP
-#define __MLPACK_CORE_TREE_RECTANGLE_TREE_RECTANGLE_TREE_IMPL_HPP
+#ifndef MLPACK_CORE_TREE_RECTANGLE_TREE_RECTANGLE_TREE_IMPL_HPP
+#define MLPACK_CORE_TREE_RECTANGLE_TREE_RECTANGLE_TREE_IMPL_HPP
 
 // In case it wasn't included already for some reason.
 #include "rectangle_tree.hpp"
 
 #include <mlpack/core/util/cli.hpp>
 #include <mlpack/core/util/log.hpp>
-#include <mlpack/core/util/string_util.hpp>
 
 namespace mlpack {
 namespace tree {
@@ -27,7 +26,7 @@ namespace tree {
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 RectangleTree(const MatType& data,
@@ -46,7 +45,6 @@ RectangleTree(const MatType& data,
     maxLeafSize(maxLeafSize),
     minLeafSize(minLeafSize),
     bound(data.n_rows),
-    splitHistory(bound.Dim()),
     parentDistance(0),
     dataset(new MatType(data)),
     ownsDataset(true),
@@ -56,6 +54,8 @@ RectangleTree(const MatType& data,
 {
   stat = StatisticType(*this);
 
+  split = SplitType<RectangleTree>(this);
+
   // For now, just insert the points in order.
   RectangleTree* root = this;
 
@@ -66,7 +66,7 @@ RectangleTree(const MatType& data,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 RectangleTree(MatType&& data,
@@ -85,7 +85,6 @@ RectangleTree(MatType&& data,
     maxLeafSize(maxLeafSize),
     minLeafSize(minLeafSize),
     bound(data.n_rows),
-    splitHistory(bound.Dim()),
     parentDistance(0),
     dataset(new MatType(std::move(data))),
     ownsDataset(true),
@@ -95,6 +94,8 @@ RectangleTree(MatType&& data,
 {
   stat = StatisticType(*this);
 
+  split = SplitType<RectangleTree>(this);
+
   // For now, just insert the points in order.
   RectangleTree* root = this;
 
@@ -105,13 +106,14 @@ RectangleTree(MatType&& data,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 RectangleTree(
     RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>*
-        parentNode) :
-    maxNumChildren(parentNode->MaxNumChildren()),
+        parentNode, const size_t numMaxChildren) :
+    maxNumChildren(numMaxChildren > 0 ? numMaxChildren :
+        parentNode->MaxNumChildren()),
     minNumChildren(parentNode->MinNumChildren()),
     numChildren(0),
     children(maxNumChildren + 1),
@@ -121,7 +123,6 @@ RectangleTree(
     maxLeafSize(parentNode->MaxLeafSize()),
     minLeafSize(parentNode->MinLeafSize()),
     bound(parentNode->Bound().Dim()),
-    splitHistory(bound.Dim()),
     parentDistance(0),
     dataset(&parentNode->Dataset()),
     ownsDataset(false),
@@ -130,6 +131,7 @@ RectangleTree(
                                                   maxLeafSize + 1)))
 {
   stat = StatisticType(*this);
+  split = SplitType<RectangleTree>(this);
 }
 
 /**
@@ -139,7 +141,7 @@ RectangleTree(
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 RectangleTree(
@@ -155,13 +157,13 @@ RectangleTree(
     maxLeafSize(other.MaxLeafSize()),
     minLeafSize(other.MinLeafSize()),
     bound(other.bound),
-    splitHistory(other.SplitHistory()),
     parentDistance(other.ParentDistance()),
-    dataset(new MatType(*other.dataset)),
-    ownsDataset(true),
+    dataset(deepCopy ? new MatType(*other.dataset) : &other.Dataset()),
+    ownsDataset(deepCopy),
     points(other.Points()),
     localDataset(NULL)
 {
+  split = SplitType<RectangleTree>(other);
   if (deepCopy)
   {
     if (numChildren > 0)
@@ -190,7 +192,7 @@ RectangleTree(
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 template<typename Archive>
 RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
@@ -211,7 +213,7 @@ RectangleTree(
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 ~RectangleTree()
@@ -232,7 +234,7 @@ RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     SoftDelete()
@@ -252,7 +254,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     NullifyData()
@@ -267,7 +269,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     InsertPoint(const size_t point)
@@ -304,7 +306,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     InsertPoint(const size_t point, std::vector<bool>& relevels)
@@ -339,7 +341,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     InsertNode(RectangleTree* node,
@@ -368,7 +370,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     DeletePoint(const size_t point)
@@ -413,7 +415,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     DeletePoint(const size_t point, std::vector<bool>& relevels)
@@ -448,7 +450,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     RemoveNode(const RectangleTree* node, std::vector<bool>& relevels)
@@ -477,7 +479,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
                      DescentType>::TreeSize() const
@@ -492,7 +494,7 @@ size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
                      DescentType>::TreeDepth() const
@@ -512,7 +514,7 @@ size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 inline bool RectangleTree<MetricType, StatisticType, MatType, SplitType,
                           DescentType>::IsLeaf() const
@@ -527,10 +529,13 @@ inline bool RectangleTree<MetricType, StatisticType, MatType, SplitType,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
-inline double RectangleTree<MetricType, StatisticType, MatType, SplitType,
-                            DescentType>::FurthestPointDistance() const
+inline
+typename RectangleTree<MetricType, StatisticType, MatType, SplitType,
+    DescentType>::ElemType
+RectangleTree<MetricType, StatisticType, MatType, SplitType,
+    DescentType>::FurthestPointDistance() const
 {
   if (!IsLeaf())
     return 0.0;
@@ -549,10 +554,13 @@ inline double RectangleTree<MetricType, StatisticType, MatType, SplitType,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
-inline double RectangleTree<MetricType, StatisticType, MatType, SplitType,
-                            DescentType>::FurthestDescendantDistance() const
+inline
+typename RectangleTree<MetricType, StatisticType, MatType, SplitType,
+    DescentType>::ElemType
+RectangleTree<MetricType, StatisticType, MatType, SplitType,
+    DescentType>::FurthestDescendantDistance() const
 {
   // Return the distance from the centroid to a corner of the bound.
   return 0.5 * bound.Diameter();
@@ -565,7 +573,7 @@ inline double RectangleTree<MetricType, StatisticType, MatType, SplitType,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 inline size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
                             DescentType>::NumPoints() const
@@ -582,7 +590,7 @@ inline size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 inline size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
                             DescentType>::NumDescendants() const
@@ -606,7 +614,7 @@ inline size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 inline size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
                             DescentType>::Descendant(const size_t index) const
@@ -638,7 +646,7 @@ inline size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 inline size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
                             DescentType>::Point(const size_t index) const
@@ -653,7 +661,7 @@ inline size_t RectangleTree<MetricType, StatisticType, MatType, SplitType,
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     SplitNode(std::vector<bool>& relevels)
@@ -666,7 +674,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 
     // If we are full, then we need to split (or at least try).  The SplitType
     // takes care of this and of moving up the tree if necessary.
-    SplitType::SplitLeafNode(this, relevels);
+    split.SplitLeafNode(this, relevels);
   }
   else
   {
@@ -676,7 +684,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 
     // If we are full, then we need to split (or at least try).  The SplitType
     // takes care of this and of moving up the tree if necessary.
-    SplitType::SplitNonLeafNode(this, relevels);
+    split.SplitNonLeafNode(this, relevels);
   }
 }
 
@@ -684,7 +692,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 RectangleTree() :
@@ -696,7 +704,6 @@ RectangleTree() :
     count(0),
     maxLeafSize(0),
     minLeafSize(0),
-    splitHistory(0),
     parentDistance(0.0),
     dataset(NULL),
     ownsDataset(false),
@@ -712,7 +719,7 @@ RectangleTree() :
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     CondenseTree(const arma::vec& point,
@@ -733,8 +740,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 
         // We find the root and shrink bounds at the same time.
         bool stillShrinking = true;
-        RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>* root =
-            parent;
+        RectangleTree* root = parent;
         while (root->Parent() != NULL)
         {
           if (stillShrinking)
@@ -801,6 +807,14 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     {
       // If there are multiple children, we can't do anything to the root.
       RectangleTree* child = children[0];
+
+      // Required for the X tree.
+      if(child->NumChildren() > maxNumChildren)
+      {
+        maxNumChildren = child->MaxNumChildren();
+        children.resize(maxNumChildren+1);
+      }
+
       for (size_t i = 0; i < child->NumChildren(); i++) {
         children[i] = child->Children()[i];
         children[i]->Parent() = this;
@@ -816,7 +830,6 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
       }
 
       count = child->Count();
-      maxNumChildren = child->MaxNumChildren(); // Required for the X tree.
       child->SoftDelete();
       return;
     }
@@ -835,7 +848,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     ShrinkBoundForPoint(const arma::vec& point)
@@ -847,7 +860,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     {
       if (bound[i].Lo() == point[i])
       {
-        double min = DBL_MAX;
+        ElemType min = std::numeric_limits<ElemType>::max();
         for (size_t j = 0; j < count; j++)
         {
           if (localDataset->col(j)[i] < min)
@@ -866,7 +879,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
       }
       else if (bound[i].Hi() == point[i])
       {
-        double max = -1 * DBL_MAX;
+        ElemType max = std::numeric_limits<ElemType>::lowest();
         for (size_t j = 0; j < count; j++)
         {
           if (localDataset->col(j)[i] > max)
@@ -891,7 +904,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     {
       if (bound[i].Lo() == point[i])
       {
-        double min = DBL_MAX;
+        ElemType min = std::numeric_limits<ElemType>::max();
         for (size_t j = 0; j < numChildren; j++)
         {
           if (children[j]->Bound()[i].Lo() < min)
@@ -906,7 +919,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
       }
       else if (bound[i].Hi() == point[i])
       {
-        double max = -DBL_MAX;
+        ElemType max = std::numeric_limits<ElemType>::lowest();
         for (size_t j = 0; j < numChildren; j++)
         {
           if (children[j]->Bound()[i].Hi() > max)
@@ -931,20 +944,20 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     ShrinkBoundForBound(const bound::HRectBound<MetricType>& /* b */)
 {
   // Using the sum is safe since none of the dimensions can increase.
-  double sum = 0;
+  ElemType sum = 0;
 
   // I think it may be faster to just recalculate the whole thing.
   for (size_t i = 0; i < bound.Dim(); i++)
   {
     sum += bound[i].Width();
-    bound[i].Lo() = DBL_MAX;
-    bound[i].Hi() = -DBL_MAX;
+    bound[i].Lo() = std::numeric_limits<ElemType>::max();
+    bound[i].Hi() = std::numeric_limits<ElemType>::lowest();
   }
 
   for (size_t i = 0; i < numChildren; i++)
@@ -952,7 +965,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
     bound |= children[i]->Bound();
   }
 
-  double sum2 = 0;
+  ElemType sum2 = 0;
   for (size_t i = 0; i < bound.Dim(); i++)
     sum2 += bound[i].Width();
 
@@ -965,7 +978,7 @@ bool RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 template<typename MetricType,
          typename StatisticType,
          typename MatType,
-         typename SplitType,
+         template<typename> class SplitType,
          typename DescentType>
 template<typename Archive>
 void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
@@ -1012,7 +1025,6 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
   ar & CreateNVP(minLeafSize, "minLeafSize");
   ar & CreateNVP(bound, "bound");
   ar & CreateNVP(stat, "stat");
-  ar & CreateNVP(splitHistory, "splitHistory");
   ar & CreateNVP(parentDistance, "parentDistance");
   ar & CreateNVP(dataset, "dataset");
 
@@ -1022,6 +1034,7 @@ void RectangleTree<MetricType, StatisticType, MatType, SplitType, DescentType>::
 
   ar & CreateNVP(points, "points");
   ar & CreateNVP(localDataset, "localDataset");
+  ar & CreateNVP(split, "split");
 
   // Because 'children' holds mlpack types (that have Serialize()), we can't use
   // the std::vector serialization.
