@@ -5,16 +5,16 @@
  *
  * You should define your own statistic that looks like EmptyStatistic.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 
-#ifndef __MLPACK_CORE_TREE_STATISTIC_HPP
-#define __MLPACK_CORE_TREE_STATISTIC_HPP
+#ifndef MLPACK_CORE_TREE_STATISTIC_HPP
+#define MLPACK_CORE_TREE_STATISTIC_HPP
 
 namespace mlpack {
 namespace tree {
@@ -50,4 +50,4 @@ class EmptyStatistic
 } // namespace tree
 } // namespace mlpack
 
-#endif // __MLPACK_CORE_TREE_STATISTIC_HPP
+#endif // MLPACK_CORE_TREE_STATISTIC_HPP
