@@ -8,15 +8,15 @@
  * debugging process where nobody can figure out why the stack is getting
  * mangled.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_UTIL_ARMA_CONFIG_CHECK_HPP
-#define __MLPACK_CORE_UTIL_ARMA_CONFIG_CHECK_HPP
+#ifndef MLPACK_CORE_UTIL_ARMA_CONFIG_CHECK_HPP
+#define MLPACK_CORE_UTIL_ARMA_CONFIG_CHECK_HPP
 
 #include "arma_config.hpp"
 
