@@ -4,25 +4,21 @@
  *
  * Implementation of the CLI module for parsing parameters.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <list>
 #include <boost/program_options.hpp>
-#include <boost/any.hpp>
 #include <boost/scoped_ptr.hpp>
 #include <iostream>
-#include <string>
 
 #include "cli.hpp"
 #include "log.hpp"
 
-#include "option.hpp"
-
 using namespace mlpack;
 using namespace mlpack::util;
 
@@ -62,7 +58,7 @@ CLI::CLI(const CLI& other) : desc(other.desc),
 CLI::~CLI()
 {
   // Terminate the program timers.
-  std::map<std::string, timeval>::iterator it;
+  std::map<std::string, std::chrono::microseconds>::iterator it;
   for (it = timer.GetAllTimers().begin(); it != timer.GetAllTimers().end();
        ++it)
   {
@@ -79,7 +75,7 @@ CLI::~CLI()
     Print();
 
     Log::Info << "Program timers:" << std::endl;
-    std::map<std::string, timeval>::iterator it;
+    std::map<std::string, std::chrono::microseconds>::iterator it;
     for (it = timer.GetAllTimers().begin(); it != timer.GetAllTimers().end();
         ++it)
     {
@@ -107,18 +103,19 @@ CLI::~CLI()
  * @param alias An alias for the parameter.
  * @param required Indicates if parameter must be set on command line.
  */
-void CLI::Add(const std::string& path,
-             const std::string& description,
-             const std::string& alias,
-             bool required)
+void CLI::Add(const std::string& identifier,
+              const std::string& description,
+              const std::string& alias,
+              bool required)
 {
   po::options_description& desc = CLI::GetSingleton().desc;
 
   // Must make use of boost option name syntax.
-  std::string progOptId = alias.length() ? path + "," + alias : path;
+  std::string progOptId =
+      alias.length() ? identifier + "," + alias : identifier;
 
   // Deal with a required alias.
-  AddAlias(alias, path);
+  AddAlias(alias, identifier);
 
   // Add the option to boost::program_options.
   desc.add_options()(progOptId.c_str(), description.c_str());
@@ -129,15 +126,15 @@ void CLI::Add(const std::string& path,
   ParamData data;
   data.desc = description;
   data.tname = "";
-  data.name = path;
+  data.name = identifier;
   data.isFlag = false;
   data.wasPassed = false;
 
-  gmap[path] = data;
+  gmap[identifier] = data;
 
   // If the option is required, add it to the required options list.
   if (required)
-    GetSingleton().requiredOptions.push_front(path);
+    GetSingleton().requiredOptions.push_front(identifier);
 
   return;
 }
@@ -162,8 +159,8 @@ void CLI::AddAlias(const std::string& alias, const std::string& original)
  * @brief Adds a flag parameter to CLI.
  */
 void CLI::AddFlag(const std::string& identifier,
-                 const std::string& description,
-                 const std::string& alias)
+                  const std::string& description,
+                  const std::string& alias)
 {
   // Reuse functionality from Add().
   Add(identifier, description, alias, false);
@@ -460,36 +457,6 @@ void CLI::RemoveDuplicateFlags(po::basic_parsed_options<char>& bpo)
   }
 }
 
-/**
- * Parses a stream for arguments
- *
- * @param stream The stream to be parsed.
- */
-void CLI::ParseStream(std::istream& stream)
-{
-  po::variables_map& vmap = GetSingleton().vmap;
-  po::options_description& desc = GetSingleton().desc;
-
-  // Parse the stream; place options & values into vmap.
-  try
-  {
-    po::store(po::parse_config_file(stream, desc), vmap);
-  }
-  catch (std::exception& ex)
-  {
-    Log::Fatal << ex.what() << std::endl;
-  }
-
-  // Flush the buffer; make sure changes are propagated to vmap.
-  po::notify(vmap);
-
-  UpdateGmap();
-  DefaultMessages();
-  RequiredOptions();
-
-  Timer::Start("total_time");
-}
-
 /* Prints out the current hierarchy. */
 void CLI::Print()
 {
