@@ -5,15 +5,15 @@
  *
  * Declaration of the PrefixedOutStream class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_UTIL_PREFIXEDOUTSTREAM_HPP
-#define __MLPACK_CORE_UTIL_PREFIXEDOUTSTREAM_HPP
+#ifndef MLPACK_CORE_UTIL_PREFIXEDOUTSTREAM_HPP
+#define MLPACK_CORE_UTIL_PREFIXEDOUTSTREAM_HPP
 
 #include <iostream>
 #include <iomanip>
@@ -26,7 +26,6 @@
 #include <boost/type_traits.hpp>
 
 #include <mlpack/core/util/sfinae_utility.hpp>
-#include <mlpack/core/util/string_util.hpp>
 
 namespace mlpack {
 namespace util {
