@@ -7,15 +7,15 @@
  * compile time, which is useful for changing functionality depending on what
  * operations an object is capable of performing.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_SFINAE_UTILITY
-#define __MLPACK_CORE_SFINAE_UTILITY
+#ifndef MLPACK_CORE_SFINAE_UTILITY
+#define MLPACK_CORE_SFINAE_UTILITY
 
 #include <boost/utility/enable_if.hpp>
 #include <boost/type_traits.hpp>
