@@ -5,42 +5,22 @@
  *
  * Timers for MLPACK.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_CORE_UTILITIES_TIMERS_HPP
-#define __MLPACK_CORE_UTILITIES_TIMERS_HPP
+#ifndef MLPACK_CORE_UTILITIES_TIMERS_HPP
+#define MLPACK_CORE_UTILITIES_TIMERS_HPP
 
 #include <map>
 #include <string>
+#include <chrono> // chrono library for cross platform timer calculation
 
-#if defined(__unix__) || defined(__unix)
-  #include <time.h>       // clock_gettime()
-  #include <sys/time.h>   // timeval, gettimeofday()
-  #include <unistd.h>     // flags like  _POSIX_VERSION
-#elif defined(__MACH__) && defined(__APPLE__)
-  #include <mach/mach_time.h>   // mach_timebase_info,
-                                // mach_absolute_time()
-
-  // TEMPORARY
-  #include <time.h>       // clock_gettime()
-  #include <sys/time.h>   // timeval, gettimeofday()
-  #include <unistd.h>     // flags like  _POSIX_VERSION
-#elif defined(_WIN32)
-  #ifndef NOMINMAX
-    #define NOMINMAX // Don't define min and max macros.
-  #endif
-  #include <windows.h>  // GetSystemTimeAsFileTime(),
-                        // QueryPerformanceFrequency(),
-                        // QueryPerformanceCounter()
-  #include <winsock.h>  // timeval on windows
-  #undef NOMINMAX
-
-  // uint64_t isn't defined on every windows.
+#if defined(_WIN32)
+ // uint64_t isn't defined on every windows.
   #if !defined(HAVE_UINT64_T)
     #if SIZEOF_UNSIGNED_LONG == 8
       typedef unsigned long uint64_t;
@@ -48,15 +28,6 @@
       typedef unsigned long long  uint64_t;
     #endif  // SIZEOF_UNSIGNED_LONG
   #endif  // HAVE_UINT64_T
-
-  //gettimeofday has no equivalent will need to write extra code for that.
-  #if defined(_MSC_VER) || defined(_MSC_EXTENSIONS)
-    #define DELTA_EPOCH_IN_MICROSECS 11644473600000000Ui64
-  #else
-    #define DELTA_EPOCH_IN_MICROSECS 11644473600000000ULL
-  #endif // _MSC_VER, _MSC_EXTENSIONS
-#else
-  #error "unknown OS"
 #endif
 
 namespace mlpack {
@@ -97,7 +68,7 @@ class Timer
    *
    * @param name Name of timer to return value of.
    */
-  static timeval Get(const std::string& name);
+  static std::chrono::microseconds Get(const std::string& name);
 };
 
 class Timers
@@ -109,14 +80,14 @@ class Timers
   /**
    * Returns a copy of all the timers used via this interface.
    */
-  std::map<std::string, timeval>& GetAllTimers();
+  std::map<std::string, std::chrono::microseconds>& GetAllTimers();
 
   /**
    * Returns a copy of the timer specified.
    *
    * @param timerName The name of the timer in question.
    */
-  timeval GetTimer(const std::string& timerName);
+  std::chrono::microseconds GetTimer(const std::string& timerName);
 
   /**
    * Prints the specified timer.  If it took longer than a minute to complete
@@ -146,21 +117,23 @@ class Timers
 
   /**
    * Returns state of the given timer.
-   * 
+   *
    * @param timerName The name of the timer in question.
    */
   bool GetState(std::string timerName);
-  
+
  private:
   //! A map of all the timers that are being tracked.
-  std::map<std::string, timeval> timers;
+  std::map<std::string, std::chrono::microseconds> timers;
   //! A map that contains whether or not each timer is currently running.
   std::map<std::string, bool> timerState;
+  //! A map for the starting values of the timers.
+  std::map<std::string, std::chrono::high_resolution_clock::time_point>
+      timerStartTime;
 
-  void FileTimeToTimeVal(timeval* tv);
-  void GetTime(timeval* tv);
+  std::chrono::high_resolution_clock::time_point GetTime();
 };
 
 } // namespace mlpack
 
-#endif // __MLPACK_CORE_UTILITIES_TIMERS_HPP
+#endif // MLPACK_CORE_UTILITIES_TIMERS_HPP
