@@ -18,15 +18,15 @@
  * }
  * @endcode
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_ADABOOST_ADABOOST_IMPL_HPP
-#define __MLPACK_METHODS_ADABOOST_ADABOOST_IMPL_HPP
+#ifndef MLPACK_METHODS_ADABOOST_ADABOOST_IMPL_HPP
+#define MLPACK_METHODS_ADABOOST_ADABOOST_IMPL_HPP
 
 #include "adaboost.hpp"
 
@@ -80,7 +80,7 @@ void AdaBoost<WeakLearnerType, MatType>::Train(
 
   // crt is the cumulative rt value for terminating the optimization when rt is
   // changing by less than the tolerance.
-  double rt, crt, alphat = 0.0, zt;
+  double rt, crt = 0.0, alphat = 0.0, zt;
 
   ztProduct = 1.0;
 
