@@ -2,18 +2,18 @@
  * @file random_init.hpp
  * @author Mohan Rajendran
  *
- * Initialization rule for alternating matrix forization (AMF). This simple
+ * Initialization rule for alternating matrix factorization (AMF). This simple
  * initialization is performed by assigning a random matrix to W and H.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_LMF_RANDOM_INIT_HPP
-#define __MLPACK_METHODS_LMF_RANDOM_INIT_HPP
+#ifndef MLPACK_METHODS_LMF_RANDOM_INIT_HPP
+#define MLPACK_METHODS_LMF_RANDOM_INIT_HPP
 
 #include <mlpack/core.hpp>
 
