@@ -4,9 +4,9 @@
  *
  * Main executable to run CF.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -92,7 +92,7 @@ PARAM_FLAG("all_user_recommendations", "Generate recommendations for all "
     "users.", "A");
 PARAM_STRING("output_file","File to save output recommendations to.", "o", "");
 PARAM_INT("recommendations", "Number of recommendations to generate for each "
-    "query user.", "n", 5);
+    "query user.", "c", 5);
 
 PARAM_INT("seed", "Set the random seed (0 uses std::time(NULL)).", "s", 0);
 
