@@ -5,9 +5,9 @@
  * This file implements functions to perform different tasks with the Density
  * Tree class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -184,14 +184,22 @@ DTree* mlpack::det::Trainer(arma::mat& dataset,
   regularizationConstants.fill(0.0);
 
   Timer::Start("cross_validation");
-  // Go through each fold.
+  // Go through each fold.  On the Visual Studio compiler, we have to use
+  // intmax_t because size_t is not yet supported by their OpenMP
+  // implementation.
+#ifdef _WIN32
+  #pragma omp parallel for default(none) \
+      shared(testSize, cvData, prunedSequence, regularizationConstants, dataset)
+  for (intmax_t fold = 0; fold < (intmax_t) folds; fold++)
+#else
   #pragma omp parallel for default(none) \
       shared(testSize, cvData, prunedSequence, regularizationConstants, dataset)
   for (size_t fold = 0; fold < folds; fold++)
+#endif
   {
     // Break up data into train and test sets.
     size_t start = fold * testSize;
-    size_t end = std::min((fold + 1) * testSize, (size_t) cvData.n_cols);
+    size_t end = std::min((size_t) (fold + 1) * testSize, (size_t) cvData.n_cols);
 
     arma::mat test = cvData.cols(start, end - 1);
     arma::mat train(cvData.n_rows, cvData.n_cols - test.n_cols);
