@@ -5,15 +5,15 @@
  * This file implements functions to perform different tasks with the Density
  * Tree class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_DET_DT_UTILS_HPP
-#define __MLPACK_METHODS_DET_DT_UTILS_HPP
+#ifndef MLPACK_METHODS_DET_DT_UTILS_HPP
+#define MLPACK_METHODS_DET_DT_UTILS_HPP
 
 #include <mlpack/core.hpp>
 #include "dtree.hpp"
@@ -71,4 +71,4 @@ DTree* Trainer(arma::mat& dataset,
 } // namespace det
 } // namespace mlpack
 
-#endif // __MLPACK_METHODS_DET_DT_UTILS_HPP
+#endif // MLPACK_METHODS_DET_DT_UTILS_HPP
