@@ -17,15 +17,15 @@
  * }
  * @endcode
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_EMST_DTB_HPP
-#define __MLPACK_METHODS_EMST_DTB_HPP
+#ifndef MLPACK_METHODS_EMST_DTB_HPP
+#define MLPACK_METHODS_EMST_DTB_HPP
 
 #include "dtb_stat.hpp"
 #include "edge_pair.hpp"
@@ -212,4 +212,4 @@ class DualTreeBoruvka
 
 #include "dtb_impl.hpp"
 
-#endif // __MLPACK_METHODS_EMST_DTB_HPP
+#endif // MLPACK_METHODS_EMST_DTB_HPP
