@@ -4,15 +4,15 @@
  *
  * DTBStat is the StatisticType used by trees when performing EMST.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_EMST_DTB_STAT_HPP
-#define __MLPACK_METHODS_EMST_DTB_STAT_HPP
+#ifndef MLPACK_METHODS_EMST_DTB_STAT_HPP
+#define MLPACK_METHODS_EMST_DTB_STAT_HPP
 
 #include <mlpack/core.hpp>
 
@@ -95,4 +95,4 @@ class DTBStat
 } // namespace emst
 } // namespace mlpack
 
-#endif // __MLPACK_METHODS_EMST_DTB_STAT_HPP
+#endif // MLPACK_METHODS_EMST_DTB_STAT_HPP
