@@ -19,9 +19,9 @@
  * }
  * @endcode
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -41,8 +41,9 @@ PROGRAM_INFO("Fast Euclidean Minimum Spanning Tree", "This program can compute "
     "column corresponds to the distance between the two points.");
 
 PARAM_STRING_REQ("input_file", "Data input file.", "i");
-PARAM_STRING("output_file", "Data output file.  Stored as an edge list.", "o",
-    "emst_output.csv");
+
+PARAM_STRING("output_file", "Data output file.  Stored as an edge list.",
+    "o", "");
 PARAM_FLAG("naive", "Compute the MST using O(n^2) naive algorithm.", "n");
 PARAM_INT("leaf_size", "Leaf size in the kd-tree.  One-element leaves give the "
     "empirically best performance, but at the cost of greater memory "
@@ -58,10 +59,15 @@ int main(int argc, char* argv[])
 {
   CLI::ParseCommandLine(argc, argv);
 
-  const string dataFilename = CLI::GetParam<string>("input_file");
+  const string inputFile = CLI::GetParam<string>("input_file");
+  const string outputFile= CLI::GetParam<string>("output_file");
+
+  if (CLI::HasParam("output_file"))
+    Log::Warn << "--output_file (-o) is not specified; no results will be "
+        << "saved!" << endl;
 
   arma::mat dataPoints;
-  data::Load(dataFilename, dataPoints, true);
+  data::Load(inputFile, dataPoints, true);
 
   // Do naive computation if necessary.
   if (CLI::GetParam<bool>("naive"))
@@ -73,9 +79,8 @@ int main(int argc, char* argv[])
     arma::mat naiveResults;
     naive.ComputeMST(naiveResults);
 
-    const string outputFilename = CLI::GetParam<string>("output_file");
-
-    data::Save(outputFilename, naiveResults, true);
+    if (CLI::HasParam("output_file"))
+      data::Save(outputFile, naiveResults, true);
   }
   else
   {
@@ -127,9 +132,7 @@ int main(int argc, char* argv[])
       unmappedResults(2, i) = results(2, i);
     }
 
-    // Output the results.
-    const string outputFilename = CLI::GetParam<string>("output_file");
-
-    data::Save(outputFilename, unmappedResults, true);
+    if (CLI::HasParam("output_file"))
+      data::Save(outputFile, unmappedResults, true);
   }
 }
