@@ -7,15 +7,15 @@
  * Calling unionfind.Union(x, y) unites the components indexed by x and y.
  * unionfind.Find(x) returns the index of the component containing point x.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_EMST_UNION_FIND_HPP
-#define __MLPACK_METHODS_EMST_UNION_FIND_HPP
+#ifndef MLPACK_METHODS_EMST_UNION_FIND_HPP
+#define MLPACK_METHODS_EMST_UNION_FIND_HPP
 
 #include <mlpack/core.hpp>
 
@@ -103,4 +103,4 @@ class UnionFind
 } // namespace emst
 } // namespace mlpack
 
-#endif // __MLPACK_METHODS_EMST_UNION_FIND_HPP
+#endif // MLPACK_METHODS_EMST_UNION_FIND_HPP
