@@ -4,9 +4,9 @@
  *
  * Given a GMM, calculate the probability of points coming from it.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -29,18 +29,26 @@ PARAM_STRING_REQ("input_model_file", "File containing input GMM.", "m");
 PARAM_STRING_REQ("input_file", "File containing points.", "i");
 
 PARAM_STRING("output_file", "File to save calculated probabilities to.", "o",
-    "output.csv");
+    "");
 
 int main(int argc, char** argv)
 {
   CLI::ParseCommandLine(argc, argv);
 
+  const string inputFile = CLI::GetParam<string>("input_file");
+  const string inputModelFile = CLI::GetParam<string>("input_model_file");
+  const string outputFile = CLI::GetParam<string>("input_model_file");
+
+  if (CLI::HasParam("output_file"))
+    Log::Warn << "--output_file (-o) is not specified;"
+        << "no results will be saved!" << endl;
+
   // Get the GMM and the points.
   GMM gmm;
-  data::Load(CLI::GetParam<string>("input_model_file"), "gmm", gmm);
+  data::Load(inputFile, "gmm", gmm);
 
   arma::mat dataset;
-  data::Load(CLI::GetParam<string>("input_file"), dataset);
+  data::Load(inputModelFile, dataset);
 
   // Now calculate the probabilities.
   arma::rowvec probabilities(dataset.n_cols);
@@ -48,5 +56,6 @@ int main(int argc, char** argv)
     probabilities[i] = gmm.Probability(dataset.unsafe_col(i));
 
   // And save the result.
-  data::Save(CLI::GetParam<string>("output_file"), probabilities);
+  if (CLI::HasParam("output_file"))
+    data::Save(outputFile, probabilities);
 }
