@@ -6,15 +6,15 @@
  *
  * Implementation of HMM class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_HMM_HMM_IMPL_HPP
-#define __MLPACK_METHODS_HMM_HMM_IMPL_HPP
+#ifndef MLPACK_METHODS_HMM_HMM_IMPL_HPP
+#define MLPACK_METHODS_HMM_HMM_IMPL_HPP
 
 // Just in case...
 #include "hmm.hpp"
@@ -134,19 +134,20 @@ void HMM<Distribution>::Train(const std::vector<arma::mat>& dataSeq)
       // Add the log-likelihood of this sequence.  This is the E-step.
       loglik += Estimate(dataSeq[seq], stateProb, forward, backward, scales);
 
+      // Add to estimate of initial probability for state j.
+      for (size_t j = 0; j < transition.n_cols; ++j)
+        newInitial[j] += stateProb(j, 0);
+
       // Now re-estimate the parameters.  This is the M-step.
       //   pi_i = sum_d ((1 / P(seq[d])) sum_t (f(i, 0) b(i, 0))
       //   T_ij = sum_d ((1 / P(seq[d])) sum_t (f(i, t) T_ij E_i(seq[d][t]) b(i,
       //           t + 1)))
       //   E_ij = sum_d ((1 / P(seq[d])) sum_{t | seq[d][t] = j} f(i, t) b(i, t)
       // We store the new estimates in a different matrix.
-      for (size_t t = 0; t < dataSeq[seq].n_cols; t++)
+      for (size_t t = 0; t < dataSeq[seq].n_cols; ++t)
       {
-        for (size_t j = 0; j < transition.n_cols; j++)
+        for (size_t j = 0; j < transition.n_cols; ++j)
         {
-          // Add to estimate of initial probability for state j.
-          newInitial[j] = stateProb(j, 0);
-
           if (t < dataSeq[seq].n_cols - 1)
           {
             // Estimate of T_ij (probability of transition from state j to state
@@ -166,8 +167,10 @@ void HMM<Distribution>::Train(const std::vector<arma::mat>& dataSeq)
     }
 
     // Normalize the new initial probabilities.
-    if (dataSeq.size() == 0)
+    if (dataSeq.size() > 1)
       initial = newInitial / dataSeq.size();
+    else
+      initial = newInitial;
 
     // Assign the new transition matrix.  We use %= (element-wise
     // multiplication) because every element of the new transition matrix must
@@ -177,14 +180,20 @@ void HMM<Distribution>::Train(const std::vector<arma::mat>& dataSeq)
 
     // Now we normalize the transition matrix.
     for (size_t i = 0; i < transition.n_cols; i++)
-      transition.col(i) /= accu(transition.col(i));
+    {
+      const double sum = accu(transition.col(i));
+      if (sum > 0.0)
+        transition.col(i) /= sum;
+      else
+        transition.col(i).fill(1.0 / (double) transition.n_rows);
+    }
 
     // Now estimate emission probabilities.
     for (size_t state = 0; state < transition.n_cols; state++)
       emission[state].Train(emissionList, emissionProb[state]);
 
     Log::Debug << "Iteration " << iter << ": log-likelihood " << loglik
-        << std::endl;
+        << "." << std::endl;
 
     if (std::abs(oldLoglik - loglik) < tolerance)
     {
@@ -517,7 +526,8 @@ void HMM<Distribution>::Forward(const arma::mat& dataSeq,
 
   // Then normalize the column.
   scales[0] = accu(forwardProb.col(0));
-  forwardProb.col(0) /= scales[0];
+  if (scales[0] > 0.0)
+    forwardProb.col(0) /= scales[0];
 
   // Now compute the probabilities for each successive observation.
   for (size_t t = 1; t < dataSeq.n_cols; t++)
@@ -534,7 +544,8 @@ void HMM<Distribution>::Forward(const arma::mat& dataSeq,
 
     // Normalize probability.
     scales[t] = accu(forwardProb.col(t));
-    forwardProb.col(t) /= scales[t];
+    if (scales[t] > 0.0)
+      forwardProb.col(t) /= scales[t];
   }
 }
 
@@ -564,7 +575,8 @@ void HMM<Distribution>::Backward(const arma::mat& dataSeq,
             * emission[state].Probability(dataSeq.unsafe_col(t + 1));
 
       // Normalize by the weights from the forward algorithm.
-      backwardProb(j, t) /= scales[t + 1];
+      if (scales[t + 1] > 0.0)
+        backwardProb(j, t) /= scales[t + 1];
     }
   }
 }
