@@ -5,15 +5,15 @@
  * An implementation of the standard Hoeffding tree by Pedro Domingos and Geoff
  * Hulten in ``Mining High-Speed Data Streams''.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_HOEFFDING_TREES_HOEFFDING_TREE_HPP
-#define __MLPACK_METHODS_HOEFFDING_TREES_HOEFFDING_TREE_HPP
+#ifndef MLPACK_METHODS_HOEFFDING_TREES_HOEFFDING_TREE_HPP
+#define MLPACK_METHODS_HOEFFDING_TREES_HOEFFDING_TREE_HPP
 
 #include <mlpack/core.hpp>
 #include "gini_impurity.hpp"
