@@ -4,9 +4,9 @@
  *
  * A command-line executable that can build a streaming decision tree.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -63,10 +63,10 @@ PARAM_STRING("output_model_file", "File to save trained tree to.", "M", "");
 
 PARAM_STRING("test_file", "File of testing data.", "T", "");
 PARAM_STRING("test_labels_file", "Labels of test data.", "L", "");
-PARAM_STRING("predictions_file", "File to output label predictions for test "
-    "data into.", "p", "");
-PARAM_STRING("probabilities_file", "In addition to predicting labels, provide "
-    "prediction probabilities in this file.", "P", "");
+PARAM_STRING("predictions_file", "File to output label predictions for"
+    "test data into.", "p", "");
+PARAM_STRING("probabilities_file", "In addition to predicting labels, "
+    "provide prediction probabilities in this file.", "P", "");
 
 PARAM_STRING("numeric_split_strategy", "The splitting strategy to use for "
     "numeric features: 'domingos' or 'binary'.", "N", "binary");
@@ -97,25 +97,28 @@ int main(int argc, char** argv)
   const string labelsFile = CLI::GetParam<string>("labels_file");
   const string inputModelFile = CLI::GetParam<string>("input_model_file");
   const string testFile = CLI::GetParam<string>("test_file");
-  const string predictionsFile = CLI::GetParam<string>("predictions_file");
-  const string probabilitiesFile = CLI::GetParam<string>("probabilities_file");
+  const string predictionsFile =
+      CLI::GetParam<string>("predictions_file");
+  const string probabilitiesFile =
+      CLI::GetParam<string>("probabilities_file");
   const string numericSplitStrategy =
       CLI::GetParam<string>("numeric_split_strategy");
 
-  if ((!predictionsFile.empty() || !probabilitiesFile.empty()) &&
-      testFile.empty())
+  if ((CLI::HasParam("predictions_file") ||
+       CLI::HasParam("probabilities_file")) &&
+       !CLI::HasParam("test_file"))
     Log::Fatal << "--test_file must be specified if --predictions_file or "
         << "--probabilities_file is specified." << endl;
 
-  if (trainingFile.empty() && inputModelFile.empty())
+  if (!CLI::HasParam("training_file") && !CLI::HasParam("input_model_file"))
     Log::Fatal << "One of --training_file or --input_model_file must be "
         << "specified!" << endl;
 
-  if (!trainingFile.empty() && labelsFile.empty())
+  if (CLI::HasParam("training_file") && !CLI::HasParam("labels_file"))
     Log::Fatal << "If --training_file is specified, --labels_file must be "
         << "specified too!" << endl;
 
-  if (trainingFile.empty() && CLI::HasParam("batch_mode"))
+  if (!CLI::HasParam("training_file") && CLI::HasParam("batch_mode"))
     Log::Warn << "--batch_mode (-b) ignored; no training set provided." << endl;
 
   if (CLI::HasParam("passes") && CLI::HasParam("batch_mode"))
@@ -184,8 +187,10 @@ void PerformActions(const typename TreeType::NumericSplit& numericSplit)
   const string inputModelFile = CLI::GetParam<string>("input_model_file");
   const string outputModelFile = CLI::GetParam<string>("output_model_file");
   const string testFile = CLI::GetParam<string>("test_file");
-  const string predictionsFile = CLI::GetParam<string>("predictions_file");
-  const string probabilitiesFile = CLI::GetParam<string>("probabilities_file");
+  const string predictionsFile =
+      CLI::GetParam<string>("predictions_file");
+  const string probabilitiesFile =
+      CLI::GetParam<string>("probabilities_file");
   bool batchTraining = CLI::HasParam("batch_mode");
   const size_t passes = (size_t) CLI::GetParam<int>("passes");
   if (passes > 1)
@@ -193,7 +198,7 @@ void PerformActions(const typename TreeType::NumericSplit& numericSplit)
 
   TreeType* tree = NULL;
   DatasetInfo datasetInfo;
-  if (inputModelFile.empty())
+  if (!CLI::HasParam("input_model_file"))
   {
     arma::mat trainingSet;
     data::Load(trainingFile, trainingSet, datasetInfo, true);
@@ -223,7 +228,7 @@ void PerformActions(const typename TreeType::NumericSplit& numericSplit)
     tree = new TreeType(datasetInfo, 1, 1);
     data::Load(inputModelFile, "streamingDecisionTree", *tree, true);
 
-    if (!trainingFile.empty())
+    if (CLI::HasParam("training_file"))
     {
       arma::mat trainingSet;
       data::Load(trainingFile, trainingSet, datasetInfo, true);
@@ -251,7 +256,7 @@ void PerformActions(const typename TreeType::NumericSplit& numericSplit)
     }
   }
 
-  if (!trainingFile.empty())
+  if (CLI::HasParam("training_file"))
   {
     // Get training error.
     arma::mat trainingSet;
@@ -289,7 +294,7 @@ void PerformActions(const typename TreeType::NumericSplit& numericSplit)
   Log::Info << nodes << " nodes in the tree." << endl;
 
   // The tree is trained or loaded.  Now do any testing if we need.
-  if (!testFile.empty())
+  if (CLI::HasParam("test_file"))
   {
     arma::mat testSet;
     data::Load(testFile, testSet, datasetInfo, true);
@@ -319,15 +324,15 @@ void PerformActions(const typename TreeType::NumericSplit& numericSplit)
           100.0 << ")." << endl;
     }
 
-    if (!predictionsFile.empty())
+    if (CLI::HasParam("predictions_file"))
       data::Save(predictionsFile, predictions);
 
-    if (!probabilitiesFile.empty())
+    if (CLI::HasParam("probabilities_file"))
       data::Save(probabilitiesFile, probabilities);
   }
 
   // Check the accuracy on the training set.
-  if (!outputModelFile.empty())
+  if (CLI::HasParam("output_model_file"))
     data::Save(outputModelFile, "streamingDecisionTree", *tree, true);
 
   // Clean up memory.
