@@ -7,15 +7,15 @@
  * probably limited to the case where k is close to the number of points in the
  * dataset, and the number of iterations of the k-means algorithm will be few.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_KMEANS_DUAL_TREE_KMEANS_HPP
-#define __MLPACK_METHODS_KMEANS_DUAL_TREE_KMEANS_HPP
+#ifndef MLPACK_METHODS_KMEANS_DUAL_TREE_KMEANS_HPP
+#define MLPACK_METHODS_KMEANS_DUAL_TREE_KMEANS_HPP
 
 #include <mlpack/core/tree/binary_space_tree.hpp>
 #include <mlpack/methods/neighbor_search/neighbor_search.hpp>
@@ -125,7 +125,7 @@ class DualTreeKMeans
   void ExtractCentroids(Tree& node,
                         arma::mat& newCentroids,
                         arma::Col<size_t>& newCounts,
-                        arma::mat& centroids);
+                        const arma::mat& centroids);
 
   void CoalesceTree(Tree& node, const size_t child = 0);
   void DecoalesceTree(Tree& node);
