@@ -7,15 +7,15 @@
  * probably limited to the case where k is close to the number of points in the
  * dataset, and the number of iterations of the k-means algorithm will be few.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_KMEANS_DTNN_KMEANS_IMPL_HPP
-#define __MLPACK_METHODS_KMEANS_DTNN_KMEANS_IMPL_HPP
+#ifndef MLPACK_METHODS_KMEANS_DTNN_KMEANS_IMPL_HPP
+#define MLPACK_METHODS_KMEANS_DTNN_KMEANS_IMPL_HPP
 
 // In case it hasn't been included yet.
 #include "dual_tree_kmeans.hpp"
@@ -28,9 +28,9 @@ namespace kmeans {
 //! Call the tree constructor that does mapping.
 template<typename TreeType>
 TreeType* BuildTree(
-    typename TreeType::Mat& dataset,
+    const typename TreeType::Mat& dataset,
     std::vector<size_t>& oldFromNew,
-    typename boost::enable_if_c<
+    const typename boost::enable_if_c<
         tree::TreeTraits<TreeType>::RearrangesDataset == true, TreeType*
     >::type = 0)
 {
@@ -103,11 +103,10 @@ double DualTreeKMeans<MetricType, MatType, TreeType>::Iterate(
     arma::mat& newCentroids,
     arma::Col<size_t>& counts)
 {
-  // Build a tree on the centroids.
-  arma::mat oldCentroids(centroids); // Slow. :(
+  // Build a tree on the centroids.  This will make a copy if necessary, which
+  // is unfortunate, but I don't see a reasonable way around it.
   std::vector<size_t> oldFromNewCentroids;
-  Tree* centroidTree = BuildTree<Tree>(const_cast<MatType&>(centroids),
-      oldFromNewCentroids);
+  Tree* centroidTree = BuildTree<Tree>(centroids, oldFromNewCentroids);
 
   // Reset information in the tree, if we need to.
   if (iteration > 0)
@@ -141,7 +140,7 @@ double DualTreeKMeans<MetricType, MatType, TreeType>::Iterate(
 
     Timer::Stop("knn");
 
-    UpdateTree(*tree, oldCentroids);
+    UpdateTree(*tree, centroids);
 
     for (size_t i = 0; i < dataset.n_cols; ++i)
       visited[i] = false;
@@ -153,8 +152,8 @@ double DualTreeKMeans<MetricType, MatType, TreeType>::Iterate(
     interclusterDistances.set_size(1, centroids.n_cols);
   }
 
-  // We won't use the AllkNN class here because we have our own set of rules.
-  lastIterationCentroids = oldCentroids;
+  // We won't use the KNN class here because we have our own set of rules.
+  lastIterationCentroids = centroids;
   typedef DualTreeKMeansRules<MetricType, Tree> RuleType;
   RuleType rules(centroidTree->Dataset(), dataset, assignments, upperBounds,
       lowerBounds, metric, prunedPoints, oldFromNewCentroids, visited);
@@ -178,27 +177,23 @@ double DualTreeKMeans<MetricType, MatType, TreeType>::Iterate(
   // Now we need to extract the clusters.
   newCentroids.zeros(centroids.n_rows, centroids.n_cols);
   counts.zeros(centroids.n_cols);
-  ExtractCentroids(*tree, newCentroids, counts, oldCentroids);
+  ExtractCentroids(*tree, newCentroids, counts, centroids);
 
   // Now, calculate how far the clusters moved, after normalizing them.
   double residual = 0.0;
   clusterDistances[centroids.n_cols] = 0.0;
   for (size_t c = 0; c < centroids.n_cols; ++c)
   {
-    // Get the mapping to the old cluster, if necessary.
-    const size_t old = (tree::TreeTraits<Tree>::RearrangesDataset) ?
-        oldFromNewCentroids[c] : c;
-    if (counts[old] == 0)
+    if (counts[c] == 0)
     {
-      newCentroids.col(old).fill(DBL_MAX);
-      clusterDistances[old] = 0;
+      clusterDistances[c] = 0;
     }
     else
     {
-      newCentroids.col(old) /= counts(old);
+      newCentroids.col(c) /= counts(c);
       const double movement = metric.Evaluate(centroids.col(c),
-          newCentroids.col(old));
-      clusterDistances[old] = movement;
+          newCentroids.col(c));
+      clusterDistances[c] = movement;
       residual += std::pow(movement, 2.0);
 
       if (movement > clusterDistances[centroids.n_cols])
@@ -488,7 +483,7 @@ void DualTreeKMeans<MetricType, MatType, TreeType>::ExtractCentroids(
     Tree& node,
     arma::mat& newCentroids,
     arma::Col<size_t>& newCounts,
-    arma::mat& centroids)
+    const arma::mat& centroids)
 {
   // Does this node own points?
   if ((node.Stat().Pruned() == newCentroids.n_cols) ||
