@@ -6,17 +6,17 @@
  * nearest neighbor search.  For the most part we'll call out to
  * NeighborSearchRules when we can.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_KMEANS_DUAL_TREE_KMEANS_RULES_HPP
-#define __MLPACK_METHODS_KMEANS_DUAL_TREE_KMEANS_RULES_HPP
+#ifndef MLPACK_METHODS_KMEANS_DUAL_TREE_KMEANS_RULES_HPP
+#define MLPACK_METHODS_KMEANS_DUAL_TREE_KMEANS_RULES_HPP
 
-#include <mlpack/methods/neighbor_search/ns_traversal_info.hpp>
+#include <mlpack/core/tree/traversal_info.hpp>
 
 namespace mlpack {
 namespace kmeans {
@@ -46,7 +46,7 @@ class DualTreeKMeansRules
                  TreeType& referenceNode,
                  const double oldScore);
 
-  typedef neighbor::NeighborSearchTraversalInfo<TreeType> TraversalInfoType;
+  typedef typename tree::TraversalInfo<TreeType> TraversalInfoType;
 
   TraversalInfoType& TraversalInfo() { return traversalInfo; }
   const TraversalInfoType& TraversalInfo() const { return traversalInfo; }
