@@ -4,15 +4,15 @@
  *
  * An implementation of Elkan's algorithm for exact Lloyd iterations.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_KMEANS_ELKAN_KMEANS_IMPL_HPP
-#define __MLPACK_METHODS_KMEANS_ELKAN_KMEANS_IMPL_HPP
+#ifndef MLPACK_METHODS_KMEANS_ELKAN_KMEANS_IMPL_HPP
+#define MLPACK_METHODS_KMEANS_ELKAN_KMEANS_IMPL_HPP
 
 // In case it hasn't been included yet.
 #include "elkan_kmeans.hpp"
@@ -162,8 +162,6 @@ double ElkanKMeans<MetricType, MatType>::Iterate(const arma::mat& centroids,
   {
     if (counts[c] > 0)
       newCentroids.col(c) /= counts[c];
-    else
-      newCentroids.fill(DBL_MAX); // Fill with invalid value.
 
     moveDistances(c) = metric.Evaluate(newCentroids.col(c), centroids.col(c));
     cNorm += std::pow(moveDistances(c), 2.0);
