@@ -4,15 +4,15 @@
  *
  * An implementation of Greg Hamerly's algorithm for k-means clustering.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_KMEANS_HAMERLY_KMEANS_IMPL_HPP
-#define __MLPACK_METHODS_KMEANS_HAMERLY_KMEANS_IMPL_HPP
+#ifndef MLPACK_METHODS_KMEANS_HAMERLY_KMEANS_IMPL_HPP
+#define MLPACK_METHODS_KMEANS_HAMERLY_KMEANS_IMPL_HPP
 
 // In case it hasn't been included yet.
 #include "hamerly_kmeans.hpp"
@@ -139,8 +139,6 @@ double HamerlyKMeans<MetricType, MatType>::Iterate(const arma::mat& centroids,
   {
     if (counts(c) > 0)
       newCentroids.col(c) /= counts(c);
-    else
-      newCentroids.col(c).fill(DBL_MAX); // Empty cluster.
 
     // Calculate movement.
     const double movement = metric.Evaluate(centroids.col(c),
