@@ -4,20 +4,20 @@
  *
  * K-Means clustering.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_KMEANS_KMEANS_HPP
-#define __MLPACK_METHODS_KMEANS_KMEANS_HPP
+#ifndef MLPACK_METHODS_KMEANS_KMEANS_HPP
+#define MLPACK_METHODS_KMEANS_KMEANS_HPP
 
 #include <mlpack/core.hpp>
 
 #include <mlpack/core/metrics/lmetric.hpp>
-#include "random_partition.hpp"
+#include "sample_initialization.hpp"
 #include "max_variance_new_cluster.hpp"
 #include "naive_kmeans.hpp"
 
@@ -54,8 +54,9 @@ namespace kmeans /** K-Means clustering. */ {
  * @tparam MetricType The distance metric to use for this KMeans; see
  *     metric::LMetric for an example.
  * @tparam InitialPartitionPolicy Initial partitioning policy; must implement a
- *     default constructor and 'void Cluster(const arma::mat&, const size_t,
- *     arma::Row<size_t>&)'.
+ *     default constructor and either 'void Cluster(const arma::mat&, const
+ *     size_t, arma::Row<size_t>&)' or 'void Cluster(const arma::mat&, const
+ *     size_t, arma::mat&)'.
  * @tparam EmptyClusterPolicy Policy for what to do on an empty cluster; must
  *     implement a default constructor and 'void EmptyCluster(const arma::mat&
  *     data, const size_t emptyCluster, const arma::mat& oldCentroids,
@@ -63,11 +64,11 @@ namespace kmeans /** K-Means clustering. */ {
  *     const size_t iteration)'.
  * @tparam LloydStepType Implementation of single Lloyd step to use.
  *
- * @see RandomPartition, RefinedStart, AllowEmptyClusters,
+ * @see RandomPartition, SampleInitialization, RefinedStart, AllowEmptyClusters,
  *      MaxVarianceNewCluster, NaiveKMeans, ElkanKMeans
  */
 template<typename MetricType = metric::EuclideanDistance,
-         typename InitialPartitionPolicy = RandomPartition,
+         typename InitialPartitionPolicy = SampleInitialization,
          typename EmptyClusterPolicy = MaxVarianceNewCluster,
          template<class, class> class LloydStepType = NaiveKMeans,
          typename MatType = arma::mat>
@@ -198,4 +199,4 @@ class KMeans
 // Include implementation.
 #include "kmeans_impl.hpp"
 
-#endif // __MLPACK_METHODS_KMEANS_KMEANS_HPP
+#endif // MLPACK_METHODS_KMEANS_KMEANS_HPP
