@@ -5,15 +5,15 @@
  * An implementation of Pelleg-Moore's 'blacklist' algorithm for k-means
  * clustering.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_KMEANS_PELLEG_MOORE_KMEANS_IMPL_HPP
-#define __MLPACK_METHODS_KMEANS_PELLEG_MOORE_KMEANS_IMPL_HPP
+#ifndef MLPACK_METHODS_KMEANS_PELLEG_MOORE_KMEANS_IMPL_HPP
+#define MLPACK_METHODS_KMEANS_PELLEG_MOORE_KMEANS_IMPL_HPP
 
 #include "pelleg_moore_kmeans.hpp"
 #include "pelleg_moore_kmeans_rules.hpp"
@@ -68,11 +68,7 @@ double PellegMooreKMeans<MetricType, MatType>::Iterate(
   double residual = 0.0;
   for (size_t c = 0; c < centroids.n_cols; ++c)
   {
-    if (counts[c] == 0)
-    {
-      newCentroids.col(c).fill(DBL_MAX); // Should have happened anyway I think.
-    }
-    else
+    if (counts[c] > 0)
     {
       newCentroids.col(c) /= counts(c);
       residual += std::pow(metric.Evaluate(centroids.col(c),
