@@ -6,15 +6,15 @@
  * K-Means clustering".  This class is meant to provide better initial points
  * for the k-means algorithm.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_KMEANS_REFINED_START_IMPL_HPP
-#define __MLPACK_METHODS_KMEANS_REFINED_START_IMPL_HPP
+#ifndef MLPACK_METHODS_KMEANS_REFINED_START_IMPL_HPP
+#define MLPACK_METHODS_KMEANS_REFINED_START_IMPL_HPP
 
 // In case it hasn't been included yet.
 #include "refined_start.hpp"
@@ -26,10 +26,8 @@ namespace kmeans {
 template<typename MatType>
 void RefinedStart::Cluster(const MatType& data,
                            const size_t clusters,
-                           arma::Row<size_t>& assignments) const
+                           arma::mat& centroids) const
 {
-  math::RandomSeed(std::time(NULL));
-
   // This will hold the sampled datasets.
   const size_t numPoints = size_t(percentage * data.n_cols);
   MatType sampledData(data.n_rows, numPoints);
@@ -37,10 +35,6 @@ void RefinedStart::Cluster(const MatType& data,
   std::vector<bool> pointsUsed(data.n_cols, false);
   arma::mat sampledCentroids(data.n_rows, samplings * clusters);
 
-  // We will use these objects repeatedly for clustering.
-  arma::Row<size_t> sampledAssignments;
-  arma::mat centroids;
-
   for (size_t i = 0; i < samplings; ++i)
   {
     // First, assemble the sampled dataset.
@@ -64,7 +58,7 @@ void RefinedStart::Cluster(const MatType& data,
     // the cluster with maximum variance.  This is not *exactly* what the paper
     // implements, but it is quite similar, and we'll call it "good enough".
     KMeans<> kmeans;
-    kmeans.Cluster(sampledData, clusters, sampledAssignments, centroids);
+    kmeans.Cluster(sampledData, clusters, centroids);
 
     // Store the sampled centroids.
     sampledCentroids.cols(i * clusters, (i + 1) * clusters - 1) = centroids;
@@ -74,7 +68,18 @@ void RefinedStart::Cluster(const MatType& data,
 
   // Now, we run k-means on the sampled centroids to get our final clusters.
   KMeans<> kmeans;
-  kmeans.Cluster(sampledCentroids, clusters, sampledAssignments, centroids);
+  kmeans.Cluster(sampledCentroids, clusters, centroids);
+}
+
+template<typename MatType>
+void RefinedStart::Cluster(const MatType& data,
+                           const size_t clusters,
+                           arma::Row<size_t>& assignments) const
+{
+  // Perform the Bradley-Fayyad refined start algorithm, and get initial
+  // centroids back.
+  arma::mat centroids;
+  Cluster(data, clusters, centroids);
 
   // Turn the final centroids into assignments.
   assignments.set_size(data.n_cols);
@@ -86,7 +91,11 @@ void RefinedStart::Cluster(const MatType& data,
 
     for (size_t j = 0; j < clusters; ++j)
     {
-      const double distance = kmeans.Metric().Evaluate(data.col(i),
+      // This is restricted to the L2 distance, and unfortunately it would take
+      // a lot of refactoring and redesign to make this more general... we would
+      // probably need to have KMeans take a template template parameter for the
+      // initial partition policy.  It's not clear how to best do this.
+      const double distance = metric::EuclideanDistance::Evaluate(data.col(i),
           centroids.col(j));
 
       if (distance < minDistance)
