@@ -4,9 +4,9 @@
  *
  * Executable for LARS.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -58,8 +58,8 @@ PARAM_STRING("output_model_file", "File to save model to.", "M", "");
 
 PARAM_STRING("test_file", "File containing points to regress on (test points).",
     "t", "");
-PARAM_STRING("output_predictions", "If --test_file is specified, this file is "
-    "where the predicted responses will be saved.", "o", "predictions.csv");
+PARAM_STRING("output_predictions", "If --test_file is specified, this "
+    "file is where the predicted responses will be saved.", "o", "");
 
 PARAM_DOUBLE("lambda1", "Regularization parameter for l1-norm penalty.", "l",
     0);
@@ -102,12 +102,16 @@ int main(int argc, char* argv[])
 
   if (!CLI::HasParam("output_predictions") &&
       !CLI::HasParam("output_model_file"))
-    Log::Warn << "--output_predictions (-o) and --output_model_file (-M) are "
-        << "not specified; no results will be saved!" << endl;
+    Log::Warn << "--output_predictions (-o) and --output_model_file (-M) "
+        << "are not specified; no results will be saved!" << endl;
 
   if (CLI::HasParam("output_predictions") && !CLI::HasParam("test_file"))
-    Log::Warn << "--output_predictions (-o) specified, but --test_file (-t) is "
-        << "not; no results will be saved." << endl;
+    Log::Warn << "--output_predictions (-o) specified, but --test_file "
+        << "(-t) is not; no results will be saved." << endl;
+
+  if (CLI::HasParam("test_file") && !CLI::HasParam("output_predictions"))
+    Log::Warn << "--test_file (-t) specified, but --output_predictions "
+        << "(-o) is not; no results will be saved." << endl;
 
   // Initialize the object.
   LARS lars(useCholesky, lambda1, lambda2);
@@ -116,16 +120,16 @@ int main(int argc, char* argv[])
   {
     // Load covariates.  We can avoid LARS transposing our data by choosing to
     // not transpose this data.
-    const string matXFilename = CLI::GetParam<string>("input_file");
+    const string inputFile = CLI::GetParam<string>("input_file");
     mat matX;
-    data::Load(matXFilename, matX, true, false);
+    data::Load(inputFile, matX, true, false);
 
     // Load responses.  The responses should be a one-dimensional vector, and it
     // seems more likely that these will be stored with one response per line
     // (one per row).  So we should not transpose upon loading.
-    const string yFilename = CLI::GetParam<string>("responses_file");
+    const string responsesFile = CLI::GetParam<string>("responses_file");
     mat matY; // Will be a vector.
-    data::Load(yFilename, matY, true, false);
+    data::Load(responsesFile, matY, true, false);
 
     // Make sure y is oriented the right way.
     if (matY.n_rows == 1)
@@ -142,16 +146,14 @@ int main(int argc, char* argv[])
   }
   else // We must have --input_model_file.
   {
-    const string modelFile = CLI::GetParam<string>("input_model_file");
-    data::Load(modelFile, "lars_model", lars, true);
+    const string inputModelFile = CLI::GetParam<string>("input_model_file");
+    data::Load(inputModelFile, "lars_model", lars, true);
   }
 
   if (CLI::HasParam("test_file"))
   {
     Log::Info << "Regressing on test points." << endl;
     const string testFile = CLI::GetParam<string>("test_file");
-    const string outputPredictionsFile =
-        CLI::GetParam<string>("output_predictions");
 
     // Load test points.
     mat testPoints;
@@ -168,7 +170,12 @@ int main(int argc, char* argv[])
     lars.Predict(testPoints.t(), predictions, false);
 
     // Save test predictions.  One per line, so, don't transpose on save.
-    data::Save(outputPredictionsFile, predictions, true, false);
+    if (CLI::HasParam("output_predictions"))
+    {
+      const string outputPredictionsFile =
+        CLI::GetParam<string>("output_predictions");
+      data::Save(outputPredictionsFile, predictions, true, false);
+    }
   }
 
   if (CLI::HasParam("output_model_file"))
