@@ -5,9 +5,9 @@
  * This file computes the approximate nearest-neighbors using 2-stable
  * Locality-sensitive Hashing.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -72,7 +72,8 @@ PARAM_DOUBLE("hash_width", "The hash width for the first-level hashing in the "
     "hash width for its use.", "H", 0.0);
 PARAM_INT("second_hash_size", "The size of the second level hash table.", "S",
     99901);
-PARAM_INT("bucket_size", "The size of a bucket in the second level hash.", "B",
+PARAM_INT("bucket_size", "The maximum size of a bucket in the second level "
+    "hash; 0 indicates no limit (so the table can be arbitrarily large!).", "B",
     500);
 PARAM_INT("seed", "Random seed.  If 0, 'std::time(NULL)' is used.", "s", 0);
 
@@ -119,10 +120,11 @@ int main(int argc, char *argv[])
   }
 
   if ((CLI::HasParam("query_file") && !CLI::HasParam("k")) ||
-      (!CLI::HasParam("query_file") && CLI::HasParam("k")))
+      (!CLI::HasParam("query_file") && !CLI::HasParam("reference_file") &&
+       CLI::HasParam("k")))
   {
-    Log::Fatal << "Both --query_file and --k must be specified if search is to "
-        << "be done!" << endl;
+    Log::Fatal << "Both --query_file or --reference_file and --k must be "
+        << "specified if search is to be done!" << endl;
   }
 
   if (CLI::HasParam("input_model_file") && CLI::HasParam("k") &&
