@@ -4,22 +4,22 @@
  *
  * Implementation of the LSHSearch class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_NEIGHBOR_SEARCH_LSH_SEARCH_IMPL_HPP
-#define __MLPACK_METHODS_NEIGHBOR_SEARCH_LSH_SEARCH_IMPL_HPP
+#ifndef MLPACK_METHODS_NEIGHBOR_SEARCH_LSH_SEARCH_IMPL_HPP
+#define MLPACK_METHODS_NEIGHBOR_SEARCH_LSH_SEARCH_IMPL_HPP
 
 #include <mlpack/core.hpp>
 
 namespace mlpack {
 namespace neighbor {
 
-// Construct the object.
+// Construct the object with random tables
 template<typename SortPolicy>
 LSHSearch<SortPolicy>::
 LSHSearch(const arma::mat& referenceSet,
@@ -42,10 +42,32 @@ LSHSearch(const arma::mat& referenceSet,
       bucketSize);
 }
 
+// Construct the object with given tables
+template<typename SortPolicy>
+LSHSearch<SortPolicy>::
+LSHSearch(const arma::mat& referenceSet,
+          const arma::cube& projections,
+          const double hashWidthIn,
+          const size_t secondHashSize,
+          const size_t bucketSize) :
+  referenceSet(NULL), // This will be set in Train().
+  ownsSet(false),
+  numProj(projections.n_cols),
+  numTables(projections.n_slices),
+  hashWidth(hashWidthIn),
+  secondHashSize(secondHashSize),
+  bucketSize(bucketSize),
+  distanceEvaluations(0)
+{
+  // Pass work to training function
+  Train(referenceSet, numProj, numTables, hashWidthIn, secondHashSize,
+      bucketSize, projections);
+}
+
 // Empty constructor.
 template<typename SortPolicy>
 LSHSearch<SortPolicy>::LSHSearch() :
-    referenceSet(new arma::mat()), // empty dataset
+    referenceSet(new arma::mat()), // Use an empty dataset.
     ownsSet(true),
     numProj(0),
     numTables(0),
@@ -72,7 +94,8 @@ void LSHSearch<SortPolicy>::Train(const arma::mat& referenceSet,
                                   const size_t numTables,
                                   const double hashWidthIn,
                                   const size_t secondHashSize,
-                                  const size_t bucketSize)
+                                  const size_t bucketSize,
+                                  const arma::cube &projection)
 {
   // Set new reference set.
   if (this->referenceSet && ownsSet)
@@ -104,7 +127,134 @@ void LSHSearch<SortPolicy>::Train(const arma::mat& referenceSet,
 
   Log::Info << "Hash width chosen as: " << hashWidth << std::endl;
 
-  BuildHash();
+  // Hash building procedure:
+  // The first level hash for a single table outputs a 'numProj'-dimensional
+  // integer key for each point in the set -- (key, pointID).  The key creation
+  // details are presented below.
+
+  // Step I: Prepare the second level hash.
+
+  // Obtain the weights for the second hash.
+  secondHashWeights = arma::floor(arma::randu(numProj) *
+                                  (double) secondHashSize);
+
+  // Instead of putting the points in the row corresponding to the bucket, we
+  // chose the next empty row and keep track of the row in which the bucket
+  // lies. This allows us to stack together and slice out the empty buckets at
+  // the end of the hashing.
+  bucketRowInHashTable.set_size(secondHashSize);
+  bucketRowInHashTable.fill(secondHashSize);
+
+  // Step II: The offsets for all projections in all tables.
+  // Since the 'offsets' are in [0, hashWidth], we obtain the 'offsets'
+  // as randu(numProj, numTables) * hashWidth.
+  offsets.randu(numProj, numTables);
+  offsets *= hashWidth;
+
+  // Step III: Obtain the 'numProj' projections for each table.
+  projections.clear(); // Reset projections vector.
+
+  if (projection.n_slices == 0) // Randomly generate the tables.
+  {
+    // For L2 metric, 2-stable distributions are used, and the normal Z ~ N(0,
+    // 1) is a 2-stable distribution.
+
+    // Build numTables random tables arranged in a cube.
+    projections.randn(referenceSet.n_rows, numProj, numTables);
+  }
+  else if (projection.n_slices == numTables) // Take user-defined tables.
+  {
+    projections = projection;
+  }
+  else // The user gave something wrong.
+  {
+    throw std::invalid_argument("LSHSearch::Train(): number of projection "
+        "tables provided must be equal to numProj");
+  }
+
+  // We will store the second hash vectors in this matrix; the second hash
+  // vector for table i will be held in row i.
+  arma::Mat<size_t> secondHashVectors(numTables, referenceSet.n_cols);
+
+  for (size_t i = 0; i < numTables; i++)
+  {
+    // Step IV: create the 'numProj'-dimensional key for each point in each
+    // table.
+
+    // The following code performs the task of hashing each point to a
+    // 'numProj'-dimensional integer key.  Hence you get a ('numProj' x
+    // 'referenceSet.n_cols') key matrix.
+    //
+    // For a single table, let the 'numProj' projections be denoted by 'proj_i'
+    // and the corresponding offset be 'offset_i'.  Then the key of a single
+    // point is obtained as:
+    // key = { floor( (<proj_i, point> + offset_i) / 'hashWidth' ) forall i }
+    arma::mat offsetMat = arma::repmat(offsets.unsafe_col(i), 1,
+                                       referenceSet.n_cols);
+    arma::mat hashMat = projections.slice(i).t() * (referenceSet);
+    hashMat += offsetMat;
+    hashMat /= hashWidth;
+
+    // Step V: Putting the points in the 'secondHashTable' by hashing the key.
+    // Now we hash every key, point ID to its corresponding bucket.
+    secondHashVectors.row(i) = arma::conv_to<arma::Row<size_t>>::from(
+        secondHashWeights.t() * arma::floor(hashMat));
+  }
+
+  // Normalize hashes (take modulus with secondHashSize).
+  secondHashVectors.transform([secondHashSize](size_t val)
+      { return val % secondHashSize; });
+
+  // Now, using the hash vectors for each table, count the number of rows we
+  // have in the second hash table.
+  arma::Row<size_t> secondHashBinCounts(secondHashSize, arma::fill::zeros);
+  for (size_t i = 0; i < secondHashVectors.n_elem; ++i)
+    secondHashBinCounts[secondHashVectors[i]]++;
+
+  // Enforce the maximum bucket size.
+  const size_t effectiveBucketSize = (bucketSize == 0) ? SIZE_MAX : bucketSize;
+  secondHashBinCounts.transform([effectiveBucketSize](size_t val)
+      { return std::min(val, effectiveBucketSize); });
+
+  const size_t numRowsInTable = arma::accu(secondHashBinCounts > 0);
+  bucketContentSize.zeros(numRowsInTable);
+  secondHashTable.resize(numRowsInTable);
+
+  // Next we must assign each point in each table to the right second hash
+  // table.
+  size_t currentRow = 0;
+  for (size_t i = 0; i < numTables; ++i)
+  {
+    // Insert the point in the corresponding row to its bucket in the
+    // 'secondHashTable'.
+    for (size_t j = 0; j < secondHashVectors.n_cols; j++)
+    {
+      // This is the bucket number.
+      size_t hashInd = (size_t) secondHashVectors(i, j);
+      // The point ID is 'j'.
+
+      // If this is currently an empty bucket, start a new row keep track of
+      // which row corresponds to the bucket.
+      const size_t maxSize = secondHashBinCounts[hashInd];
+      if (bucketRowInHashTable[hashInd] == secondHashSize)
+      {
+        bucketRowInHashTable[hashInd] = currentRow;
+        secondHashTable[currentRow].set_size(maxSize);
+        currentRow++;
+      }
+
+      // If this vector in the hash table is not full, add the point.
+      const size_t index = bucketRowInHashTable[hashInd];
+      if (bucketContentSize[index] < maxSize)
+        secondHashTable[index](bucketContentSize[index]++) = j;
+
+    } // Loop over all points in the reference set.
+  } // Loop over tables.
+
+  Log::Info << "Final hash table size: " << numRowsInTable << " rows, with a "
+            << "maximum length of " << arma::max(secondHashBinCounts) << ", "
+            << "totaling " << arma::accu(secondHashBinCounts) << " elements."
+            << std::endl;
 }
 
 template<typename SortPolicy>
@@ -212,7 +362,8 @@ void LSHSearch<SortPolicy>::ReturnIndicesFromTable(
   // Compute the projection of the query in each table.
   arma::mat allProjInTables(numProj, numTablesToSearch);
   for (size_t i = 0; i < numTablesToSearch; i++)
-    allProjInTables.unsafe_col(i) = projections[i].t() * queryPoint;
+    //allProjInTables.unsafe_col(i) = projections[i].t() * queryPoint;
+    allProjInTables.unsafe_col(i) = projections.slice(i).t() * queryPoint;
   allProjInTables += offsets.cols(0, numTablesToSearch - 1);
   allProjInTables /= hashWidth;
 
@@ -225,28 +376,75 @@ void LSHSearch<SortPolicy>::ReturnIndicesFromTable(
 
   Log::Assert(hashVec.n_elem == numTablesToSearch);
 
-  // For all the buckets that the query is hashed into, sequentially
-  // collect the indices in those buckets.
-  arma::Col<size_t> refPointsConsidered;
-  refPointsConsidered.zeros(referenceSet->n_cols);
-
-  for (size_t i = 0; i < hashVec.n_elem; i++) // For all tables.
+  // Count number of points hashed in the same bucket as the query.
+  size_t maxNumPoints = 0;
+  for (size_t i = 0; i < numTablesToSearch; ++i)
   {
-    size_t hashInd = (size_t) hashVec[i];
-
-    if (bucketContentSize[hashInd] > 0)
-    {
-      // Pick the indices in the bucket corresponding to 'hashInd'.
-      size_t tableRow = bucketRowInHashTable[hashInd];
-      assert(tableRow < secondHashSize);
-      assert(tableRow < secondHashTable.n_rows);
-
-      for (size_t j = 0; j < bucketContentSize[hashInd]; j++)
-        refPointsConsidered[secondHashTable(tableRow, j)]++;
-    }
+    const size_t hashInd = (size_t) hashVec[i];
+    const size_t tableRow = bucketRowInHashTable[hashInd];
+    if (tableRow != secondHashSize)
+      maxNumPoints += bucketContentSize[tableRow];
   }
 
-  referenceIndices = arma::find(refPointsConsidered > 0);
+  // There are two ways to proceed here:
+  // Either allocate a maxNumPoints-size vector, place all candidates, and run
+  // unique on the vector to discard duplicates.
+  // Or allocate a referenceSet->n_cols size vector (i.e. number of reference
+  // points) of zeros, and mark found indices as 1.
+  // Option 1 runs faster for small maxNumPoints but worse for larger values, so
+  // we choose based on a heuristic.
+  const float cutoff = 0.1;
+  const float selectivity = static_cast<float>(maxNumPoints) /
+      static_cast<float>(referenceSet->n_cols);
+
+  if (selectivity > cutoff)
+  {
+    // Heuristic: larger maxNumPoints means we should use find() because it
+    // should be faster.
+    // Reference points hashed in the same bucket as the query are set to >0.
+    arma::Col<size_t> refPointsConsidered;
+    refPointsConsidered.zeros(referenceSet->n_cols);
+
+    for (size_t i = 0; i < hashVec.n_elem; ++i)
+    {
+      const size_t hashInd = (size_t) hashVec[i];
+      const size_t tableRow = bucketRowInHashTable[hashInd];
+
+      // Pick the indices in the bucket corresponding to 'hashInd'.
+      if (tableRow != secondHashSize)
+        for (size_t j = 0; j < bucketContentSize[tableRow]; j++)
+          refPointsConsidered[secondHashTable[tableRow](j)]++;
+    }
+
+    // Only keep reference points found in at least one bucket.
+    referenceIndices = arma::find(refPointsConsidered > 0);
+    return;
+  }
+  else
+  {
+    // Heuristic: smaller maxNumPoints means we should use unique() because it
+    // should be faster.
+    // Allocate space for the query's potential neighbors.
+    arma::uvec refPointsConsideredSmall;
+    refPointsConsideredSmall.zeros(maxNumPoints);
+
+    // Retrieve candidates.
+    size_t start = 0;
+    for (size_t i = 0; i < numTablesToSearch; ++i) // For all tables
+    {
+      const size_t hashInd = (size_t) hashVec[i]; // Find the query's bucket.
+      const size_t tableRow = bucketRowInHashTable[hashInd];
+
+      // Store all secondHashTable points in the candidates set.
+      if (tableRow != secondHashSize)
+        for (size_t j = 0; j < bucketContentSize[tableRow]; ++j)
+          refPointsConsideredSmall(start++) = secondHashTable[tableRow][j];
+    }
+
+    // Only keep unique candidates.
+    referenceIndices = arma::unique(refPointsConsideredSmall);
+    return;
+  }
 }
 
 // Search for nearest neighbors in a given query set.
@@ -361,153 +559,10 @@ Search(const size_t k,
       std::endl;
 }
 
-template<typename SortPolicy>
-void LSHSearch<SortPolicy>::BuildHash()
-{
-  // The first level hash for a single table outputs a 'numProj'-dimensional
-  // integer key for each point in the set -- (key, pointID)
-  // The key creation details are presented below
-  //
-  // The second level hash is performed by hashing the key to
-  // an integer in the range [0, 'secondHashSize').
-  //
-  // This is done by creating a weight vector 'secondHashWeights' of
-  // length 'numProj' with each entry an integer randomly chosen
-  // between [0, 'secondHashSize').
-  //
-  // Then the bucket for any key and its corresponding point is
-  // given by <key, 'secondHashWeights'> % 'secondHashSize'
-  // and the corresponding point ID is put into that bucket.
-
-  // Step I: Prepare the second level hash.
-
-  // Obtain the weights for the second hash.
-  secondHashWeights = arma::floor(arma::randu(numProj) *
-                                  (double) secondHashSize);
-
-  // The 'secondHashTable' is initially an empty matrix of size
-  // ('secondHashSize' x 'bucketSize'). But by only filling the buckets
-  // as points land in them allows us to shrink the size of the
-  // 'secondHashTable' at the end of the hashing.
-
-  // Fill the second hash table n = referenceSet.n_cols.  This is because no
-  // point has index 'n' so the presence of this in the bucket denotes that
-  // there are no more points in this bucket.
-  secondHashTable.set_size(secondHashSize, bucketSize);
-  secondHashTable.fill(referenceSet->n_cols);
-
-  // Keep track of the size of each bucket in the hash.  At the end of hashing
-  // most buckets will be empty.
-  bucketContentSize.zeros(secondHashSize);
-
-  // Instead of putting the points in the row corresponding to the bucket, we
-  // chose the next empty row and keep track of the row in which the bucket
-  // lies. This allows us to stack together and slice out the empty buckets at
-  // the end of the hashing.
-  bucketRowInHashTable.set_size(secondHashSize);
-  bucketRowInHashTable.fill(secondHashSize);
-
-  // Keep track of number of non-empty rows in the 'secondHashTable'.
-  size_t numRowsInTable = 0;
-
-  // Step II: The offsets for all projections in all tables.
-  // Since the 'offsets' are in [0, hashWidth], we obtain the 'offsets'
-  // as randu(numProj, numTables) * hashWidth.
-  offsets.randu(numProj, numTables);
-  offsets *= hashWidth;
-
-  // Step III: Create each hash table in the first level hash one by one and
-  // putting them directly into the 'secondHashTable' for memory efficiency.
-  projections.clear(); // Reset projections vector.
-  for (size_t i = 0; i < numTables; i++)
-  {
-    // Step IV: Obtain the 'numProj' projections for each table.
-
-    // For L2 metric, 2-stable distributions are used, and
-    // the normal Z ~ N(0, 1) is a 2-stable distribution.
-    arma::mat projMat;
-    projMat.randn(referenceSet->n_rows, numProj);
-
-    // Save the projection matrix for querying.
-    projections.push_back(projMat);
-
-    // Step V: create the 'numProj'-dimensional key for each point in each
-    // table.
-
-    // The following code performs the task of hashing each point to a
-    // 'numProj'-dimensional integer key.  Hence you get a ('numProj' x
-    // 'referenceSet.n_cols') key matrix.
-    //
-    // For a single table, let the 'numProj' projections be denoted by 'proj_i'
-    // and the corresponding offset be 'offset_i'.  Then the key of a single
-    // point is obtained as:
-    // key = { floor( (<proj_i, point> + offset_i) / 'hashWidth' ) forall i }
-    arma::mat offsetMat = arma::repmat(offsets.unsafe_col(i), 1,
-                                       referenceSet->n_cols);
-    arma::mat hashMat = projMat.t() * (*referenceSet);
-    hashMat += offsetMat;
-    hashMat /= hashWidth;
-
-    // Step VI: Putting the points in the 'secondHashTable' by hashing the key.
-    // Now we hash every key, point ID to its corresponding bucket.
-    arma::rowvec secondHashVec = secondHashWeights.t() * arma::floor(hashMat);
-
-    // This gives us the bucket for the corresponding point ID.
-    for (size_t j = 0; j < secondHashVec.n_elem; j++)
-      secondHashVec[j] = (double)((size_t) secondHashVec[j] % secondHashSize);
-
-    Log::Assert(secondHashVec.n_elem == referenceSet->n_cols);
-
-    // Insert the point in the corresponding row to its bucket in the
-    // 'secondHashTable'.
-    for (size_t j = 0; j < secondHashVec.n_elem; j++)
-    {
-      // This is the bucket number.
-      size_t hashInd = (size_t) secondHashVec[j];
-      // The point ID is 'j'.
-
-      // If this is currently an empty bucket, start a new row keep track of
-      // which row corresponds to the bucket.
-      if (bucketContentSize[hashInd] == 0)
-      {
-        // Start a new row for hash.
-        bucketRowInHashTable[hashInd] = numRowsInTable;
-        secondHashTable(numRowsInTable, 0) = j;
-
-        numRowsInTable++;
-      }
-
-      else
-      {
-        // If bucket is already present in the 'secondHashTable', find the
-        // corresponding row and insert the point ID in this row unless the
-        // bucket is full, in which case, do nothing.
-        if (bucketContentSize[hashInd] < bucketSize)
-          secondHashTable(bucketRowInHashTable[hashInd],
-                          bucketContentSize[hashInd]) = j;
-      }
-
-      // Increment the count of the points in this bucket.
-      if (bucketContentSize[hashInd] < bucketSize)
-        bucketContentSize[hashInd]++;
-    } // Loop over all points in the reference set.
-  } // Loop over tables.
-
-  // Step VII: Condensing the 'secondHashTable'.
-  size_t maxBucketSize = 0;
-  for (size_t i = 0; i < bucketContentSize.n_elem; i++)
-    if (bucketContentSize[i] > maxBucketSize)
-      maxBucketSize = bucketContentSize[i];
-
-  Log::Info << "Final hash table size: (" << numRowsInTable << " x "
-            << maxBucketSize << ")" << std::endl;
-  secondHashTable.resize(numRowsInTable, maxBucketSize);
-}
-
 template<typename SortPolicy>
 template<typename Archive>
 void LSHSearch<SortPolicy>::Serialize(Archive& ar,
-                                      const unsigned int /* version */)
+                                      const unsigned int version)
 {
   using data::CreateNVP;
 
@@ -525,17 +580,106 @@ void LSHSearch<SortPolicy>::Serialize(Archive& ar,
 
   // Delete existing projections, if necessary.
   if (Archive::is_loading::value)
-    projections.clear();
+    projections.reset();
+
+  // Backward compatibility: older versions of LSHSearch stored the projection
+  // tables in a std::vector<arma::mat>.
+  if (version == 0)
+  {
+    std::vector<arma::mat> tmpProj;
+    ar & CreateNVP(tmpProj, "projections");
+
+    projections.set_size(tmpProj[0].n_rows, tmpProj[0].n_cols, tmpProj.size());
+    for (size_t i = 0; i < tmpProj.size(); ++i)
+      projections.slice(i) = tmpProj[i];
+  }
+  else
+  {
+    ar & CreateNVP(projections, "projections");
+  }
 
-  ar & CreateNVP(projections, "projections");
   ar & CreateNVP(offsets, "offsets");
   ar & CreateNVP(hashWidth, "hashWidth");
   ar & CreateNVP(secondHashSize, "secondHashSize");
   ar & CreateNVP(secondHashWeights, "secondHashWeights");
   ar & CreateNVP(bucketSize, "bucketSize");
-  ar & CreateNVP(secondHashTable, "secondHashTable");
-  ar & CreateNVP(bucketContentSize, "bucketContentSize");
-  ar & CreateNVP(bucketRowInHashTable, "bucketRowInHashTable");
+  // needs specific handling for new version
+
+  // Backward compatibility: in older versions of LSHSearch, the secondHashTable
+  // was stored as an arma::Mat<size_t>.  So we need to properly load that, then
+  // prune it down to size.
+  if (version == 0)
+  {
+    arma::Mat<size_t> tmpSecondHashTable;
+    ar & CreateNVP(tmpSecondHashTable, "secondHashTable");
+
+    // The old secondHashTable was stored in row-major format, so we transpose
+    // it.
+    tmpSecondHashTable = tmpSecondHashTable.t();
+
+    secondHashTable.resize(tmpSecondHashTable.n_cols);
+    for (size_t i = 0; i < tmpSecondHashTable.n_cols; ++i)
+    {
+      // Find length of each column.  We know we are at the end of the list when
+      // the value referenceSet->n_cols is seen.
+
+      size_t len = 0;
+      for ( ; len < tmpSecondHashTable.n_rows; ++len)
+        if (tmpSecondHashTable(len, i) == referenceSet->n_cols)
+          break;
+
+      // Set the size of the new column correctly.
+      secondHashTable[i].set_size(len);
+      for (size_t j = 0; j < len; ++j)
+        secondHashTable[i](j) = tmpSecondHashTable(j, i);
+    }
+  }
+  else
+  {
+    size_t tables;
+    if (Archive::is_saving::value)
+      tables = secondHashTable.size();
+    ar & CreateNVP(tables, "numSecondHashTables");
+
+    // Set size of second hash table if needed.
+    if (Archive::is_loading::value)
+    {
+      secondHashTable.clear();
+      secondHashTable.resize(tables);
+    }
+
+    for (size_t i = 0; i < secondHashTable.size(); ++i)
+    {
+      std::ostringstream oss;
+      oss << "secondHashTable" << i;
+      ar & CreateNVP(secondHashTable[i], oss.str());
+    }
+  }
+
+  // Backward compatibility: old versions of LSHSearch held bucketContentSize
+  // for all possible buckets (of size secondHashSize), but now we hold a
+  // compressed representation.
+  if (version == 0)
+  {
+    // The vector was stored in the old uncompressed form.  So we need to shrink
+    // it.  But we can't do that until we have bucketRowInHashTable, so we also
+    // have to load that.
+    arma::Col<size_t> tmpBucketContentSize;
+    ar & CreateNVP(tmpBucketContentSize, "bucketContentSize");
+    ar & CreateNVP(bucketRowInHashTable, "bucketRowInHashTable");
+
+    // Compress into a smaller vector by just dropping all of the zeros.
+    bucketContentSize.set_size(secondHashTable.size());
+    for (size_t i = 0; i < tmpBucketContentSize.n_elem; ++i)
+      if (tmpBucketContentSize[i] > 0)
+        bucketContentSize[bucketRowInHashTable[i]] = tmpBucketContentSize[i];
+  }
+  else
+  {
+    ar & CreateNVP(bucketContentSize, "bucketContentSize");
+    ar & CreateNVP(bucketRowInHashTable, "bucketRowInHashTable");
+  }
+
   ar & CreateNVP(distanceEvaluations, "distanceEvaluations");
 }
 
