@@ -4,16 +4,16 @@
  *
  * Mean Shift clustering
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 
-#ifndef __MLPACK_METHODS_MEAN_SHIFT_MEAN_SHIFT_HPP
-#define __MLPACK_METHODS_MEAN_SHIFT_MEAN_SHIFT_HPP
+#ifndef MLPACK_METHODS_MEAN_SHIFT_MEAN_SHIFT_HPP
+#define MLPACK_METHODS_MEAN_SHIFT_MEAN_SHIFT_HPP
 
 #include <mlpack/core.hpp>
 #include <mlpack/core/kernels/gaussian_kernel.hpp>
@@ -172,4 +172,4 @@ class MeanShift
 // Include implementation.
 #include "mean_shift_impl.hpp"
 
-#endif // __MLPACK_METHODS_MEAN_SHIFT_MEAN_SHIFT_HPP
+#endif // MLPACK_METHODS_MEAN_SHIFT_MEAN_SHIFT_HPP
