@@ -4,23 +4,15 @@
  *
  * Implementation of NearestNeighborRules.
  *
- * This file is part of mlpack 2.0.0.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software: you can redistribute it and/or modify it under the
- * terms of the GNU Lesser General Public License as published by the Free
- * Software Foundation, either version 3 of the License, or (at your option) any
- * later version.
- *
- * mlpack is distributed in the hope that it will be useful, but WITHOUT ANY
- * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
- * A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
- * details (LICENSE.txt).
- *
- * You should have received a copy of the GNU General Public License along with
- * mlpack.  If not, see <http://www.gnu.org/licenses/>.
+ * mlpack is free software; you may redistribute it and/or modify it under the
+ * terms of the 3-clause BSD license.  You should have received a copy of the
+ * 3-clause BSD license along with mlpack.  If not, see
+ * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_NEIGHBOR_SEARCH_NEAREST_NEIGHBOR_RULES_IMPL_HPP
-#define __MLPACK_METHODS_NEIGHBOR_SEARCH_NEAREST_NEIGHBOR_RULES_IMPL_HPP
+#ifndef MLPACK_METHODS_NEIGHBOR_SEARCH_NEAREST_NEIGHBOR_RULES_IMPL_HPP
+#define MLPACK_METHODS_NEIGHBOR_SEARCH_NEAREST_NEIGHBOR_RULES_IMPL_HPP
 
 // In case it hasn't been included yet.
 #include "neighbor_search_rules.hpp"
@@ -192,7 +184,7 @@ inline double NeighborSearchRules<SortPolicy, MetricType, TreeType>::Score(
     const double lastRefDescDist =
         traversalInfo.LastReferenceNode()->MinimumBoundDistance();
     adjustedScore = SortPolicy::CombineWorst(score, lastQueryDescDist);
-    adjustedScore = SortPolicy::CombineWorst(score, lastRefDescDist);
+    adjustedScore = SortPolicy::CombineWorst(adjustedScore, lastRefDescDist);
   }
 
   // Assemble an adjusted score.  For nearest neighbor search, this adjusted
@@ -246,7 +238,7 @@ inline double NeighborSearchRules<SortPolicy, MetricType, TreeType>::Score(
   }
 
   // Can we prune?
-  if (SortPolicy::IsBetter(bestDistance, adjustedScore))
+  if (!SortPolicy::IsBetter(adjustedScore, bestDistance))
   {
     if (!(tree::TreeTraits<TreeType>::FirstPointIsCentroid && score == 0.0))
     {
@@ -359,6 +351,8 @@ inline double NeighborSearchRules<SortPolicy, MetricType, TreeType>::
 
   double worstDistance = SortPolicy::BestDistance();
   double bestDistance = SortPolicy::WorstDistance();
+  double bestPointDistance = SortPolicy::WorstDistance();
+  double auxDistance = SortPolicy::WorstDistance();
 
   // Loop over points held in the node.
   for (size_t i = 0; i < queryNode.NumPoints(); ++i)
@@ -366,33 +360,43 @@ inline double NeighborSearchRules<SortPolicy, MetricType, TreeType>::
     const double distance = distances(distances.n_rows - 1, queryNode.Point(i));
     if (SortPolicy::IsBetter(worstDistance, distance))
       worstDistance = distance;
-    if (SortPolicy::IsBetter(distance, bestDistance))
-      bestDistance = distance;
+    if (SortPolicy::IsBetter(distance, bestPointDistance))
+      bestPointDistance = distance;
   }
 
-  // Add triangle inequality adjustment to best distance.  It is possible this
-  // could be tighter for some certain types of trees.
-  bestDistance = SortPolicy::CombineWorst(bestDistance,
-      queryNode.FurthestPointDistance() +
-      queryNode.FurthestDescendantDistance());
+  auxDistance = bestPointDistance;
 
   // Loop over children of the node, and use their cached information to
   // assemble bounds.
   for (size_t i = 0; i < queryNode.NumChildren(); ++i)
   {
     const double firstBound = queryNode.Child(i).Stat().FirstBound();
-    const double adjustment = std::max(0.0,
-        queryNode.FurthestDescendantDistance() -
-        queryNode.Child(i).FurthestDescendantDistance());
-    const double adjustedSecondBound = SortPolicy::CombineWorst(
-        queryNode.Child(i).Stat().SecondBound(), 2 * adjustment);
+    const double auxBound = queryNode.Child(i).Stat().AuxBound();
 
     if (SortPolicy::IsBetter(worstDistance, firstBound))
       worstDistance = firstBound;
-    if (SortPolicy::IsBetter(adjustedSecondBound, bestDistance))
-      bestDistance = adjustedSecondBound;
+    if (SortPolicy::IsBetter(auxBound, auxDistance))
+      auxDistance = auxBound;
   }
 
+  // Add triangle inequality adjustment to best distance.  It is possible this
+  // could be tighter for some certain types of trees.
+  bestDistance = SortPolicy::CombineWorst(auxDistance,
+      2 * queryNode.FurthestDescendantDistance());
+
+  // Add triangle inequality adjustment to best distance of points in node.
+  bestPointDistance = SortPolicy::CombineWorst(bestPointDistance,
+      queryNode.FurthestPointDistance() +
+      queryNode.FurthestDescendantDistance());
+
+  if (SortPolicy::IsBetter(bestPointDistance, bestDistance))
+    bestDistance = bestPointDistance;
+
+  // At this point:
+  // worstDistance holds the value of B_1(N_q).
+  // bestDistance holds the value of B_2(N_q).
+  // auxDistance holds the value of B_aux(N_q).
+
   // Now consider the parent bounds.
   if (queryNode.Parent() != NULL)
   {
@@ -420,6 +424,7 @@ inline double NeighborSearchRules<SortPolicy, MetricType, TreeType>::
   // Cache bounds for later.
   queryNode.Stat().FirstBound() = worstDistance;
   queryNode.Stat().SecondBound() = bestDistance;
+  queryNode.Stat().AuxBound() = auxDistance;
 
   if (SortPolicy::IsBetter(worstDistance, bestDistance))
     return worstDistance;
@@ -462,4 +467,4 @@ void NeighborSearchRules<SortPolicy, MetricType, TreeType>::InsertNeighbor(
 } // namespace neighbor
 } // namespace mlpack
 
-#endif // __MLPACK_METHODS_NEIGHBOR_SEARCH_NEAREST_NEIGHBOR_RULES_IMPL_HPP
+#endif // MLPACK_METHODS_NEIGHBOR_SEARCH_NEAREST_NEIGHBOR_RULES_IMPL_HPP
