@@ -5,15 +5,15 @@
  * Defines the NeighborSearch class, which performs an abstract
  * nearest-neighbor-like query on two datasets.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_NEIGHBOR_SEARCH_NEIGHBOR_SEARCH_STAT_HPP
-#define __MLPACK_METHODS_NEIGHBOR_SEARCH_NEIGHBOR_SEARCH_STAT_HPP
+#ifndef MLPACK_METHODS_NEIGHBOR_SEARCH_NEIGHBOR_SEARCH_STAT_HPP
+#define MLPACK_METHODS_NEIGHBOR_SEARCH_NEIGHBOR_SEARCH_STAT_HPP
 
 #include <mlpack/core.hpp>
 
@@ -36,11 +36,9 @@ class NeighborSearchStat
   //! using the best descendant candidate distance modified by the furthest
   //! descendant distance.
   double secondBound;
-  //! The better of the two bounds.
-  double bound;
-
-  //! The last distance evaluation node.
-  void* lastDistanceNode;
+  //! The aux bound on the node's neighbor distances (B_aux). This represents
+  //! the best descendant candidate distance (used to calculate secondBound).
+  double auxBound;
   //! The last distance evaluation.
   double lastDistance;
 
@@ -52,7 +50,7 @@ class NeighborSearchStat
   NeighborSearchStat() :
       firstBound(SortPolicy::WorstDistance()),
       secondBound(SortPolicy::WorstDistance()),
-      bound(SortPolicy::WorstDistance()),
+      auxBound(SortPolicy::WorstDistance()),
       lastDistance(0.0) { }
 
   /**
@@ -63,9 +61,20 @@ class NeighborSearchStat
   NeighborSearchStat(TreeType& /* node */) :
       firstBound(SortPolicy::WorstDistance()),
       secondBound(SortPolicy::WorstDistance()),
-      bound(SortPolicy::WorstDistance()),
+      auxBound(SortPolicy::WorstDistance()),
       lastDistance(0.0) { }
 
+  /**
+   * Reset statistic parameters to initial values.
+   */
+  void Reset()
+  {
+    firstBound = SortPolicy::WorstDistance();
+    secondBound = SortPolicy::WorstDistance();
+    auxBound = SortPolicy::WorstDistance();
+    lastDistance = 0.0;
+  }
+
   //! Get the first bound.
   double FirstBound() const { return firstBound; }
   //! Modify the first bound.
@@ -74,10 +83,10 @@ class NeighborSearchStat
   double SecondBound() const { return secondBound; }
   //! Modify the second bound.
   double& SecondBound() { return secondBound; }
-  //! Get the overall bound (the better of the two bounds).
-  double Bound() const { return bound; }
-  //! Modify the overall bound (it should be the better of the two bounds).
-  double& Bound() { return bound; }
+  //! Get the aux bound.
+  double AuxBound() const { return auxBound; }
+  //! Modify the aux bound.
+  double& AuxBound() { return auxBound; }
   //! Get the last distance calculation.
   double LastDistance() const { return lastDistance; }
   //! Modify the last distance calculation.
@@ -91,7 +100,7 @@ class NeighborSearchStat
 
     ar & CreateNVP(firstBound, "firstBound");
     ar & CreateNVP(secondBound, "secondBound");
-    ar & CreateNVP(bound, "bound");
+    ar & CreateNVP(auxBound, "auxBound");
     ar & CreateNVP(lastDistance, "lastDistance");
   }
 };
