@@ -7,15 +7,15 @@
  * different types of trees, and also reflects the NeighborSearch API and
  * automatically directs to the right tree type.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_NEIGHBOR_SEARCH_NS_MODEL_HPP
-#define __MLPACK_METHODS_NEIGHBOR_SEARCH_NS_MODEL_HPP
+#ifndef MLPACK_METHODS_NEIGHBOR_SEARCH_NS_MODEL_HPP
+#define MLPACK_METHODS_NEIGHBOR_SEARCH_NS_MODEL_HPP
 
 #include <mlpack/core/tree/binary_space_tree.hpp>
 #include <mlpack/core/tree/cover_tree.hpp>
@@ -54,11 +54,12 @@ class NSModel
     COVER_TREE,
     R_TREE,
     R_STAR_TREE,
-    BALL_TREE
+    BALL_TREE,
+    X_TREE
   };
 
  private:
-  int treeType;
+  TreeTypes treeType;
   size_t leafSize;
 
   // For random projections.
@@ -82,13 +83,14 @@ class NSModel
   NSType<tree::RTree>* rTreeNS;
   NSType<tree::RStarTree>* rStarTreeNS;
   NSType<tree::BallTree>* ballTreeNS;
+  NSType<tree::XTree>* xTreeNS;
 
  public:
   /**
    * Initialize the NSModel with the given type and whether or not a random
    * basis should be used.
    */
-  NSModel(int treeType = TreeTypes::KD_TREE, bool randomBasis = false);
+  NSModel(TreeTypes treeType = TreeTypes::KD_TREE, bool randomBasis = false);
 
   //! Clean memory, if necessary.
   ~NSModel();
@@ -110,8 +112,8 @@ class NSModel
   size_t LeafSize() const { return leafSize; }
   size_t& LeafSize() { return leafSize; }
 
-  int TreeType() const { return treeType; }
-  int& TreeType() { return treeType; }
+  TreeTypes TreeType() const { return treeType; }
+  TreeTypes& TreeType() { return treeType; }
 
   bool RandomBasis() const { return randomBasis; }
   bool& RandomBasis() { return randomBasis; }
