@@ -7,15 +7,15 @@
  * different types of trees, and also reflects the NeighborSearch API and
  * automatically directs to the right tree type.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_NEIGHBOR_SEARCH_NS_MODEL_IMPL_HPP
-#define __MLPACK_METHODS_NEIGHBOR_SEARCH_NS_MODEL_IMPL_HPP
+#ifndef MLPACK_METHODS_NEIGHBOR_SEARCH_NS_MODEL_IMPL_HPP
+#define MLPACK_METHODS_NEIGHBOR_SEARCH_NS_MODEL_IMPL_HPP
 
 // In case it hasn't been included yet.
 #include "ns_model.hpp"
@@ -28,14 +28,15 @@ namespace neighbor {
  * basis should be used.
  */
 template<typename SortPolicy>
-NSModel<SortPolicy>::NSModel(int treeType, bool randomBasis) :
+NSModel<SortPolicy>::NSModel(TreeTypes treeType, bool randomBasis) :
     treeType(treeType),
     randomBasis(randomBasis),
     kdTreeNS(NULL),
     coverTreeNS(NULL),
     rTreeNS(NULL),
     rStarTreeNS(NULL),
-    ballTreeNS(NULL)
+    ballTreeNS(NULL),
+    xTreeNS(NULL)
 {
   // Nothing to do.
 }
@@ -54,6 +55,8 @@ NSModel<SortPolicy>::~NSModel()
     delete rStarTreeNS;
   if (ballTreeNS)
     delete ballTreeNS;
+  if (xTreeNS)
+    delete xTreeNS;
 }
 
 //! Serialize the kNN model.
@@ -79,12 +82,16 @@ void NSModel<SortPolicy>::Serialize(Archive& ar,
       delete rStarTreeNS;
     if (ballTreeNS)
       delete ballTreeNS;
+    if (xTreeNS)
+      delete xTreeNS;
 
     // Set all the pointers to NULL.
     kdTreeNS = NULL;
     coverTreeNS = NULL;
     rTreeNS = NULL;
     rStarTreeNS = NULL;
+    ballTreeNS = NULL;
+    xTreeNS = NULL;
   }
 
   // We'll only need to serialize one of the kNN objects, based on the type.
@@ -106,6 +113,9 @@ void NSModel<SortPolicy>::Serialize(Archive& ar,
     case BALL_TREE:
       ar & data::CreateNVP(ballTreeNS, name);
       break;
+    case X_TREE:
+      ar & data::CreateNVP(xTreeNS, name);
+      break;
   }
 }
 
@@ -122,6 +132,8 @@ const arma::mat& NSModel<SortPolicy>::Dataset() const
     return rStarTreeNS->ReferenceSet();
   else if (ballTreeNS)
     return ballTreeNS->ReferenceSet();
+  else if (xTreeNS)
+    return xTreeNS->ReferenceSet();
 
   throw std::runtime_error("no neighbor search model initialized");
 }
@@ -140,6 +152,8 @@ bool NSModel<SortPolicy>::SingleMode() const
     return rStarTreeNS->SingleMode();
   else if (ballTreeNS)
     return ballTreeNS->SingleMode();
+  else if (xTreeNS)
+    return xTreeNS->SingleMode();
 
   throw std::runtime_error("no neighbor search model initialized");
 }
@@ -157,6 +171,8 @@ bool& NSModel<SortPolicy>::SingleMode()
     return rStarTreeNS->SingleMode();
   else if (ballTreeNS)
     return ballTreeNS->SingleMode();
+  else if (xTreeNS)
+    return xTreeNS->SingleMode();
 
   throw std::runtime_error("no neighbor search model initialized");
 }
@@ -174,6 +190,8 @@ bool NSModel<SortPolicy>::Naive() const
     return rStarTreeNS->Naive();
   else if (ballTreeNS)
     return ballTreeNS->Naive();
+  else if (xTreeNS)
+    return xTreeNS->Naive();
 
   throw std::runtime_error("no neighbor search model initialized");
 }
@@ -191,6 +209,8 @@ bool& NSModel<SortPolicy>::Naive()
     return rStarTreeNS->Naive();
   else if (ballTreeNS)
     return ballTreeNS->Naive();
+  else if (xTreeNS)
+    return xTreeNS->Naive();
 
   throw std::runtime_error("no neighbor search model initialized");
 }
@@ -245,6 +265,8 @@ void NSModel<SortPolicy>::BuildModel(arma::mat&& referenceSet,
     delete rStarTreeNS;
   if (ballTreeNS)
     delete ballTreeNS;
+  if (xTreeNS)
+    delete xTreeNS;
 
   // Do we need to modify the reference set?
   if (randomBasis)
@@ -305,7 +327,7 @@ void NSModel<SortPolicy>::BuildModel(arma::mat&& referenceSet,
       {
         std::vector<size_t> oldFromNewReferences;
         typename NSType<tree::BallTree>::Tree* ballTree =
-            new typename NSType<tree::KDTree>::Tree(std::move(referenceSet),
+            new typename NSType<tree::BallTree>::Tree(std::move(referenceSet),
             oldFromNewReferences, leafSize);
         ballTreeNS = new NSType<tree::BallTree>(ballTree, singleMode);
 
@@ -315,6 +337,11 @@ void NSModel<SortPolicy>::BuildModel(arma::mat&& referenceSet,
       }
 
       break;
+    case X_TREE:
+      // If necessary, build the X tree.
+      xTreeNS = new NSType<tree::XTree>(std::move(referenceSet), naive,
+          singleMode);
+      break;
   }
 
   if (!naive)
@@ -419,6 +446,10 @@ void NSModel<SortPolicy>::Search(arma::mat&& querySet,
         ballTreeNS->Search(querySet, k, neighbors, distances);
       }
 
+      break;
+    case X_TREE:
+      // No mapping necessary.
+      xTreeNS->Search(querySet, k, neighbors, distances);
       break;
   }
 }
@@ -454,6 +485,9 @@ void NSModel<SortPolicy>::Search(const size_t k,
     case BALL_TREE:
       ballTreeNS->Search(k, neighbors, distances);
       break;
+    case X_TREE:
+      xTreeNS->Search(k, neighbors, distances);
+      break;
   }
 }
 
@@ -473,6 +507,8 @@ std::string NSModel<SortPolicy>::TreeName() const
       return "R* tree";
     case BALL_TREE:
       return "ball tree";
+    case X_TREE:
+      return "X tree";
     default:
       return "unknown tree";
   }
