@@ -7,15 +7,15 @@
  * also reflects the RangeSearch API and automatically directs to the right
  * tree types.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_RANGE_SEARCH_RS_MODEL_HPP
-#define __MLPACK_METHODS_RANGE_SEARCH_RS_MODEL_HPP
+#ifndef MLPACK_METHODS_RANGE_SEARCH_RS_MODEL_HPP
+#define MLPACK_METHODS_RANGE_SEARCH_RS_MODEL_HPP
 
 #include <mlpack/core/tree/binary_space_tree.hpp>
 #include <mlpack/core/tree/cover_tree.hpp>
@@ -35,11 +35,12 @@ class RSModel
     COVER_TREE,
     R_TREE,
     R_STAR_TREE,
-    BALL_TREE
+    BALL_TREE,
+    X_TREE
   };
 
  private:
-  int treeType;
+  TreeTypes treeType;
   size_t leafSize;
 
   //! If true, we randomly project the data into a new basis before search.
@@ -64,6 +65,8 @@ class RSModel
   RSType<tree::RStarTree>* rStarTreeRS;
   //! Ball tree based range search object (NULL if not in use).
   RSType<tree::BallTree>* ballTreeRS;
+  //! X tree based range search object (NULL if not in use).
+  RSType<tree::XTree>* xTreeRS;
 
  public:
   /**
@@ -73,7 +76,7 @@ class RSModel
    * @param treeType Type of tree to use.
    * @param randomBasis Whether or not to use a random basis.
    */
-  RSModel(const int treeType = TreeTypes::KD_TREE,
+  RSModel(const TreeTypes treeType = TreeTypes::KD_TREE,
           const bool randomBasis = false);
 
   /**
@@ -104,9 +107,9 @@ class RSModel
   size_t& LeafSize() { return leafSize; }
 
   //! Get the type of tree.
-  int TreeType() const { return treeType; }
+  TreeTypes TreeType() const { return treeType; }
   //! Modify the type of tree (don't do this after the model has been built).
-  int& TreeType() { return treeType; }
+  TreeTypes& TreeType() { return treeType; }
 
   //! Get whether a random basis is used.
   bool RandomBasis() const { return randomBasis; }
