@@ -4,15 +4,15 @@
  *
  * Implementation of the RAModel class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_RANN_RA_MODEL_IMPL_HPP
-#define __MLPACK_METHODS_RANN_RA_MODEL_IMPL_HPP
+#ifndef MLPACK_METHODS_RANN_RA_MODEL_IMPL_HPP
+#define MLPACK_METHODS_RANN_RA_MODEL_IMPL_HPP
 
 // In case it hasn't been included yet.
 #include "ra_model.hpp"
@@ -21,14 +21,15 @@ namespace mlpack {
 namespace neighbor {
 
 template<typename SortPolicy>
-RAModel<SortPolicy>::RAModel(const int treeType, const bool randomBasis) :
+RAModel<SortPolicy>::RAModel(const TreeTypes treeType, const bool randomBasis) :
     treeType(treeType),
     leafSize(20),
     randomBasis(randomBasis),
     kdTreeRA(NULL),
     coverTreeRA(NULL),
     rTreeRA(NULL),
-    rStarTreeRA(NULL)
+    rStarTreeRA(NULL),
+    xTreeRA(NULL)
 {
   // Nothing to do.
 }
@@ -44,6 +45,8 @@ RAModel<SortPolicy>::~RAModel()
     delete rTreeRA;
   if (rStarTreeRA)
     delete rStarTreeRA;
+  if (xTreeRA)
+    delete xTreeRA;
 }
 
 template<typename SortPolicy>
@@ -66,12 +69,15 @@ void RAModel<SortPolicy>::Serialize(Archive& ar,
       delete rTreeRA;
     if (rStarTreeRA)
       delete rStarTreeRA;
+    if (xTreeRA)
+      delete xTreeRA;
 
     // Set all the pointers to NULL.
     kdTreeRA = NULL;
     coverTreeRA = NULL;
     rTreeRA = NULL;
     rStarTreeRA = NULL;
+    xTreeRA = NULL;
   }
 
   // We only need to serialize one of the kRANN objects.
@@ -89,6 +95,9 @@ void RAModel<SortPolicy>::Serialize(Archive& ar,
     case R_STAR_TREE:
       ar & data::CreateNVP(rStarTreeRA, "ra_model");
       break;
+    case X_TREE:
+      ar & data::CreateNVP(xTreeRA, "ra_model");
+      break;
   }
 }
 
@@ -103,6 +112,8 @@ const arma::mat& RAModel<SortPolicy>::Dataset() const
     return rTreeRA->ReferenceSet();
   else if (rStarTreeRA)
     return rStarTreeRA->ReferenceSet();
+  else if (xTreeRA)
+    return xTreeRA->ReferenceSet();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -119,6 +130,8 @@ bool RAModel<SortPolicy>::Naive() const
     return rTreeRA->Naive();
   else if (rStarTreeRA)
     return rStarTreeRA->Naive();
+  else if (xTreeRA)
+    return xTreeRA->Naive();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -135,6 +148,8 @@ bool& RAModel<SortPolicy>::Naive()
     return rTreeRA->Naive();
   else if (rStarTreeRA)
     return rStarTreeRA->Naive();
+  else if (xTreeRA)
+    return xTreeRA->Naive();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -151,6 +166,8 @@ bool RAModel<SortPolicy>::SingleMode() const
     return rTreeRA->SingleMode();
   else if (rStarTreeRA)
     return rStarTreeRA->SingleMode();
+  else if (xTreeRA)
+    return xTreeRA->SingleMode();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -167,6 +184,8 @@ bool& RAModel<SortPolicy>::SingleMode()
     return rTreeRA->SingleMode();
   else if (rStarTreeRA)
     return rStarTreeRA->SingleMode();
+  else if (xTreeRA)
+    return xTreeRA->SingleMode();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -183,6 +202,8 @@ double RAModel<SortPolicy>::Tau() const
     return rTreeRA->Tau();
   else if (rStarTreeRA)
     return rStarTreeRA->Tau();
+  else if (xTreeRA)
+    return xTreeRA->Tau();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -199,6 +220,8 @@ double& RAModel<SortPolicy>::Tau()
     return rTreeRA->Tau();
   else if (rStarTreeRA)
     return rStarTreeRA->Tau();
+  else if (xTreeRA)
+    return xTreeRA->Tau();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -215,6 +238,8 @@ double RAModel<SortPolicy>::Alpha() const
     return rTreeRA->Alpha();
   else if (rStarTreeRA)
     return rStarTreeRA->Alpha();
+  else if (xTreeRA)
+    return xTreeRA->Alpha();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -231,6 +256,8 @@ double& RAModel<SortPolicy>::Alpha()
     return rTreeRA->Alpha();
   else if (rStarTreeRA)
     return rStarTreeRA->Alpha();
+  else if (xTreeRA)
+    return xTreeRA->Alpha();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -247,6 +274,8 @@ bool RAModel<SortPolicy>::SampleAtLeaves() const
     return rTreeRA->SampleAtLeaves();
   else if (rStarTreeRA)
     return rStarTreeRA->SampleAtLeaves();
+  else if (xTreeRA)
+    return xTreeRA->SampleAtLeaves();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -263,6 +292,8 @@ bool& RAModel<SortPolicy>::SampleAtLeaves()
     return rTreeRA->SampleAtLeaves();
   else if (rStarTreeRA)
     return rStarTreeRA->SampleAtLeaves();
+  else if (xTreeRA)
+    return xTreeRA->SampleAtLeaves();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -279,6 +310,8 @@ bool RAModel<SortPolicy>::FirstLeafExact() const
     return rTreeRA->FirstLeafExact();
   else if (rStarTreeRA)
     return rStarTreeRA->FirstLeafExact();
+  else if (xTreeRA)
+    return xTreeRA->FirstLeafExact();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -295,6 +328,8 @@ bool& RAModel<SortPolicy>::FirstLeafExact()
     return rTreeRA->FirstLeafExact();
   else if (rStarTreeRA)
     return rStarTreeRA->FirstLeafExact();
+  else if (xTreeRA)
+    return xTreeRA->FirstLeafExact();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -311,6 +346,8 @@ size_t RAModel<SortPolicy>::SingleSampleLimit() const
     return rTreeRA->SingleSampleLimit();
   else if (rStarTreeRA)
     return rStarTreeRA->SingleSampleLimit();
+  else if (xTreeRA)
+    return xTreeRA->SingleSampleLimit();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -327,6 +364,8 @@ size_t& RAModel<SortPolicy>::SingleSampleLimit()
     return rTreeRA->SingleSampleLimit();
   else if (rStarTreeRA)
     return rStarTreeRA->SingleSampleLimit();
+  else if (xTreeRA)
+    return xTreeRA->SingleSampleLimit();
 
   throw std::runtime_error("no rank-approximate nearest neighbor search model "
       "initialized");
@@ -345,13 +384,13 @@ size_t& RAModel<SortPolicy>::LeafSize()
 }
 
 template<typename SortPolicy>
-int RAModel<SortPolicy>::TreeType() const
+typename RAModel<SortPolicy>::TreeTypes RAModel<SortPolicy>::TreeType() const
 {
   return treeType;
 }
 
 template<typename SortPolicy>
-int& RAModel<SortPolicy>::TreeType()
+typename RAModel<SortPolicy>::TreeTypes& RAModel<SortPolicy>::TreeType()
 {
   return treeType;
 }
@@ -390,6 +429,8 @@ void RAModel<SortPolicy>::BuildModel(arma::mat&& referenceSet,
     delete rTreeRA;
   if (rStarTreeRA)
     delete rStarTreeRA;
+  if (xTreeRA)
+    delete xTreeRA;
 
   if (randomBasis)
     referenceSet = q * referenceSet;
@@ -434,6 +475,10 @@ void RAModel<SortPolicy>::BuildModel(arma::mat&& referenceSet,
       rStarTreeRA = new RAType<tree::RStarTree>(std::move(referenceSet), naive,
           singleMode);
       break;
+    case X_TREE:
+      xTreeRA = new RAType<tree::XTree>(std::move(referenceSet), naive,
+          singleMode);
+      break;
   }
 
   if (!naive)
@@ -507,6 +552,10 @@ void RAModel<SortPolicy>::Search(arma::mat&& querySet,
       // No mapping necessary.
       rStarTreeRA->Search(querySet, k, neighbors, distances);
       break;
+    case X_TREE:
+      // No mapping necessary.
+      xTreeRA->Search(querySet, k, neighbors, distances);
+      break;
   }
 }
 
@@ -538,6 +587,9 @@ void RAModel<SortPolicy>::Search(const size_t k,
     case R_STAR_TREE:
       rStarTreeRA->Search(k, neighbors, distances);
       break;
+    case X_TREE:
+      xTreeRA->Search(k, neighbors, distances);
+      break;
   }
 }
 
@@ -554,6 +606,8 @@ std::string RAModel<SortPolicy>::TreeName() const
       return "R tree";
     case R_STAR_TREE:
       return "R* tree";
+    case X_TREE:
+      return "X tree";
     default:
       return "unknown tree";
   }
