@@ -5,15 +5,15 @@
  * Implementation of RASearch class to perform rank-approximate
  * all-nearest-neighbors on two specified data sets.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_RANN_RA_SEARCH_IMPL_HPP
-#define __MLPACK_METHODS_RANN_RA_SEARCH_IMPL_HPP
+#ifndef MLPACK_METHODS_RANN_RA_SEARCH_IMPL_HPP
+#define MLPACK_METHODS_RANN_RA_SEARCH_IMPL_HPP
 
 #include <mlpack/core.hpp>
 
