@@ -6,17 +6,17 @@
  * tree-based rank-approximate search (with an arbitrary tree) for the RASearch
  * class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_RANN_RA_SEARCH_RULES_HPP
-#define __MLPACK_METHODS_RANN_RA_SEARCH_RULES_HPP
+#ifndef MLPACK_METHODS_RANN_RA_SEARCH_RULES_HPP
+#define MLPACK_METHODS_RANN_RA_SEARCH_RULES_HPP
 
-#include "../neighbor_search/ns_traversal_info.hpp"
+#include <mlpack/core/tree/traversal_info.hpp>
 
 namespace mlpack {
 namespace neighbor {
@@ -192,7 +192,7 @@ class RASearchRules
       return arma::sum(numSamplesMade);
   }
 
-  typedef neighbor::NeighborSearchTraversalInfo<TreeType> TraversalInfoType;
+  typedef typename tree::TraversalInfo<TreeType> TraversalInfoType;
 
   const TraversalInfoType& TraversalInfo() const { return traversalInfo; }
   TraversalInfoType& TraversalInfo() { return traversalInfo; }
@@ -276,4 +276,4 @@ class RASearchRules
 // Include implementation.
 #include "ra_search_rules_impl.hpp"
 
-#endif // __MLPACK_METHODS_RANN_RA_SEARCH_RULES_HPP
+#endif // MLPACK_METHODS_RANN_RA_SEARCH_RULES_HPP
