@@ -5,15 +5,15 @@
  * Simple typedefs describing template instantiations of the RASearch
  * class which are commonly used.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_RANN_RA_TYPEDEF_HPP
-#define __MLPACK_RANN_RA_TYPEDEF_HPP
+#ifndef MLPACK_RANN_RA_TYPEDEF_HPP
+#define MLPACK_RANN_RA_TYPEDEF_HPP
 
 // In case someone included this directly.
 #include "ra_search.hpp"
@@ -27,32 +27,55 @@ namespace mlpack {
 namespace neighbor {
 
 /**
- * The AllkRANN class is the all-k-rank-approximate-nearest-neighbors method.
- * It returns squared L2 distances (squared Euclidean distances) for each of the
- * k rank-approximate nearest-neighbors.  Squared distances are used because
- * they are slightly faster than non-squared distances (they have one fewer call
- * to sqrt()).
+ * The KRANN class is the k-rank-approximate-nearest-neighbors method.  It
+ * returns L2 distances for each of the k rank-approximate nearest-neighbors.
  *
  * The approximation is controlled with two parameters (see allkrann_main.cpp)
  * which can be specified at search time. So the tree building is done only once
  * while the search can be performed multiple times with different approximation
  * levels.
  */
+typedef RASearch<> KRANN;
+
+/**
+ * The KRAFN class is the k-rank-approximate-farthest-neighbors method.  It
+ * returns L2 distances for each of the k rank-approximate farthest-neighbors.
+ *
+ * The approximation is controlled with two parameters (see allkrann_main.cpp)
+ * which can be specified at search time. So the tree building is done only once
+ * while the search can be performed multiple times with different approximation
+ * levels.
+ */
+typedef RASearch<FurthestNeighborSort> KRAFN;
+
+/**
+ * @deprecated
+ * The AllkRANN class is the all-k-rank-approximate-nearest-neighbors method.  It
+ * returns L2 distances for each of the k rank-approximate nearest-neighbors.
+ *
+ * The approximation is controlled with two parameters (see allkrann_main.cpp)
+ * which can be specified at search time. So the tree building is done only once
+ * while the search can be performed multiple times with different approximation
+ * levels.
+ *
+ * This typedef will be removed in mlpack 3.0.0; use the KRANN typedef instead.
+ */
 typedef RASearch<> AllkRANN;
 
 /**
+ * @deprecated
  * The AllkRAFN class is the all-k-rank-approximate-farthest-neighbors method.
- * It returns squared L2 distances (squared Euclidean distances) for each of the
- * k rank-approximate farthest-neighbors.  Squared distances are used because
- * they are slightly faster than  non-squared distances (they have one fewer
- * call to sqrt()).
+ * It returns L2 distances for each of the k rank-approximate
+ * farthest-neighbors.
  *
  * The approximation is controlled with two parameters (see allkrann_main.cpp)
  * which can be specified at search time. So the tree building is done only once
  * while the search can be performed multiple times with different approximation
  * levels.
+ *
+ * This typedef will be removed in mlpack 3.0.0; use the KRANN typedef instead.
  */
-typedef RASearch<FurthestNeighborSort> AllkRAFN;
+typedef RASearch<> AllkRAFN;
 
 } // namespace neighbor
 } // namespace mlpack
