@@ -4,9 +4,9 @@
  *
  * Main executable for softmax regression.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -34,9 +34,9 @@ PROGRAM_INFO("Softmax Regression", "This program performs softmax regression, "
     "(-r), and if an intercept term is not desired in the model, the "
     "--no_intercept (-N) can be specified."
     "\n\n"
-    "The trained model can be saved to a file with the --output_model (-m) "
+    "The trained model can be saved to a file with the --output_model_file (-m) "
     "option.  If training is not desired, but only testing is, a model can be "
-    "loaded with the --input_model (-i) option.  At the current time, a loaded "
+    "loaded with the --input_model_file (-i) option.  At the current time, a loaded "
     "model cannot be trained further, so specifying both -i and -t is not "
     "allowed."
     "\n\n"
@@ -93,10 +93,10 @@ void TestPredictAcc(const string& testFile,
 
 // Build the softmax model given the parameters.
 template<typename Model>
-std::unique_ptr<Model> TrainSoftmax(const string& trainingFile,
-                                    const string& labelFile,
-                                    const string& inputModelFile,
-                                    const size_t maxIterations);
+unique_ptr<Model> TrainSoftmax(const string& trainingFile,
+                               const string& labelsFile,
+                               const string& inputModelFile,
+                               const size_t maxIterations);
 
 int main(int argc, char** argv)
 {
@@ -104,39 +104,39 @@ int main(int argc, char** argv)
 
   CLI::ParseCommandLine(argc, argv);
 
-  const std::string trainingFile = CLI::GetParam<std::string>("training_file");
-  const std::string inputModelFile = CLI::GetParam<std::string>("input_model");
+  const string trainingFile = CLI::GetParam<string>("training_file");
+  const string labelsFile = CLI::GetParam<string>("labels_file");
+  const string inputModelFile = CLI::GetParam<string>("input_model_file");
+  const string outputModelFile = CLI::GetParam<string>("output_model_file");
+  const string testLabelsFile = CLI::GetParam<string>("test_labels");
+  const int maxIterations = CLI::GetParam<int>("max_iterations");
+  const string predictionsFile = CLI::GetParam<string>("predictions_file");
 
   // One of inputFile and modelFile must be specified.
-  if (inputModelFile.empty() && trainingFile.empty())
-    Log::Fatal << "One of --input_model or --training_file must be specified."
+  if (!CLI::HasParam("input_model_file") && !CLI::HasParam("training_file"))
+    Log::Fatal << "One of --input_model_file or --training_file must be specified."
         << endl;
 
-  const std::string labelFile = CLI::GetParam<std::string>("labels_file");
-  if (!trainingFile.empty() && labelFile.empty())
+  if (CLI::HasParam("training_file") && CLI::HasParam("labels_file"))
     Log::Fatal << "--labels_file must be specified with --training_file!"
         << endl;
 
-  const int maxIterations = CLI::GetParam<int>("max_iterations");
-
   if (maxIterations < 0)
     Log::Fatal << "Invalid value for maximum iterations (" << maxIterations
         << ")! Must be greater than or equal to 0." << endl;
 
-  const string outputModelFile = CLI::GetParam<string>("output_model");
-  const string testLabelsFile = CLI::GetParam<string>("test_labels");
-  const string predictionsFile = CLI::GetParam<string>("predictions_file");
-
   // Make sure we have an output file of some sort.
-  if (outputModelFile.empty() && testLabelsFile.empty() &&
-      predictionsFile.empty())
-    Log::Warn << "None of --output_model, --test_labels, or --predictions_file "
-        << "are set; no results from this program will be saved." << endl;
+  if (!CLI::HasParam("output_model_file") &&
+      !CLI::HasParam("test_labels") &&
+      !CLI::HasParam("predictions_file"))
+    Log::Warn << "None of --output_model_file, --test_labels, or "
+        << "--predictions_file are set; no results from this program will be "
+        << "saved." << endl;
 
 
   using SM = regression::SoftmaxRegression<>;
-  std::unique_ptr<SM> sm = TrainSoftmax<SM>(trainingFile,
-                                            labelFile,
+  unique_ptr<SM> sm = TrainSoftmax<SM>(trainingFile,
+                                            labelsFile,
                                             inputModelFile,
                                             maxIterations);
 
@@ -145,11 +145,9 @@ int main(int argc, char** argv)
                  CLI::GetParam<string>("test_labels"),
                  sm->NumClasses(), *sm);
 
-  if (!outputModelFile.empty())
-  {
-    data::Save(CLI::GetParam<std::string>("output_model"),
+  if (CLI::HasParam("output_model_file"))
+    data::Save(CLI::GetParam<string>("output_model_file"),
         "softmax_regression_model", *sm, true);
-  }
 }
 
 size_t CalculateNumberOfClasses(const size_t numClasses,
@@ -157,8 +155,8 @@ size_t CalculateNumberOfClasses(const size_t numClasses,
 {
   if (numClasses == 0)
   {
-    const std::set<size_t> unique_labels(std::begin(trainLabels),
-                                         std::end(trainLabels));
+    const set<size_t> unique_labels(begin(trainLabels),
+                                    end(trainLabels));
     return unique_labels.size();
   }
   else
@@ -216,12 +214,12 @@ void TestPredictAcc(const string& testFile,
     if (testData.n_cols != testLabels.n_elem)
     {
       Log::Fatal << "Test data in --test_data has " << testData.n_cols
-          << " points, but labels in --test_labels have " << testLabels.n_elem
-          << " labels!" << endl;
+          << " points, but labels in --test_labels have "
+          << testLabels.n_elem << " labels!" << endl;
     }
 
-    std::vector<size_t> bingoLabels(numClasses, 0);
-    std::vector<size_t> labelSize(numClasses, 0);
+    vector<size_t> bingoLabels(numClasses, 0);
+    vector<size_t> labelSize(numClasses, 0);
     for (arma::uword i = 0; i != predictLabels.n_elem; ++i)
     {
       if (predictLabels(i) == testLabels(i))
@@ -247,16 +245,16 @@ void TestPredictAcc(const string& testFile,
 }
 
 template<typename Model>
-std::unique_ptr<Model> TrainSoftmax(const string& trainingFile,
-                                    const string& labelFile,
-                                    const string& inputModelFile,
-                                    const size_t maxIterations)
+unique_ptr<Model> TrainSoftmax(const string& trainingFile,
+                               const string& labelsFile,
+                               const string& inputModelFile,
+                               const size_t maxIterations)
 {
   using namespace mlpack;
 
   using SRF = regression::SoftmaxRegressionFunction;
 
-  std::unique_ptr<Model> sm;
+  unique_ptr<Model> sm;
   if (!inputModelFile.empty())
   {
     sm.reset(new Model(0, 0, false));
@@ -271,7 +269,7 @@ std::unique_ptr<Model> TrainSoftmax(const string& trainingFile,
     //load functions of mlpack do not works on windows, it will complain
     //"[FATAL] Unable to detect type of 'softmax_data.txt'; incorrect extension?"
     data::Load(trainingFile, trainData, true);
-    data::Load(labelFile, tmpTrainLabels, true);
+    data::Load(labelsFile, tmpTrainLabels, true);
     trainLabels = tmpTrainLabels.row(0);
 
     if (trainData.n_cols != trainLabels.n_elem)
