@@ -5,15 +5,15 @@
  * A very simple random dictionary initializer for SparseCoding; it is probably
  * not a very good choice.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_SPARSE_CODING_RANDOM_INITIALIZER_HPP
-#define __MLPACK_METHODS_SPARSE_CODING_RANDOM_INITIALIZER_HPP
+#ifndef MLPACK_METHODS_SPARSE_CODING_RANDOM_INITIALIZER_HPP
+#define MLPACK_METHODS_SPARSE_CODING_RANDOM_INITIALIZER_HPP
 
 #include <mlpack/core.hpp>
 
