@@ -5,15 +5,15 @@
  * Definition of the SparseCoding class, which performs L1 (LASSO) or
  * L1+L2 (Elastic Net)-regularized sparse coding with dictionary learning
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_METHODS_SPARSE_CODING_SPARSE_CODING_HPP
-#define __MLPACK_METHODS_SPARSE_CODING_SPARSE_CODING_HPP
+#ifndef MLPACK_METHODS_SPARSE_CODING_SPARSE_CODING_HPP
+#define MLPACK_METHODS_SPARSE_CODING_SPARSE_CODING_HPP
 
 #include <mlpack/core.hpp>
 #include <mlpack/methods/lars/lars.hpp>
