@@ -4,9 +4,9 @@
  *
  * Test file for CosineTree class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -58,6 +58,8 @@ BOOST_AUTO_TEST_CASE(CosineNodeCosineSplit)
   // Initialize constants required for the test.
   const size_t numRows = 500;
   const size_t numCols = 1000;
+  // Calculation accuracy.
+  const double precision = 1e-15;
 
   // Make a random dataset and the root object.
   arma::mat data = arma::randu(numRows, numCols);
@@ -111,15 +113,53 @@ BOOST_AUTO_TEST_CASE(CosineNodeCosineSplit)
         cosines(k) = arma::norm_dot(data.col(rightIndices[j]), splitPoint);
 
       // Check if the columns assigned to the children agree with the splitting
-      // condition.
-      double cosineMax = arma::max(cosines % (cosines < 1));
+      // condition.  Due to miscalculations cosineMax calculated by
+      // CosineNodeSplit may differ from cosineMax below, so we have to handle
+      // minor differences.
+      double cosineMax = arma::max(cosines % (cosines < 1.0 + precision));
       double cosineMin = arma::min(cosines);
+      // If max(cosines) is close to 1.0 cosineMax and cosineMax2 may
+      // differ significantly.
+      double cosineMax2 = arma::max(cosines % (cosines < 1.0 - precision));
 
-      for (i = 0; i < leftIndices.size(); i++)
-        BOOST_CHECK_LT(cosineMax - cosines(i), cosines(i) - cosineMin);
 
-      for (j = 0, k = i; j < rightIndices.size(); j++, k++)
-        BOOST_CHECK_GT(cosineMax - cosines(k), cosines(k) - cosineMin);
+      if (std::fabs(cosineMax - cosineMax2) < precision)
+      {
+        // Check with some precision.
+        for (i = 0; i < leftIndices.size(); i++)
+          BOOST_REQUIRE_LT(cosineMax - cosines(i),
+                           cosines(i) - cosineMin + precision);
+
+        for (j = 0, k = i; j < rightIndices.size(); j++, k++)
+          BOOST_REQUIRE_GT(cosineMax - cosines(k),
+                           cosines(k) - cosineMin - precision);
+      }
+      else
+      {
+        size_t numMax1Errors = 0;
+        size_t numMax2Errors = 0;
+
+        // Find errors for cosineMax.
+        for (i = 0; i < leftIndices.size(); i++)
+          if (cosineMax - cosines(i) >= cosines(i) - cosineMin + precision)
+            numMax1Errors++;
+
+        for (j = 0, k = i; j < rightIndices.size(); j++, k++)
+          if (cosineMax - cosines(k) <= cosines(k) - cosineMin - precision)
+            numMax1Errors++;
+
+        // Find errors for cosineMax2.
+        for (i = 0; i < leftIndices.size(); i++)
+          if (cosineMax2 - cosines(i) >= cosines(i) - cosineMin + precision)
+            numMax2Errors++;
+
+        for (j = 0, k = i; j < rightIndices.size(); j++, k++)
+          if (cosineMax2 - cosines(k) <= cosines(k) - cosineMin - precision)
+            numMax2Errors++;
+
+        // One of the maximum cosine values should be correct
+        BOOST_REQUIRE_EQUAL(std::min(numMax1Errors, numMax2Errors), 0);
+      }
     }
   }
 }
