@@ -5,15 +5,15 @@
  * Ancient Boost.Test versions don't act how we expect.  This file includes the
  * things we need to fix that.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
-#ifndef __MLPACK_TESTS_OLD_BOOST_TEST_DEFINITIONS_HPP
-#define __MLPACK_TESTS_OLD_BOOST_TEST_DEFINITIONS_HPP
+#ifndef MLPACK_TESTS_OLD_BOOST_TEST_DEFINITIONS_HPP
+#define MLPACK_TESTS_OLD_BOOST_TEST_DEFINITIONS_HPP
 
 #include <boost/version.hpp>
 
