@@ -4,9 +4,9 @@
  *
  * Test file for RangeSearch<> class.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -1258,7 +1258,7 @@ BOOST_AUTO_TEST_CASE(RSModelTest)
   arma::mat referenceData = arma::randu<arma::mat>(10, 200);
 
   // Build all the possible models.
-  RSModel models[10];
+  RSModel models[12];
   models[0] = RSModel(RSModel::TreeTypes::KD_TREE, true);
   models[1] = RSModel(RSModel::TreeTypes::KD_TREE, false);
   models[2] = RSModel(RSModel::TreeTypes::COVER_TREE, true);
@@ -1267,8 +1267,10 @@ BOOST_AUTO_TEST_CASE(RSModelTest)
   models[5] = RSModel(RSModel::TreeTypes::R_TREE, false);
   models[6] = RSModel(RSModel::TreeTypes::R_STAR_TREE, true);
   models[7] = RSModel(RSModel::TreeTypes::R_STAR_TREE, false);
-  models[8] = RSModel(RSModel::TreeTypes::BALL_TREE, true);
-  models[9] = RSModel(RSModel::TreeTypes::BALL_TREE, false);
+  models[8] = RSModel(RSModel::TreeTypes::X_TREE, true);
+  models[9] = RSModel(RSModel::TreeTypes::X_TREE, false);
+  models[10] = RSModel(RSModel::TreeTypes::BALL_TREE, true);
+  models[11] = RSModel(RSModel::TreeTypes::BALL_TREE, false);
 
   for (size_t j = 0; j < 2; ++j)
   {
@@ -1282,7 +1284,7 @@ BOOST_AUTO_TEST_CASE(RSModelTest)
     vector<vector<pair<double, size_t>>> baselineSorted;
     SortResults(baselineNeighbors, baselineDistances, baselineSorted);
 
-    for (size_t i = 0; i < 10; ++i)
+    for (size_t i = 0; i < 12; ++i)
     {
       // We only have std::move() constructors, so make a copy of our data.
       arma::mat referenceCopy(referenceData);
@@ -1326,7 +1328,7 @@ BOOST_AUTO_TEST_CASE(RSModelMonochromaticTest)
   arma::mat referenceData = arma::randu<arma::mat>(10, 200);
 
   // Build all the possible models.
-  RSModel models[10];
+  RSModel models[12];
   models[0] = RSModel(RSModel::TreeTypes::KD_TREE, true);
   models[1] = RSModel(RSModel::TreeTypes::KD_TREE, false);
   models[2] = RSModel(RSModel::TreeTypes::COVER_TREE, true);
@@ -1335,8 +1337,10 @@ BOOST_AUTO_TEST_CASE(RSModelMonochromaticTest)
   models[5] = RSModel(RSModel::TreeTypes::R_TREE, false);
   models[6] = RSModel(RSModel::TreeTypes::R_STAR_TREE, true);
   models[7] = RSModel(RSModel::TreeTypes::R_STAR_TREE, false);
-  models[8] = RSModel(RSModel::TreeTypes::BALL_TREE, true);
-  models[9] = RSModel(RSModel::TreeTypes::BALL_TREE, false);
+  models[8] = RSModel(RSModel::TreeTypes::X_TREE, true);
+  models[9] = RSModel(RSModel::TreeTypes::X_TREE, false);
+  models[10] = RSModel(RSModel::TreeTypes::BALL_TREE, true);
+  models[11] = RSModel(RSModel::TreeTypes::BALL_TREE, false);
 
   for (size_t j = 0; j < 2; ++j)
   {
@@ -1349,7 +1353,7 @@ BOOST_AUTO_TEST_CASE(RSModelMonochromaticTest)
     vector<vector<pair<double, size_t>>> baselineSorted;
     SortResults(baselineNeighbors, baselineDistances, baselineSorted);
 
-    for (size_t i = 0; i < 10; ++i)
+    for (size_t i = 0; i < 12; ++i)
     {
       // We only have std::move() cosntructors, so make a copy of our data.
       arma::mat referenceCopy(referenceData);
