@@ -6,9 +6,9 @@
  * correctly and that subsequent changes don't break anything.  Because it's
  * only used to test the trees, it is slow.
  *
- * This file is part of mlpack 2.0.1.
+ * This file is part of mlpack 2.0.2.
  *
- * mlpack is free software; you may redstribute it and/or modify it under the
+ * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
  * 3-clause BSD license along with mlpack.  If not, see
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
@@ -28,10 +28,6 @@ using namespace mlpack::metric;
 
 BOOST_AUTO_TEST_SUITE(RectangleTreeTest);
 
-// Be careful!  When writing new tests, always get the boolean value and store
-// it in a temporary, because the Boost unit test macros do weird things and
-// will cause bizarre problems.
-
 // Test the traits on RectangleTrees.
 
 BOOST_AUTO_TEST_CASE(RectangleTreeTraitsTest)
@@ -261,7 +257,7 @@ BOOST_AUTO_TEST_CASE(TreeLocalDatasetInSync)
 {
   arma::mat dataset;
   dataset.randu(8, 1000); // 1000 points in 8 dimensions.
-  
+
   typedef RTree<EuclideanDistance, NeighborSearchStat<NearestNeighborSort>,
       arma::mat> TreeType;
 
@@ -433,11 +429,11 @@ BOOST_AUTO_TEST_CASE(PointDeletion)
 
   // Single-tree search.
   NeighborSearch<NearestNeighborSort, metric::LMetric<2, true>, arma::mat,
-      RTree> allknn1(&tree, true);
+      RTree> knn1(&tree, true);
 
   arma::Mat<size_t> neighbors1;
   arma::mat distances1;
-  allknn1.Search(querySet, 5, neighbors1, distances1);
+  knn1.Search(querySet, 5, neighbors1, distances1);
 
   arma::mat newDataset;
   newDataset = dataset;
@@ -447,9 +443,9 @@ BOOST_AUTO_TEST_CASE(PointDeletion)
   arma::mat distances2;
 
   // Nearest neighbor search the naive way.
-  AllkNN allknn2(newDataset, true, true);
+  KNN knn2(newDataset, true, true);
 
-  allknn2.Search(querySet, 5, neighbors2, distances2);
+  knn2.Search(querySet, 5, neighbors2, distances2);
 
   for (size_t i = 0; i < neighbors1.size(); i++)
   {
@@ -523,14 +519,14 @@ BOOST_AUTO_TEST_CASE(PointDynamicAdd)
 
   // Nearest neighbor search with the R tree.
   NeighborSearch<NearestNeighborSort, metric::LMetric<2, true>, arma::mat,
-      RTree> allknn1(&tree, true);
+      RTree> knn1(&tree, true);
 
-  allknn1.Search(5, neighbors1, distances1);
+  knn1.Search(5, neighbors1, distances1);
 
   // Nearest neighbor search the naive way.
-  AllkNN allknn2(dataset, true, true);
+  KNN knn2(dataset, true, true);
 
-  allknn2.Search(5, neighbors2, distances2);
+  knn2.Search(5, neighbors2, distances2);
 
   for (size_t i = 0; i < neighbors1.size(); i++)
   {
@@ -556,7 +552,7 @@ BOOST_AUTO_TEST_CASE(SingleTreeTraverserTest)
 
   // Nearest neighbor search with the R tree.
   NeighborSearch<NearestNeighborSort, metric::LMetric<2, true>, arma::mat,
-      RStarTree> allknn1(&rTree, true);
+      RStarTree> knn1(&rTree, true);
 
   BOOST_REQUIRE_EQUAL(rTree.NumDescendants(), 1000);
 
@@ -565,12 +561,12 @@ BOOST_AUTO_TEST_CASE(SingleTreeTraverserTest)
   CheckExactContainment(rTree);
   CheckHierarchy(rTree);
 
-  allknn1.Search(5, neighbors1, distances1);
+  knn1.Search(5, neighbors1, distances1);
 
   // Nearest neighbor search the naive way.
-  AllkNN allknn2(dataset, true, true);
+  KNN knn2(dataset, true, true);
 
-  allknn2.Search(5, neighbors2, distances2);
+  knn2.Search(5, neighbors2, distances2);
 
   for (size_t i = 0; i < neighbors1.size(); i++)
   {
@@ -582,7 +578,7 @@ BOOST_AUTO_TEST_CASE(SingleTreeTraverserTest)
 
 // A test to ensure that the SingleTreeTraverser is working correctly by
 // comparing its results to the results of a naive search.
-/** This is known to not work: see #368.
+//* This is known to not work: see #368.
 BOOST_AUTO_TEST_CASE(XTreeTraverserTest)
 {
   arma::mat dataset;
@@ -595,32 +591,28 @@ BOOST_AUTO_TEST_CASE(XTreeTraverserTest)
   arma::Mat<size_t> neighbors2;
   arma::mat distances2;
 
-  typedef RectangleTree<
-      XTreeSplit<RStarTreeDescentHeuristic,
-                 NeighborSearchStat<NearestNeighborSort>,
-                 arma::mat>,
-      RStarTreeDescentHeuristic,
-      NeighborSearchStat<NearestNeighborSort>,
+  typedef XTree<EuclideanDistance, NeighborSearchStat<NearestNeighborSort>,
       arma::mat> TreeType;
   TreeType xTree(dataset, 20, 6, 5, 2, 0);
 
   // Nearest neighbor search with the X tree.
-  NeighborSearch<NearestNeighborSort, metric::LMetric<2, true>, TreeType>
-      allknn1(&xTree, dataset, true);
+
+  NeighborSearch<NearestNeighborSort, metric::LMetric<2, true>, arma::mat, XTree >
+      knn1(&xTree, true);
 
   BOOST_REQUIRE_EQUAL(xTree.NumDescendants(), numP);
 
   CheckSync(xTree);
-  //CheckContainment(xTree);
+  CheckContainment(xTree);
   CheckExactContainment(xTree);
   CheckHierarchy(xTree);
 
-  allknn1.Search(5, neighbors1, distances1);
+  knn1.Search(5, neighbors1, distances1);
 
   // Nearest neighbor search the naive way.
-  AllkNN allknn2(dataset, true, true);
+  KNN knn2(dataset, true, true);
 
-  allknn2.Search(5, neighbors2, distances2);
+  knn2.Search(5, neighbors2, distances2);
 
   for (size_t i = 0; i < neighbors1.size(); i++)
   {
@@ -628,7 +620,6 @@ BOOST_AUTO_TEST_CASE(XTreeTraverserTest)
     BOOST_REQUIRE_EQUAL(distances1[i], distances2[i]);
   }
 }
-*/
 
 // Test the tree splitting.  We set MaxLeafSize and MaxNumChildren rather low
 // to allow us to test by hand without adding hundreds of points.
